@@ -22,6 +22,7 @@ package org.apache.ranger.admin.client;
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.plugin.model.RangerRole;
 import org.apache.ranger.plugin.util.*;
 import org.slf4j.Logger;
@@ -34,6 +35,8 @@ public abstract class AbstractRangerAdminClient implements RangerAdminClient {
 
     protected Gson gson;
 
+    private boolean forceNonKerberos = false;
+
     @Override
     public void init(String serviceName, String appId, String configPropertyPrefix, Configuration config) {
         Gson gson = null;
@@ -45,6 +48,7 @@ public abstract class AbstractRangerAdminClient implements RangerAdminClient {
         }
 
         this.gson = gson;
+        this.forceNonKerberos = config.getBoolean(configPropertyPrefix + ".forceNonKerberos", false);
     }
 
     @Override
@@ -116,4 +120,16 @@ public abstract class AbstractRangerAdminClient implements RangerAdminClient {
     public RangerUserStore getUserStoreIfUpdated(long lastKnownUserStoreVersion, long lastActivationTimeInMillis) throws Exception {
         return null;
     }
+
+    public boolean isKerberosEnabled(UserGroupInformation user) {
+        final boolean ret;
+
+        if (forceNonKerberos) {
+            ret = false;
+        } else {
+            ret = user != null && UserGroupInformation.isSecurityEnabled() && user.hasKerberosCredentials();
+        }
+
+        return ret;
+    }
 }
