@@ -25,25 +25,28 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.hadoop.config.RangerPluginConfig;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.plugin.model.RangerPolicy;
-import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
+import org.apache.ranger.plugin.model.RangerServiceDef.RangerResourceDef;
 import org.apache.ranger.plugin.model.RangerServiceResource;
 import org.apache.ranger.plugin.model.RangerTag;
 import org.apache.ranger.plugin.model.validation.RangerServiceDefHelper;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
+import org.apache.ranger.plugin.policyengine.RangerAccessRequest.ResourceMatchingScope;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequestImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResource;
 import org.apache.ranger.plugin.policyengine.RangerAccessResourceImpl;
+import org.apache.ranger.plugin.policyengine.RangerPluginContext;
 import org.apache.ranger.plugin.policyengine.RangerResourceTrie;
 import org.apache.ranger.plugin.policyresourcematcher.RangerDefaultPolicyResourceMatcher;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
 import org.apache.ranger.plugin.util.DownloadTrigger;
 import org.apache.ranger.plugin.util.DownloaderTask;
 import org.apache.ranger.plugin.service.RangerAuthContext;
+import org.apache.ranger.plugin.util.CachedResourceEvaluators;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
 import org.apache.ranger.plugin.util.RangerCommonConstants;
 import org.apache.ranger.plugin.util.RangerPerfTracer;
 import org.apache.ranger.plugin.util.RangerReadWriteLock;
-import org.apache.ranger.plugin.util.RangerResourceEvaluatorsRetriever;
 import org.apache.ranger.plugin.util.RangerServiceNotFoundException;
 import org.apache.ranger.plugin.util.RangerServiceTagsDeltaUtil;
 import org.apache.ranger.plugin.util.ServiceTags;
@@ -73,12 +76,11 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 	private static final Logger LOG = LoggerFactory.getLogger(RangerTagEnricher.class);
 
 	private static final Logger PERF_CONTEXTENRICHER_INIT_LOG = RangerPerfTracer.getPerfLogger("contextenricher.init");
-	private static final Logger PERF_TRIE_OP_LOG              = RangerPerfTracer.getPerfLogger("resourcetrie.retrieval");
 	private static final Logger PERF_SET_SERVICETAGS_LOG      = RangerPerfTracer.getPerfLogger("tagenricher.setservicetags");
 	private static final Logger PERF_SERVICETAGS_RETRIEVAL_LOG = RangerPerfTracer.getPerfLogger("tagenricher.tags.retrieval");
 
 	private static final String TAG_REFRESHER_POLLINGINTERVAL_OPTION = "tagRefresherPollingInterval";
-	public static final String TAG_RETRIEVER_CLASSNAME_OPTION        = "tagRetrieverClassName";
+	public  static final String TAG_RETRIEVER_CLASSNAME_OPTION       = "tagRetrieverClassName";
 	private static final String TAG_DISABLE_TRIE_PREFILTER_OPTION    = "disableTrieLookupPrefilter";
 
 	private RangerTagRefresher                 tagRefresher;
@@ -87,12 +89,13 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 	private EnrichedServiceTags                enrichedServiceTags;
 	private boolean                            disableCacheIfServiceNotFound = true;
 	private boolean                            dedupStrings                  = true;
+	private Timer                              tagDownloadTimer;
+	private RangerServiceDefHelper             serviceDefHelper;
 
 	private final BlockingQueue<DownloadTrigger> tagDownloadQueue = new LinkedBlockingQueue<>();
-	private Timer                              tagDownloadTimer;
+	private final RangerReadWriteLock            lock             = new RangerReadWriteLock(false);
+	private final CachedResourceEvaluators       cache            = new CachedResourceEvaluators();
 
-	private RangerServiceDefHelper             serviceDefHelper;
-	private RangerReadWriteLock                lock = new RangerReadWriteLock(false);
 
 	@Override
 	public void init() {
@@ -287,6 +290,9 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			LOG.debug("==> RangerTagEnricher.setServiceTags(serviceTags=" + serviceTags + ", rebuildOnlyIndex=" + rebuildOnlyIndex + ")");
 		}
 
+		final EnrichedServiceTags localEnrichedServiceTags;
+		final Set<String>         keysToRemoveFromCache = new HashSet<>();
+
 		try (RangerReadWriteLock.RangerLock writeLock = this.lock.getWriteLock()) {
 
 			if (LOG.isDebugEnabled()) {
@@ -296,13 +302,13 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			}
 			RangerPerfTracer perf = null;
 
-			if(RangerPerfTracer.isPerfTraceEnabled(PERF_SET_SERVICETAGS_LOG)) {
+			if (RangerPerfTracer.isPerfTraceEnabled(PERF_SET_SERVICETAGS_LOG)) {
 				perf = RangerPerfTracer.getPerfTracer(PERF_SET_SERVICETAGS_LOG, "RangerTagEnricher.setServiceTags(newTagVersion=" + serviceTags.getTagVersion() + ",isDelta=" + serviceTags.getIsDelta() + ")");
 			}
 
 			if (serviceTags == null) {
 				LOG.info("ServiceTags is null for service " + serviceName);
-				enrichedServiceTags = null;
+				localEnrichedServiceTags = null;
 			} else {
 				if (dedupStrings) {
 					serviceTags.dedupStrings();
@@ -314,7 +320,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 
 						LOG.info("Number of duplicate tags removed from the received serviceTags:[" + countOfDuplicateTags + "]. Number of tags in the de-duplicated serviceTags :[" + serviceTags.getTags().size() + "].");
 					}
-					processServiceTags(serviceTags);
+					localEnrichedServiceTags = processServiceTags(serviceTags);
 				} else {
 					if (LOG.isDebugEnabled()) {
 						LOG.debug("Received service-tag deltas:" + serviceTags);
@@ -326,6 +332,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 						if (LOG.isDebugEnabled()) {
 							LOG.debug("No change to service-tags other than version change");
 						}
+						localEnrichedServiceTags = enrichedServiceTags;
 					} else {
 						if (serviceTags.getTagsChangeExtent() != ServiceTags.TagsChangeExtent.TAGS) {
 							Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> trieMap;
@@ -336,20 +343,32 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 								trieMap = writeLock.isLockingEnabled() ? enrichedServiceTags.getServiceResourceTrie() : copyServiceResourceTrie();
 							}
 
-							processServiceTagDeltas(serviceTags, allServiceTags, trieMap);
+							localEnrichedServiceTags = processServiceTagDeltas(serviceTags, allServiceTags, trieMap, keysToRemoveFromCache);
 						} else {
 							if (LOG.isDebugEnabled()) {
 								LOG.debug("Delta contains only tag attribute changes");
 							}
-							List<RangerServiceResourceMatcher> resourceMatchers = enrichedServiceTags != null ? enrichedServiceTags.getServiceResourceMatchers() : new ArrayList<>();
+							List<RangerServiceResourceMatcher>                            resourceMatchers    = enrichedServiceTags != null ? enrichedServiceTags.getServiceResourceMatchers() : new ArrayList<>();
 							Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> serviceResourceTrie = enrichedServiceTags != null ? enrichedServiceTags.getServiceResourceTrie() : new HashMap<>();
-							enrichedServiceTags = new EnrichedServiceTags(allServiceTags, resourceMatchers, serviceResourceTrie);
+							localEnrichedServiceTags = new EnrichedServiceTags(allServiceTags, resourceMatchers, serviceResourceTrie);
 						}
 					}
 				}
-
 			}
-			setEnrichedServiceTagsInPlugin();
+
+			synchronized (RangerTagEnricher.class) {
+				enrichedServiceTags = localEnrichedServiceTags;
+
+				if (serviceTags != null) {
+					if (serviceTags.getIsDelta()) {
+						cache.removeCacheEvaluators(keysToRemoveFromCache);
+						keysToRemoveFromCache.clear();
+					} else {
+						cache.clearCache();
+					}
+				}
+				setEnrichedServiceTagsInPlugin();
+			}
 
 			RangerPerfTracer.logAlways(perf);
 		}
@@ -422,14 +441,16 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 		return new RangerReadWriteLock(useReadWriteLock);
 
 	}
-	private void processServiceTags(ServiceTags serviceTags) {
+	private EnrichedServiceTags processServiceTags(ServiceTags serviceTags) {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("Processing all service-tags");
 		}
 
+		final EnrichedServiceTags ret;
+
 		if (CollectionUtils.isEmpty(serviceTags.getServiceResources())) {
 			LOG.info("There are no tagged resources for service " + serviceName);
-			enrichedServiceTags = null;
+			ret = null;
 		} else {
 			ResourceHierarchies                hierarchies      = new ResourceHierarchies();
 			List<RangerServiceResourceMatcher> resourceMatchers = new ArrayList<>();
@@ -437,7 +458,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 
 			for (ListIterator<RangerServiceResource> iter = serviceResources.listIterator(); iter.hasNext(); ) {
 				RangerServiceResource        serviceResource        = iter.next();
-				RangerServiceResourceMatcher serviceResourceMatcher = createRangerServiceResourceMatcher(serviceResource, serviceDefHelper, hierarchies);
+				RangerServiceResourceMatcher serviceResourceMatcher = createRangerServiceResourceMatcher(serviceResource, serviceDefHelper, hierarchies, getPluginContext());
 
 				if (serviceResourceMatcher != null) {
 					resourceMatchers.add(serviceResourceMatcher);
@@ -455,19 +476,22 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			if (!disableTrieLookupPrefilter) {
 				serviceResourceTrie = new HashMap<>();
 
-				for (RangerServiceDef.RangerResourceDef resourceDef : serviceDef.getResources()) {
+				for (RangerResourceDef resourceDef : serviceDef.getResources()) {
 					serviceResourceTrie.put(resourceDef.getName(), new RangerResourceTrie(resourceDef, resourceMatchers, getPolicyEngineOptions().optimizeTagTrieForRetrieval, getPolicyEngineOptions().optimizeTagTrieForSpace, null));
 				}
 			}
-			enrichedServiceTags = new EnrichedServiceTags(serviceTags, resourceMatchers, serviceResourceTrie);
+			ret = new EnrichedServiceTags(serviceTags, resourceMatchers, serviceResourceTrie);
 		}
+		return ret;
 	}
 
-	private void processServiceTagDeltas(ServiceTags deltas, ServiceTags allServiceTags, Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> serviceResourceTrie) {
+	private EnrichedServiceTags processServiceTagDeltas(ServiceTags deltas, ServiceTags allServiceTags, Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> serviceResourceTrie, Set<String> keysToRemoveFromCache) {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("Delta contains changes other than tag attribute changes, [" + deltas.getTagsChangeExtent() + "]");
 		}
 
+		final EnrichedServiceTags ret;
+
 		boolean                            isInError        = false;
 
 		ResourceHierarchies                hierarchies      = new ResourceHierarchies();
@@ -480,15 +504,15 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 		List<RangerServiceResource> changedServiceResources = deltas.getServiceResources();
 
 		for (RangerServiceResource serviceResource : changedServiceResources) {
-			final boolean removedOldServiceResource = MapUtils.isEmpty(serviceResource.getResourceElements()) || removeOldServiceResource(serviceResource, resourceMatchers, serviceResourceTrie);
+			final RangerAccessResource removedAccessResource = MapUtils.isEmpty(serviceResource.getResourceElements()) ? null : removeOldServiceResource(serviceResource, resourceMatchers, serviceResourceTrie);
 
-			if (removedOldServiceResource) {
+			if (removedAccessResource != null) {
 				if (!StringUtils.isEmpty(serviceResource.getResourceSignature())) {
-					RangerServiceResourceMatcher resourceMatcher = createRangerServiceResourceMatcher(serviceResource, serviceDefHelper, hierarchies);
+					RangerServiceResourceMatcher resourceMatcher = createRangerServiceResourceMatcher(serviceResource, serviceDefHelper, hierarchies, getPluginContext());
 
 					if (resourceMatcher != null) {
-						for (RangerServiceDef.RangerResourceDef resourceDef : serviceDef.getResources()) {
-							RangerPolicy.RangerPolicyResource                policyResource = serviceResource.getResourceElements().get(resourceDef.getName());
+						for (RangerResourceDef resourceDef : serviceDef.getResources()) {
+							RangerPolicyResource                             policyResource = serviceResource.getResourceElements().get(resourceDef.getName());
 							RangerResourceTrie<RangerServiceResourceMatcher> trie           = serviceResourceTrie.get(resourceDef.getName());
 
 							if (LOG.isDebugEnabled()) {
@@ -518,6 +542,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 						LOG.debug("Service-resource:[id=" + serviceResource.getId() + "] is deleted as its resource-signature is empty. No need to create it!");
 					}
 				}
+				keysToRemoveFromCache.add(removedAccessResource.getCacheKey());
 			} else {
 				isInError = true;
 			}
@@ -529,16 +554,20 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 		if (isInError) {
 			LOG.error("Error in processing tag-deltas. Will continue to use old tags");
 			deltas.setTagVersion(-1L);
+			keysToRemoveFromCache.clear();
+			ret = enrichedServiceTags;
 		} else {
 			for (Map.Entry<String, RangerResourceTrie<RangerServiceResourceMatcher>> entry : serviceResourceTrie.entrySet()) {
 				entry.getValue().wrapUpUpdate();
 			}
-			enrichedServiceTags = new EnrichedServiceTags(allServiceTags, resourceMatchers, serviceResourceTrie);
+			ret = new EnrichedServiceTags(allServiceTags, resourceMatchers, serviceResourceTrie);
 		}
+		return ret;
 	}
 
-	private boolean removeOldServiceResource(RangerServiceResource serviceResource, List<RangerServiceResourceMatcher> resourceMatchers, Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> resourceTries) {
-		boolean ret = true;
+	private RangerAccessResource removeOldServiceResource(RangerServiceResource serviceResource, List<RangerServiceResourceMatcher> resourceMatchers, Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> resourceTries) {
+		final RangerAccessResource ret;
+		boolean result = true;
 
 		if (enrichedServiceTags != null) {
 			if (LOG.isDebugEnabled()) {
@@ -547,10 +576,12 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 
 			RangerAccessResourceImpl accessResource = new RangerAccessResourceImpl();
 
-			for (Map.Entry<String, RangerPolicy.RangerPolicyResource> entry : serviceResource.getResourceElements().entrySet()) {
+			for (Map.Entry<String, RangerPolicyResource> entry : serviceResource.getResourceElements().entrySet()) {
 				accessResource.setValue(entry.getKey(), entry.getValue().getValues());
 			}
 
+			accessResource.setServiceDef(serviceDef);
+
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("RangerAccessResource:[" + accessResource + "] created to represent service-resource[" + serviceResource + "] to find evaluators from trie-map");
 			}
@@ -558,7 +589,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			RangerAccessRequestImpl request = new RangerAccessRequestImpl();
 			request.setResource(accessResource);
 
-			Collection<RangerServiceResourceMatcher> oldMatchers = getEvaluators(request, enrichedServiceTags);
+			Collection<RangerServiceResourceMatcher> oldMatchers = CachedResourceEvaluators.getEvaluators(request, enrichedServiceTags.getServiceResourceTrie(), cache);
 
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("Found [" + oldMatchers + "] matchers for service-resource[" + serviceResource + "]");
@@ -587,7 +618,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			}
 
 			for (RangerServiceResourceMatcher matcher : oldMatchers) {
-				for (RangerServiceDef.RangerResourceDef resourceDef : serviceDef.getResources()) {
+				for (RangerResourceDef resourceDef : serviceDef.getResources()) {
 					String                                           resourceDefName = resourceDef.getName();
 					RangerResourceTrie<RangerServiceResourceMatcher> trie            = resourceTries.get(resourceDefName);
 
@@ -596,24 +627,31 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 					} else {
 						LOG.error("Cannot find resourceDef with name:[" + resourceDefName + "]. Should NOT happen!!");
 						LOG.error("Setting tagVersion to -1 to ensure that in the next download all tags are downloaded");
-						ret = false;
+						result = false;
 						break;
 					}
 				}
 			}
 
-			if (ret) {
+			if (result) {
 				resourceMatchers.removeAll(oldMatchers);
 
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("Found and removed [" + oldMatchers + "] matchers for service-resource[" + serviceResource + "] from trie-map");
 				}
+
+				ret = accessResource;
+			} else {
+				ret = null;
 			}
+		} else {
+			ret = null;
 		}
+
 		return ret;
 	}
 
-	static public RangerServiceResourceMatcher createRangerServiceResourceMatcher(RangerServiceResource serviceResource, RangerServiceDefHelper serviceDefHelper, ResourceHierarchies hierarchies) {
+	static public RangerServiceResourceMatcher createRangerServiceResourceMatcher(RangerServiceResource serviceResource, RangerServiceDefHelper serviceDefHelper, ResourceHierarchies hierarchies, RangerPluginContext pluginContext) {
 
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> createRangerServiceResourceMatcher(serviceResource=" + serviceResource + ")");
@@ -628,7 +666,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			if (isValidHierarchy == null) { // hierarchy not yet validated
 				isValidHierarchy = Boolean.FALSE;
 
-				for (List<RangerServiceDef.RangerResourceDef> hierarchy : serviceDefHelper.getResourceHierarchies(policyType)) {
+				for (List<RangerResourceDef> hierarchy : serviceDefHelper.getResourceHierarchies(policyType)) {
 					if (serviceDefHelper.hierarchyHasAllResources(hierarchy, resourceKeys)) {
 						isValidHierarchy = Boolean.TRUE;
 
@@ -644,6 +682,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 
 				matcher.setServiceDef(serviceDefHelper.getServiceDef());
 				matcher.setPolicyResources(serviceResource.getResourceElements(), policyType);
+				matcher.setPluginContext(pluginContext);
 
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("RangerTagEnricher.setServiceTags() - Initializing matcher with (resource=" + serviceResource
@@ -704,7 +743,7 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			ret = enrichedServiceTags.getTagsForEmptyResourceAndAnyAccess();
 		} else {
 
-			final Collection<RangerServiceResourceMatcher> serviceResourceMatchers = getEvaluators(request, enrichedServiceTags);
+			final Collection<RangerServiceResourceMatcher> serviceResourceMatchers = CachedResourceEvaluators.getEvaluators(request, enrichedServiceTags.getServiceResourceTrie(), cache);
 
 			if (CollectionUtils.isNotEmpty(serviceResourceMatchers)) {
 				for (RangerServiceResourceMatcher resourceMatcher : serviceResourceMatchers) {
@@ -715,14 +754,13 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 						LOG.debug("resource:[" + resource + ", MatchType:[" + matchType + "]");
 					}
 
-					final boolean isMatched;
+					final ResourceMatchingScope resourceMatchingScope = request.getResourceMatchingScope() != null ? request.getResourceMatchingScope() : ResourceMatchingScope.SELF;
+					final boolean               isMatched;
 
-					if (request.isAccessTypeAny()) {
-						isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-					} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-						isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
+					if (request.isAccessTypeAny() || resourceMatchingScope == ResourceMatchingScope.SELF_OR_DESCENDANTS) {
+						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR || matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
 					} else {
-						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
+						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR || matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS;
 					}
 
 					if (isMatched) {
@@ -755,40 +793,6 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 		return ret;
 	}
 
-	private Collection<RangerServiceResourceMatcher> getEvaluators(RangerAccessRequest request, EnrichedServiceTags enrichedServiceTags) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerTagEnricher.getEvaluators(request=" + request + ")");
-		}
-		Collection<RangerServiceResourceMatcher>  ret;
-
-		RangerAccessResource                resource   = request.getResource();
-
-		final Map<String, RangerResourceTrie<RangerServiceResourceMatcher>> serviceResourceTrie = enrichedServiceTags.getServiceResourceTrie();
-
-		if (resource == null || resource.getKeys() == null || resource.getKeys().isEmpty() || serviceResourceTrie == null) {
-			ret = enrichedServiceTags.getServiceResourceMatchers();
-		} else {
-			RangerPerfTracer perf = null;
-
-			if (RangerPerfTracer.isPerfTraceEnabled(PERF_TRIE_OP_LOG)) {
-				perf = RangerPerfTracer.getPerfTracer(PERF_TRIE_OP_LOG, "RangerTagEnricher.getEvaluators(resource=" + resource.getAsString() + ")");
-			}
-
-			ret = RangerResourceEvaluatorsRetriever.getEvaluators(serviceResourceTrie, resource.getAsMap(), request.getResourceElementMatchingScopes());
-
-			RangerPerfTracer.logAlways(perf);
-		}
-		if (ret == null) {
-			ret = new ArrayList<>();
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerTagEnricher.getEvaluators(request=" + request + "): evaluators=" + ret);
-		}
-
-		return ret;
-	}
-
 	private static Set<RangerTagForEval> getTagsForServiceResource(Date accessTime, final ServiceTags serviceTags, final RangerServiceResource serviceResource, final RangerPolicyResourceMatcher.MatchType matchType) {
 		Set<RangerTagForEval> ret = new HashSet<>();
 
@@ -1144,4 +1148,5 @@ public class RangerTagEnricher extends RangerAbstractContextEnricher {
 			}
 		}
 	}
+
 }
