@@ -27,27 +27,22 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlRootElement;
-
 import org.apache.ranger.authorization.utils.StringUtil;
-import org.codehaus.jackson.annotate.JsonAutoDetect;
-import org.codehaus.jackson.annotate.JsonIgnoreProperties;
-import org.codehaus.jackson.annotate.JsonAutoDetect.Visibility;
-import org.codehaus.jackson.map.annotate.JsonSerialize;
+import com.fasterxml.jackson.annotation.JsonAutoDetect;
+import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
+import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;
+import com.fasterxml.jackson.annotation.JsonInclude;
 
 
 @JsonAutoDetect(fieldVisibility=Visibility.ANY)
-@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+@JsonInclude(JsonInclude.Include.NON_EMPTY)
 @JsonIgnoreProperties(ignoreUnknown=true)
-@XmlRootElement
-@XmlAccessorType(XmlAccessType.FIELD)
 public class RangerServiceDef extends RangerBaseModelObject implements java.io.Serializable {
 	private static final long serialVersionUID = 1L;
 
 	public static final String OPTION_ENABLE_DENY_AND_EXCEPTIONS_IN_POLICIES = "enableDenyAndExceptionsInPolicies";
 	public static final String OPTION_ENABLE_IMPLICIT_CONDITION_EXPRESSION   = "enableImplicitConditionExpression";
+	public static final String OPTION_ENABLE_TAG_BASED_POLICIES = "enableTagBasedPolicies";
 
 	private String                         name;
 	private String                         displayName;
@@ -65,6 +60,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	private List<RangerEnumDef>            enums;
 	private RangerDataMaskDef              dataMaskDef;
 	private RangerRowFilterDef             rowFilterDef;
+	private List<RangerAccessTypeDef>      markerAccessTypes; // read-only
 
 	public RangerServiceDef() {
 		this(null, null, null, null, null, null, null, null, null, null, null, null, null);
@@ -104,6 +100,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		setEnums(enums);
 		setDataMaskDef(dataMaskDef);
 		setRowFilterDef(rowFilterDef);
+		setMarkerAccessTypes(null);
 	}
 
 	public RangerServiceDef(String name, String displayName, String implClass, String label, String description,
@@ -137,6 +134,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		setEnums(other.getEnums());
 		setDataMaskDef(other.getDataMaskDef());
 		setRowFilterDef(other.getRowFilterDef());
+		setMarkerAccessTypes(other.getMarkerAccessTypes());
 	}
 
 	/**
@@ -421,6 +419,26 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.rowFilterDef = rowFilterDef == null ? new RangerRowFilterDef() : rowFilterDef;
 	}
 
+	public List<RangerAccessTypeDef> getMarkerAccessTypes() {
+		return markerAccessTypes;
+	}
+
+	public void setMarkerAccessTypes(List<RangerAccessTypeDef> markerAccessTypes) {
+		if (this.markerAccessTypes == null) {
+			this.markerAccessTypes = new ArrayList<>();
+		}
+
+		if (this.markerAccessTypes == markerAccessTypes) {
+			return;
+		}
+
+		this.markerAccessTypes.clear();
+
+		if(markerAccessTypes != null) {
+			this.markerAccessTypes.addAll(markerAccessTypes);
+		}
+	}
+
 	public String getDisplayName() {
 		return displayName;
 	}
@@ -481,6 +499,12 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		if (rowFilterDef != null) {
 			rowFilterDef.dedupStrings(strTbl);
 		}
+
+		if (markerAccessTypes != null) {
+			for (RangerAccessTypeDef accessType : markerAccessTypes) {
+				accessType.dedupStrings(strTbl);
+			}
+		}
 	}
 
 	@Override
@@ -585,6 +609,16 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		}
 		sb.append("} ");
 
+		sb.append("markerAccessTypes={");
+		if(markerAccessTypes != null) {
+			for(RangerAccessTypeDef accessType : markerAccessTypes) {
+				if(accessType != null) {
+					accessType.toString(sb);
+				}
+			}
+		}
+		sb.append("} ");
+
 		sb.append("}");
 
 		return sb;
@@ -592,10 +626,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerEnumDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -768,10 +800,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerEnumElementDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 		
@@ -923,10 +953,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerServiceConfigDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -1326,10 +1354,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerResourceDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -1918,29 +1944,39 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerAccessTypeDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
+		public enum AccessTypeCategory { CREATE, READ, UPDATE, DELETE, MANAGE }
+
 		private Long               itemId;
 		private String             name;
 		private String             label;
 		private String             rbKeyLabel;
 		private Collection<String> impliedGrants;
+		private AccessTypeCategory category;
 
 		public RangerAccessTypeDef() {
-			this(null, null, null, null, null);
+			this(null, null, null, null, null, null);
+		}
+
+		public RangerAccessTypeDef(String name) {
+			this(null, name, name, null, null, null);
 		}
 
 		public RangerAccessTypeDef(Long itemId, String name, String label, String rbKeyLabel, Collection<String> impliedGrants) {
+			this(itemId, name, label, rbKeyLabel, impliedGrants, null);
+		}
+
+		public RangerAccessTypeDef(Long itemId, String name, String label, String rbKeyLabel, Collection<String> impliedGrants, AccessTypeCategory category) {
 			setItemId(itemId);
 			setName(name);
 			setLabel(label);
 			setRbKeyLabel(rbKeyLabel);
 			setImpliedGrants(impliedGrants);
+			setCategory(category);
 		}
 
 		public RangerAccessTypeDef(RangerAccessTypeDef other) {
@@ -1949,6 +1985,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			setLabel(other.getLabel());
 			setRbKeyLabel(other.getRbKeyLabel());
 			setImpliedGrants(other.getImpliedGrants());
+			setCategory((other.getCategory()));
 		}
 
 		/**
@@ -2033,6 +2070,14 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			}
 		}
 
+		public AccessTypeCategory getCategory() {
+			return category;
+		}
+
+		public void setCategory(AccessTypeCategory category) {
+			this.category = category;
+		}
+
 		public void dedupStrings(Map<String, String> strTbl) {
 			name          = StringUtil.dedupString(name, strTbl);
 			label         = StringUtil.dedupString(label, strTbl);
@@ -2065,6 +2110,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 				}
 			}
 			sb.append("} ");
+			sb.append("category={").append(category).append("} ");
 
 			sb.append("}");
 
@@ -2127,10 +2173,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerPolicyConditionDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -2496,10 +2540,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	}
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerContextEnricherDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -2653,10 +2695,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerDataMaskDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -2850,10 +2890,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	}
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerDataMaskTypeDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -3111,10 +3149,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	}
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RangerRowFilterDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
