@@ -21,14 +21,11 @@ package org.apache.ranger.plugin.model;
 
 
 import org.apache.ranger.plugin.util.ServiceTags;
-import org.codehaus.jackson.annotate.JsonAutoDetect;
-import org.codehaus.jackson.annotate.JsonAutoDetect.Visibility;
-import org.codehaus.jackson.annotate.JsonIgnoreProperties;
-import org.codehaus.jackson.map.annotate.JsonSerialize;
+import com.fasterxml.jackson.annotation.JsonAutoDetect;
+import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;
+import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
+import com.fasterxml.jackson.annotation.JsonInclude;
 
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlRootElement;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
@@ -36,10 +33,8 @@ import java.util.List;
 import java.util.Map;
 
 @JsonAutoDetect(fieldVisibility=Visibility.ANY)
-@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+@JsonInclude(JsonInclude.Include.NON_EMPTY)
 @JsonIgnoreProperties(ignoreUnknown=true)
-@XmlRootElement
-@XmlAccessorType(XmlAccessType.FIELD)
 public class RangerServiceTags implements java.io.Serializable {
     private static final long serialVersionUID = 1L;
 
@@ -175,7 +170,7 @@ public class RangerServiceTags implements java.io.Serializable {
             ret = new ServiceTags(toServiceTagsOp(tags.getOp()), tags.getServiceName(),
                                   tags.tagVersion, tags.getTagUpdateTime(), tags.getTagDefinitions(), tags.getTags(),
                                   tags.getServiceResources(), tags.getResourceToTagIds(), false,
-                                  ServiceTags.TagsChangeExtent.ALL);
+                                  ServiceTags.TagsChangeExtent.ALL, false);
         }
 
         return ret;
