@@ -30,6 +30,7 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.Collectors;
 
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
@@ -172,6 +173,14 @@ public class RangerServiceDefHelper {
 		_delegate.patchServiceDefWithDefaultValues();
 	}
 
+	public RangerResourceDef getResourceDef(String resourceName) {
+		return _delegate.getResourceDef(resourceName, RangerPolicy.POLICY_TYPE_ACCESS);
+	}
+
+	public RangerResourceDef getResourceDef(String resourceName, Integer policyType) {
+		return _delegate.getResourceDef(resourceName, policyType);
+	}
+
 	/**
 	 * for a resource definition as follows:
 	 *
@@ -342,6 +351,10 @@ public class RangerServiceDefHelper {
 		return _delegate.getWildcardEnabledResourceDef(resourceName, policyType);
 	}
 
+	public Set<String> getAllAccessTypes() {
+		return _delegate.getAllAccessTypes();
+	}
+
 	public Map<String, Collection<String>> getImpliedAccessGrants() {
 		return _delegate.getImpliedAccessGrants();
 	}
@@ -360,6 +373,7 @@ public class RangerServiceDefHelper {
 		final boolean _valid;
 		final List<String> _orderedResourceNames;
 		final Map<String, Collection<String>> _impliedGrants;
+		final Set<String>                     _allAccessTypes;
 		final static Set<List<RangerResourceDef>> EMPTY_RESOURCE_HIERARCHY = Collections.unmodifiableSet(new HashSet<List<RangerResourceDef>>());
 
 
@@ -398,7 +412,8 @@ public class RangerServiceDefHelper {
 				}
 			}
 
-			_impliedGrants = computeImpliedGrants();
+			_impliedGrants  = computeImpliedGrants();
+			_allAccessTypes = Collections.unmodifiableSet(serviceDef.getAccessTypes().stream().map(RangerAccessTypeDef::getName).collect(Collectors.toSet()));
 
 			if (isValid) {
 				_orderedResourceNames = buildSortedResourceNames();
@@ -428,6 +443,28 @@ public class RangerServiceDefHelper {
 			}
 		}
 
+		public RangerResourceDef getResourceDef(String resourceName, Integer policyType) {
+			RangerResourceDef ret = null;
+
+			if (policyType == null) {
+				policyType = RangerPolicy.POLICY_TYPE_ACCESS;
+			}
+
+			List<RangerResourceDef> resourceDefs = this.getResourceDefs(_serviceDef, policyType);
+
+			if (resourceDefs != null) {
+				for (RangerResourceDef resourceDef : resourceDefs) {
+					if (StringUtils.equals(resourceName, resourceDef.getName())) {
+						ret = resourceDef;
+
+						break;
+					}
+				}
+			}
+
+			return ret;
+		}
+
 		public Set<List<RangerResourceDef>> getResourceHierarchies(Integer policyType) {
 			if(policyType == null) {
 				policyType = RangerPolicy.POLICY_TYPE_ACCESS;
@@ -463,6 +500,11 @@ public class RangerServiceDefHelper {
 		public boolean isResourceGraphValid() {
 			return _valid;
 		}
+
+		public Set<String> getAllAccessTypes() {
+			return _allAccessTypes;
+		}
+
 		/**
 		 * Builds a directed graph where each resource is node and arc goes from parent level to child level
 		 *
