@@ -28,7 +28,9 @@ import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.util.MacroProcessor;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
 import org.apache.ranger.plugin.util.RangerPerfTracer;
+import org.apache.ranger.plugin.util.RangerTimeRangeChecker;
 import org.apache.ranger.plugin.util.RangerUserStore;
+import org.apache.ranger.plugin.util.JavaScriptEdits;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -66,28 +68,31 @@ public final class RangerRequestScriptEvaluator {
 	private static final String DEFAULT_RANGER_TAG_ATTRIBUTE_DATE_FORMAT    = "yyyy/MM/dd";
 	private static final String DEFAULT_ATLAS_TAG_ATTRIBUTE_DATE_FORMAT_NAME = "ATLAS_DATE_FORMAT";
 	private static final String DEFAULT_ATLAS_TAG_ATTRIBUTE_DATE_FORMAT     = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'";
+	private static final String SCRIPT_SAFE_PREEXEC                         = "exit=null;quit=null;";
 	private static final String SCRIPT_PREEXEC                              = SCRIPT_VAR__CTX + "=JSON.parse(" + SCRIPT_VAR__CTX_JSON + "); J=JSON.stringify;" +
-                                                                                 SCRIPT_VAR_REQ + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_REQUEST + ";" +
-                                                                                 SCRIPT_VAR_RES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_RESOURCE + ";" +
-                                                                                 SCRIPT_VAR_USER + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_ATTRIBUTES + ";" +
-                                                                                 SCRIPT_VAR_UGNAMES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_GROUPS + ";" +
-                                                                                 SCRIPT_VAR_UG + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_GROUP_ATTRIBUTES + ";" +
-                                                                                 SCRIPT_VAR_UGA + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_UGA + ";" +
-                                                                                 SCRIPT_VAR_URNAMES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_ROLES + ";" +
-                                                                                 SCRIPT_VAR_TAG + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAG + ";" +
-                                                                                 SCRIPT_VAR_TAGS + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAGS + ";" +
-                                                                                 SCRIPT_VAR_TAGNAMES + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAG_NAMES + ";";
+			SCRIPT_VAR_REQ + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_REQUEST + ";" +
+			SCRIPT_VAR_RES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_RESOURCE + ";" +
+			SCRIPT_VAR_USER + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_ATTRIBUTES + ";" +
+			SCRIPT_VAR_UGNAMES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_GROUPS + ";" +
+			SCRIPT_VAR_UG + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_GROUP_ATTRIBUTES + ";" +
+			SCRIPT_VAR_UGA + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_UGA + ";" +
+			SCRIPT_VAR_URNAMES + "=" + SCRIPT_VAR_REQ + "." + SCRIPT_FIELD_USER_ROLES + ";" +
+			SCRIPT_VAR_TAG + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAG + ";" +
+			SCRIPT_VAR_TAGS + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAGS + ";" +
+			SCRIPT_VAR_TAGNAMES + "=" + SCRIPT_VAR__CTX + "." + SCRIPT_FIELD_TAG_NAMES + ";";
 	private static final Pattern JSON_VAR_NAMES_PATTERN   = Pattern.compile(getJsonVarNamesPattern());
 	private static final Pattern USER_ATTRIBUTES_PATTERN  = Pattern.compile(getUserAttributesPattern());
 	private static final Pattern GROUP_ATTRIBUTES_PATTERN = Pattern.compile(getGroupAttributesPattern());
-	private static final Character CHAR_QUOTE = '\'';
-	private static final Character CHAR_COMMA = ',';
+	private static final String  STR_QUOTE  = "'";
+	private static final String  STR_COMMA  = ",";
 
 	private static final MacroProcessor MACRO_PROCESSOR = new MacroProcessor(getMacrosMap());
 
 	private static String[] dateFormatStrings = null;
 
 	private final RangerAccessRequest              accessRequest;
+	private final ScriptEngine                     scriptEngine;
+	private final Bindings                         bindings;
 	private       boolean                          initDone   = false;
 	private       Map<String, String>              userAttrs  = Collections.emptyMap();
 	private       Map<String, Map<String, String>> groupAttrs = Collections.emptyMap();
@@ -128,25 +133,37 @@ public final class RangerRequestScriptEvaluator {
 
 
 	public static boolean needsJsonCtxEnabled(String script) {
-		Matcher matcher = JSON_VAR_NAMES_PATTERN.matcher(script);
+		boolean ret = false;
 
-		boolean ret = matcher.find();
+		if (script != null) {
+			Matcher matcher = JSON_VAR_NAMES_PATTERN.matcher(script);
+
+			ret = matcher.find();
+		}
 
 		return ret;
 	}
 
 	public static boolean hasUserAttributeReference(String script) {
-		Matcher matcher = USER_ATTRIBUTES_PATTERN.matcher(script);
+		boolean ret = false;
 
-		boolean ret = matcher.find();
+		if (script != null) {
+			Matcher matcher = USER_ATTRIBUTES_PATTERN.matcher(script);
+
+			ret = matcher.find();
+		}
 
 		return ret;
 	}
 
 	public static boolean hasGroupAttributeReference(String script) {
-		Matcher matcher = GROUP_ATTRIBUTES_PATTERN.matcher(script);
+		boolean ret = false;
 
-		boolean ret = matcher.find();
+		if (script != null) {
+			Matcher matcher = GROUP_ATTRIBUTES_PATTERN.matcher(script);
+
+			ret = matcher.find();
+		}
 
 		return ret;
 	}
@@ -175,20 +192,47 @@ public final class RangerRequestScriptEvaluator {
 		return MACRO_PROCESSOR.expandMacros(script);
 	}
 
-	public RangerRequestScriptEvaluator(final RangerAccessRequest accessRequest) {
+	public RangerRequestScriptEvaluator(RangerAccessRequest accessRequest, ScriptEngine scriptEngine) {
+		this(accessRequest, scriptEngine, true);
+	}
+
+	public RangerRequestScriptEvaluator(RangerAccessRequest accessRequest, ScriptEngine scriptEngine, boolean enableJsonCtx) {
 		this.accessRequest = accessRequest.getReadOnlyCopy();
+		this.scriptEngine  = scriptEngine;
+		this.bindings      = scriptEngine.createBindings();
+
+		RangerTagForEval    currentTag = this.getCurrentTag();
+		Map<String, String> tagAttribs = currentTag != null ? currentTag.getAttributes() : Collections.emptyMap();
+
+		bindings.put(SCRIPT_VAR_ctx, this);
+		bindings.put(SCRIPT_VAR_tag, currentTag);
+		bindings.put(SCRIPT_VAR_tagAttr, tagAttribs);
+
+		String preExecScript = "";
+
+		if (enableJsonCtx) {
+			bindings.put(SCRIPT_VAR__CTX_JSON, this.toJson());
+
+			preExecScript += SCRIPT_PREEXEC;
+		}
+
+		if (StringUtils.isNotBlank(preExecScript)) {
+			try {
+				scriptEngine.eval(preExecScript, bindings);
+			} catch (ScriptException excp) {
+				LOG.error("RangerRequestScriptEvaluator(): initialization failed", excp);
+			}
+		}
 	}
 
-	public Object evaluateScript(ScriptEngine scriptEngine, String script) {
+	public Object evaluateScript(String script) {
 		script = expandMacros(script);
 
-		return evaluateScript(scriptEngine, script, needsJsonCtxEnabled(script));
+		return evaluateScriptImpl(script);
 	}
 
-	public Object evaluateConditionScript(ScriptEngine scriptEngine, String script, boolean enableJsonCtx) {
-		script = expandMacros(script);
-
-		Object ret = evaluateScript(scriptEngine, script, enableJsonCtx);
+	public Object evaluateConditionScript(String script) {
+		Object ret = evaluateScript(script);
 
 		if (ret == null) {
 			ret = getResult();
@@ -201,42 +245,36 @@ public final class RangerRequestScriptEvaluator {
 		return ret;
 	}
 
-	private Object evaluateScript(ScriptEngine scriptEngine, String script, boolean enableJsonCtx) {
-		Object              ret        = null;
-		Bindings            bindings   = scriptEngine.createBindings();
-		RangerTagForEval    currentTag = this.getCurrentTag();
-		Map<String, String> tagAttribs = currentTag != null ? currentTag.getAttributes() : Collections.emptyMap();
-
-		bindings.put(SCRIPT_VAR_ctx, this);
-		bindings.put(SCRIPT_VAR_tag, currentTag);
-		bindings.put(SCRIPT_VAR_tagAttr, tagAttribs);
-
-		if (enableJsonCtx) {
-			bindings.put(SCRIPT_VAR__CTX_JSON, this.toJson());
-
-			script = SCRIPT_PREEXEC + script;
-		}
-
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("RangerRequestScriptEvaluator.evaluateScript(): script={" + script + "}");
-		}
-
+	private Object evaluateScriptImpl(String script) {
+		Object           ret  = null;
 		RangerPerfTracer perf = null;
 
 		try {
-			long requestHash = accessRequest.hashCode();
-
 			if (RangerPerfTracer.isPerfTraceEnabled(PERF_POLICY_CONDITION_SCRIPT_EVAL)) {
-				perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_CONDITION_SCRIPT_EVAL, "RangerRequestScriptEvaluator.evaluateScript(requestHash=" + requestHash + ")");
+				perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_CONDITION_SCRIPT_EVAL, "RangerRequestScriptEvaluator.evaluateScript(requestHash=" + accessRequest.hashCode() + ")");
 			}
 
-			ret = scriptEngine.eval(script, bindings);
+			String preExec = SCRIPT_SAFE_PREEXEC;
+
+			if (script.contains(".includes(")) {
+				preExec += SCRIPT_POLYFILL_INCLUDES;
+			}
+
+			if (script.contains(".intersects(")) {
+				preExec += SCRIPT_POLYFILL_INTERSECTS;
+			}
+
+			if (JavaScriptEdits.hasDoubleBrackets(script)) {
+				script = JavaScriptEdits.replaceDoubleBrackets(script);
+			}
+
+			ret = scriptEngine.eval(preExec + script, bindings);
 		} catch (NullPointerException nullp) {
 			LOG.error("RangerRequestScriptEvaluator.evaluateScript(): eval called with NULL argument(s)", nullp);
-
-		} catch (ScriptException exception) {
-			LOG.error("RangerRequestScriptEvaluator.evaluateScript(): failed to evaluate script," +
-					" exception=" + exception);
+		} catch (ScriptException excp) {
+			LOG.error("RangerRequestScriptEvaluator.evaluateScript(): failed to evaluate script", excp);
+		} catch (Throwable t) {
+			LOG.error("RangerRequestScriptEvaluator.evaluateScript(): failed to evaluate script", t);
 		} finally {
 			RangerPerfTracer.log(perf);
 		}
@@ -247,10 +285,8 @@ public final class RangerRequestScriptEvaluator {
 	private String toJson() {
 		RangerPerfTracer perf = null;
 
-		long requestHash = accessRequest.hashCode();
-
 		if (RangerPerfTracer.isPerfTraceEnabled(PERF_POLICY_CONDITION_SCRIPT_TOJSON)) {
-			perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_CONDITION_SCRIPT_TOJSON, "RangerRequestScriptEvaluator.toJson(requestHash=" + requestHash + ")");
+			perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_CONDITION_SCRIPT_TOJSON, "RangerRequestScriptEvaluator.toJson(requestHash=" + accessRequest.hashCode() + ")");
 		}
 
 		Map<String, Object> ret        = new HashMap<>();
@@ -339,6 +375,18 @@ public final class RangerRequestScriptEvaluator {
 		return ret;
 	}
 
+	public String getResourceZone() {
+		String ret = RangerAccessRequestUtil.getResourceZoneNameFromContext(getRequestContext());
+
+		return ret != null ? ret : StringUtils.EMPTY;
+	}
+
+	public Set<String> getResourceZones() {
+		Set<String> ret = RangerAccessRequestUtil.getResourceZoneNamesFromContext(getRequestContext());
+
+		return ret != null ? Collections.emptySet() : ret;
+	}
+
 	public String getRequestContextAttribute(String attributeName) {
 		String ret = null;
 
@@ -361,7 +409,9 @@ public final class RangerRequestScriptEvaluator {
 
 	public Set<String> getUserGroups() { return accessRequest.getUserGroups(); }
 
-	public Set<String> getUserRoles() { return accessRequest.getUserRoles(); }
+	public Set<String> getUserRoles() {
+		return RangerAccessRequestUtil.getUserRoles(accessRequest);
+	}
 
 	public Date getAccessTime() { return accessRequest.getAccessTime() != null ? accessRequest.getAccessTime() : new Date(); }
 
@@ -615,98 +665,116 @@ public final class RangerRequestScriptEvaluator {
 		return ret;
 	}
 
-	public String ugNamesCsv() {
+	public String tagNames(Object... args) {
 		init();
 
-		return toCsv(userGroups);
+		return toCsv(tagNames, args);
 	}
 
-	public String ugNamesCsvQ() {
+	public String tagNamesQ(Object... args) {
 		init();
 
-		return toCsvQ(userGroups);
+		return toCsvQ(tagNames, args);
 	}
 
-	public String urNamesCsv() {
+	public String tagAttrNames(Object... args) {
 		init();
 
-		return toCsv(userRoles);
+		return toCsv(getTagAttrNames(), args);
 	}
 
-	public String urNamesCsvQ() {
+	public String tagAttrNamesQ(Object... args) {
 		init();
 
-		return toCsvQ(userRoles);
+		return toCsvQ(getTagAttrNames(), args);
 	}
 
-	public String tagNamesCsv() {
+	public String tagAttr(String attrName, Object... args) {
 		init();
 
-		return toCsv(tagNames);
+		return toCsv(getTagAttr(attrName), args);
 	}
 
-	public String tagNamesCsvQ() {
+	public String tagAttrQ(String attrName, Object... args) {
 		init();
 
-		return toCsvQ(tagNames);
+		return toCsvQ(getTagAttr(attrName), args);
 	}
 
-	public String userAttrNamesCsv() {
+	public String ugNames(Object... args) {
 		init();
 
-		return toCsv(getUserAttrNames());
+		return toCsv(userGroups, args);
 	}
 
-	public String userAttrNamesCsvQ() {
+	public String ugNamesQ(Object... args) {
 		init();
 
-		return toCsvQ(getUserAttrNames());
+		return toCsvQ(userGroups, args);
 	}
 
-	public String ugAttrNamesCsv() {
+	public String ugAttrNames(Object... args) {
 		init();
 
-		return toCsv(getUgAttrNames());
+		return toCsv(getUgAttrNames(), args);
 	}
 
-	public String ugAttrNamesCsvQ() {
-		return toCsvQ(getUgAttrNames());
-	}
-
-	public String tagAttrNamesCsv() {
+	public String ugAttrNamesQ(Object... args) {
 		init();
 
-		return toCsv(getTagAttrNames());
+		return toCsvQ(getUgAttrNames(), args);
 	}
 
-	public String tagAttrNamesCsvQ() {
+	public String ugAttr(String attrName, Object... args) {
 		init();
 
-		return toCsvQ(getTagAttrNames());
+		return toCsv(getUgAttr(attrName), args);
 	}
 
-	public String ugAttrCsv(String attrName) {
+	public String ugAttrQ(String attrName, Object... args) {
 		init();
 
-		return toCsv(getUgAttr(attrName));
+		return toCsvQ(getUgAttr(attrName), args);
 	}
 
-	public String ugAttrCsvQ(String attrName) {
+	public String urNames(Object... args) {
 		init();
 
-		return toCsvQ(getUgAttr(attrName));
+		return toCsv(userRoles, args);
 	}
 
-	public String tagAttrCsv(String attrName) {
+	public String urNamesQ(Object... args) {
 		init();
 
-		return toCsv(getTagAttr(attrName));
+		return toCsvQ(userRoles, args);
 	}
 
-	public String tagAttrCsvQ(String attrName) {
+	public String userAttrNames(Object... args) {
 		init();
 
-		return toCsvQ(getTagAttr(attrName));
+		return toCsv(getUserAttrNames(), args);
+	}
+
+	public String userAttrNamesQ(Object... args) {
+		init();
+
+		return toCsvQ(getUserAttrNames(), args);
+	}
+
+	public String userAttr(String attrName, Object... args) {
+		init();
+
+		String attrVal = userAttrs.get(attrName);
+
+		return toCsv(Collections.singletonList(attrVal), args);
+	}
+
+	public String userAttrQ(String attrName, Object... args) {
+		init();
+
+		String attrVal = userAttrs.get(attrName);
+
+		return toCsvQ(Collections.singletonList(attrVal), args);
 	}
 
 	public boolean hasTag(String tagName) {
@@ -786,6 +854,97 @@ public final class RangerRequestScriptEvaluator {
 		return !userRoles.isEmpty();
 	}
 
+	public boolean isAccessTimeAfter(String strTime) {
+		return isAccessTimeBetween(strTime, null, null);
+	}
+
+	public boolean isAccessTimeAfter(String strTime, String timeZone) {
+		return isAccessTimeBetween(strTime, null, timeZone);
+	}
+
+	public boolean isAccessTimeBefore(String strTime) {
+		return isAccessTimeBetween(null, strTime, null);
+	}
+
+	public boolean isAccessTimeBefore(String strTime, String timeZone) {
+		return isAccessTimeBetween(null, strTime, timeZone);
+	}
+
+	public boolean isAccessTimeBetween(String fromTime, String toTime) {
+		return isAccessTimeBetween(fromTime, toTime, null);
+	}
+
+	public boolean isAccessTimeBetween(String fromTime, String toTime, String timeZone) {
+		RangerTimeRangeChecker evaluator = new RangerTimeRangeChecker(fromTime, toTime, timeZone);
+
+		return evaluator.isInRange(getAccessTime().getTime());
+	}
+
+	// for backward compatibility
+	public String ugNamesCsv() {
+		return ugNames(null, STR_COMMA);
+	}
+
+	public String ugNamesCsvQ() {
+		return ugNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String urNamesCsv() {
+		return urNames(null, STR_COMMA);
+	}
+
+	public String urNamesCsvQ() {
+		return urNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String tagNamesCsv() {
+		return tagNames(null, STR_COMMA);
+	}
+
+	public String tagNamesCsvQ() {
+		return tagNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String userAttrNamesCsv() {
+		return userAttrNames(null, STR_COMMA);
+	}
+
+	public String userAttrNamesCsvQ() {
+		return userAttrNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String ugAttrNamesCsv() {
+		return ugAttrNames(null, STR_COMMA);
+	}
+
+	public String ugAttrNamesCsvQ() {
+		return ugAttrNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String tagAttrNamesCsv() {
+		return tagAttrNames(null, STR_COMMA);
+	}
+
+	public String tagAttrNamesCsvQ() {
+		return tagAttrNamesQ(null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String ugAttrCsv(String attrName) {
+		return ugAttr(attrName, null, STR_COMMA);
+	}
+
+	public String ugAttrCsvQ(String attrName) {
+		return ugAttrQ(attrName, null, STR_COMMA, STR_QUOTE);
+	}
+
+	public String tagAttrCsv(String attrName) {
+		return tagAttr(attrName, null, STR_COMMA);
+	}
+
+	public String tagAttrCsvQ(String attrName) {
+		return tagAttrQ(attrName, null, STR_COMMA, STR_QUOTE);
+	}
+
 	private void init() {
 		if (!initDone) {
 			RangerUserStore                  userStore        = RangerAccessRequestUtil.getRequestUserStoreFromContext(accessRequest.getContext());
@@ -947,8 +1106,9 @@ public final class RangerRequestScriptEvaluator {
 		return getSorted(ret);
 	}
 
-	private String toCsv(Collection<? extends Object> values) {
-		StringBuilder sb = new StringBuilder();
+	private String toCsv(Collection<? extends Object> values, Object[] args) {
+		StringBuilder sb        = new StringBuilder();
+		String        separator = getSeparator(args);
 
 		for (Object value : values) {
 			if (value == null) {
@@ -956,17 +1116,28 @@ public final class RangerRequestScriptEvaluator {
 			}
 
 			if (sb.length() > 0) {
-				sb.append(CHAR_COMMA);
+				sb.append(separator);
 			}
 
 			sb.append(value);
 		}
 
+		if (sb.length() == 0) {
+			String defValue = getDefaultValue(args);
+
+			if (defValue != null) {
+				sb.append(getDefaultValue(args));
+			}
+		}
+
 		return sb.toString();
 	}
 
-	private String toCsvQ(Collection<? extends Object> values) {
-		StringBuilder sb = new StringBuilder();
+	private String toCsvQ(Collection<? extends Object> values, Object[] args) {
+		StringBuilder sb         = new StringBuilder();
+		String        openQuote  = getOpenQuote(args);
+		String        closeQuote = getCloseQuote(args, openQuote);
+		String        separator  = getSeparator(args);
 
 		for (Object value : values) {
 			if (value == null) {
@@ -974,15 +1145,47 @@ public final class RangerRequestScriptEvaluator {
 			}
 
 			if (sb.length() > 0) {
-				sb.append(CHAR_COMMA);
+				sb.append(separator);
 			}
 
-			sb.append(CHAR_QUOTE).append(value).append(CHAR_QUOTE);
+			sb.append(openQuote).append(value).append(closeQuote);
+		}
+
+		if (sb.length() == 0) {
+			String defValue = getDefaultValue(args);
+
+			if (defValue != null) {
+				sb.append(openQuote).append(getDefaultValue(args)).append(closeQuote);
+			}
 		}
 
 		return sb.toString();
 	}
 
+	private String getDefaultValue(Object[] args) {
+		Object ret = (args != null && args.length > 0) ? args[0] : null;
+
+		return ret != null ? ret.toString() : null;
+	}
+
+	private String getSeparator(Object[] args) {
+		Object ret = (args != null && args.length > 1) ? args[1] : STR_COMMA;
+
+		return ret != null ? ret.toString() : "";
+	}
+
+	private String getOpenQuote(Object[] args) {
+		Object ret = (args != null && args.length > 2) ? args[2] : STR_QUOTE;
+
+		return ret != null ? ret.toString() : "";
+	}
+
+	private String getCloseQuote(Object[] args, String openQuote) {
+		Object ret = (args != null && args.length > 3) ? args[3] : null;
+
+		return ret != null ? ret.toString() : openQuote;
+	}
+
 	private static String getJsonVarNamesPattern() {
 		List<String> varNames = new ArrayList<>();
 
@@ -1012,10 +1215,21 @@ public final class RangerRequestScriptEvaluator {
 		List<String> varNames = new ArrayList<>();
 
 		varNames.add(SCRIPT_VAR_USER);
+
+		varNames.add(SCRIPT_MACRO_GET_USER_ATTR);
+		varNames.add(SCRIPT_MACRO_GET_USER_ATTR_Q);
+
+		varNames.add(SCRIPT_MACRO_GET_USER_ATTR_NAMES);
+		varNames.add(SCRIPT_MACRO_GET_USER_ATTR_NAMES_Q);
 		varNames.add(SCRIPT_MACRO_USER_ATTR_NAMES_CSV);
 		varNames.add(SCRIPT_MACRO_USER_ATTR_NAMES_Q_CSV);
+
 		varNames.add(SCRIPT_MACRO_HAS_USER_ATTR);
 
+		varNames.add("userAttr");
+		varNames.add("userAttrQ");
+		varNames.add("userAttrNames");
+		varNames.add("userAttrNamesQ");
 		varNames.add("userAttrNamesCsv");
 		varNames.add("userAttrNamesCsvQ");
 		varNames.add("hasUserAttr");
@@ -1029,16 +1243,28 @@ public final class RangerRequestScriptEvaluator {
 		varNames.add(SCRIPT_VAR_UG);
 		varNames.add(SCRIPT_VAR_UGA);
 
+		varNames.add(SCRIPT_MACRO_GET_UG_ATTR);
+		varNames.add(SCRIPT_MACRO_GET_UG_ATTR_Q);
 		varNames.add(SCRIPT_MACRO_GET_UG_ATTR_CSV);
 		varNames.add(SCRIPT_MACRO_GET_UG_ATTR_Q_CSV);
+
+		varNames.add(SCRIPT_MACRO_GET_UG_ATTR_NAMES);
+		varNames.add(SCRIPT_MACRO_GET_UG_ATTR_NAMES_Q);
 		varNames.add(SCRIPT_MACRO_UG_ATTR_NAMES_CSV);
 		varNames.add(SCRIPT_MACRO_UG_ATTR_NAMES_Q_CSV);
+
 		varNames.add(SCRIPT_MACRO_HAS_UG_ATTR);
 
+		varNames.add("ugAttr");
+		varNames.add("ugAttrQ");
 		varNames.add("ugAttrCsv");
 		varNames.add("ugAttrCsvQ");
+
+		varNames.add("ugAttrNames");
+		varNames.add("ugAttrNamesQ");
 		varNames.add("ugAttrNamesCsv");
 		varNames.add("ugAttrNamesCsvQ");
+
 		varNames.add("hasUgAttr");
 
 		return "\\b(" + StringUtils.join(varNames, '|') + ")\\b";
@@ -1047,6 +1273,25 @@ public final class RangerRequestScriptEvaluator {
 	private static Map<String, String> getMacrosMap() {
 		Map<String, String> ret = new HashMap<>();
 
+		ret.put(SCRIPT_MACRO_GET_TAG_NAMES,         "ctx.tagNames");
+		ret.put(SCRIPT_MACRO_GET_TAG_NAMES_Q,       "ctx.tagNamesQ");
+		ret.put(SCRIPT_MACRO_GET_TAG_ATTR_NAMES,    "ctx.tagAttrNames");
+		ret.put(SCRIPT_MACRO_GET_TAG_ATTR_NAMES_Q,  "ctx.tagAttrNamesQ");
+		ret.put(SCRIPT_MACRO_GET_TAG_ATTR,          "ctx.tagAttr");
+		ret.put(SCRIPT_MACRO_GET_TAG_ATTR_Q,        "ctx.tagAttrQ");
+		ret.put(SCRIPT_MACRO_GET_UG_NAMES,          "ctx.ugNames");
+		ret.put(SCRIPT_MACRO_GET_UG_NAMES_Q,        "ctx.ugNamesQ");
+		ret.put(SCRIPT_MACRO_GET_UG_ATTR_NAMES,     "ctx.ugAttrNames");
+		ret.put(SCRIPT_MACRO_GET_UG_ATTR_NAMES_Q,   "ctx.ugAttrNamesQ");
+		ret.put(SCRIPT_MACRO_GET_UG_ATTR,           "ctx.ugAttr");
+		ret.put(SCRIPT_MACRO_GET_UG_ATTR_Q,         "ctx.ugAttrQ");
+		ret.put(SCRIPT_MACRO_GET_UR_NAMES,          "ctx.urNames");
+		ret.put(SCRIPT_MACRO_GET_UR_NAMES_Q,        "ctx.urNamesQ");
+		ret.put(SCRIPT_MACRO_GET_USER_ATTR_NAMES,   "ctx.userAttrNames");
+		ret.put(SCRIPT_MACRO_GET_USER_ATTR_NAMES_Q, "ctx.userAttrNamesQ");
+		ret.put(SCRIPT_MACRO_GET_USER_ATTR,         "ctx.userAttr");
+		ret.put(SCRIPT_MACRO_GET_USER_ATTR_Q,       "ctx.userAttrQ");
+
 		ret.put(SCRIPT_MACRO_GET_TAG_ATTR_CSV,      "ctx.tagAttrCsv");
 		ret.put(SCRIPT_MACRO_GET_TAG_ATTR_Q_CSV,    "ctx.tagAttrCsvQ");
 		ret.put(SCRIPT_MACRO_GET_UG_ATTR_CSV,       "ctx.ugAttrCsv");
@@ -1075,6 +1320,9 @@ public final class RangerRequestScriptEvaluator {
 		ret.put(SCRIPT_MACRO_IS_IN_ANY_ROLE,        "ctx.isInAnyRole()");
 		ret.put(SCRIPT_MACRO_IS_NOT_IN_ANY_GROUP,   "!ctx.isInAnyGroup()");
 		ret.put(SCRIPT_MACRO_IS_NOT_IN_ANY_ROLE,    "!ctx.isInAnyRole()");
+		ret.put(SCRIPT_MACRO_IS_ACCESS_TIME_AFTER,   "ctx.isAccessTimeAfter");
+		ret.put(SCRIPT_MACRO_IS_ACCESS_TIME_BEFORE,  "ctx.isAccessTimeBefore");
+		ret.put(SCRIPT_MACRO_IS_ACCESS_TIME_BETWEEN, "ctx.isAccessTimeBetween");
 
 		return ret;
 	}
