@@ -24,13 +24,10 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemDataMaskInfo;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemRowFilterInfo;
 
-import org.codehaus.jackson.annotate.JsonAutoDetect;
-import org.codehaus.jackson.annotate.JsonIgnoreProperties;
-import org.codehaus.jackson.map.annotate.JsonSerialize;
+import com.fasterxml.jackson.annotation.JsonAutoDetect;
+import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
+import com.fasterxml.jackson.annotation.JsonInclude;
 
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlRootElement;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -165,6 +162,28 @@ public class RangerResourceACLs {
 		}
 	}
 
+	@Override
+	public int hashCode() {
+		return Objects.hash(userACLs, groupACLs, roleACLs, rowFilters, dataMasks);
+	}
+
+	@Override
+	public boolean equals(Object obj) {
+		if (this == obj) {
+			return true;
+		} else if (obj == null || !getClass().equals(obj.getClass())) {
+			return false;
+		} else {
+			RangerResourceACLs other = (RangerResourceACLs) obj;
+
+			return Objects.equals(userACLs, other.userACLs) &&
+					Objects.equals(groupACLs, other.groupACLs) &&
+					Objects.equals(roleACLs, other.roleACLs) &&
+					Objects.equals(rowFilters, other.rowFilters) &&
+					Objects.equals(dataMasks, other.dataMasks);
+		}
+	}
+
 	@Override
 	public String toString() {
 		StringBuilder sb = new StringBuilder();
@@ -244,10 +263,8 @@ public class RangerResourceACLs {
 	}
 
 	@JsonAutoDetect(fieldVisibility=JsonAutoDetect.Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class AccessResult {
 		private int     result;
 		private boolean isFinal;
@@ -315,10 +332,8 @@ public class RangerResourceACLs {
 	}
 
 	@JsonAutoDetect(fieldVisibility=JsonAutoDetect.Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class DataMaskResult implements Serializable {
 		private static final long serialVersionUID = 1L;
 
@@ -432,10 +447,8 @@ public class RangerResourceACLs {
 	}
 
 	@JsonAutoDetect(fieldVisibility=JsonAutoDetect.Visibility.ANY)
-	@JsonSerialize(include=JsonSerialize.Inclusion.NON_EMPTY)
+	@JsonInclude(JsonInclude.Include.NON_EMPTY)
 	@JsonIgnoreProperties(ignoreUnknown=true)
-	@XmlRootElement
-	@XmlAccessorType(XmlAccessType.FIELD)
 	public static class RowFilterResult implements Serializable {
 		private static final long serialVersionUID = 1L;
 
