@@ -22,7 +22,7 @@ package org.apache.ranger.plugin.policyengine;
 
 import org.apache.ranger.plugin.model.RangerServiceDef;
 
-class RangerTagResource extends RangerAccessResourceImpl {
+public class RangerTagResource extends RangerAccessResourceImpl {
 	private static final String KEY_TAG = "tag";
 
 
@@ -30,4 +30,10 @@ class RangerTagResource extends RangerAccessResourceImpl {
 		super.setValue(KEY_TAG, tagType);
 		super.setServiceDef(tagServiceDef);
 	}
+
+	public RangerTagResource(String tagType, RangerServiceDef tagServiceDef, String ownerUser) {
+		super.setValue(KEY_TAG, tagType);
+		super.setServiceDef(tagServiceDef);
+		super.setOwnerUser(ownerUser);
+	}
 }
