@@ -232,9 +232,9 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 					final boolean                                   isMatched;
 
 					if (request.isAccessTypeAny() || resourceMatchingScope == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
+						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT || (matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR && request instanceof RangerTagAccessRequest);
 					} else {
-						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS;
+						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || (matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR && request instanceof RangerTagAccessRequest);
 					}
 
 					if (isMatched) {
@@ -864,8 +864,12 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 							if (getPolicyPriority() >= oldPriority && allowResult != null && (oneRequest.isAccessTypeAny() || RangerAccessRequestUtil.getIsAnyAccessInContext(oneRequest.getContext()))) {
 								accessTypeResults.put(accessType, allowResult);
 							} else {
-								if (getPolicyPriority() > oldPriority && denyResult != null) {
-									accessTypeResults.put(accessType, denyResult);
+								if (getPolicyPriority() > oldPriority) {
+									if (allowResult != null) {
+										accessTypeResults.put(accessType, allowResult);
+									} else if (denyResult != null) {
+										accessTypeResults.put(accessType, denyResult);
+									}
 								}
 							}
 						}
