@@ -209,14 +209,19 @@ public class RangerURLResourceMatcher extends RangerDefaultResourceMatcher {
     }
 
     static boolean isPathURLType(String url) {
+        boolean ret = false;
 
-        Pattern p1 = Pattern.compile(":/{2}");
-        Matcher m1 = p1.matcher(url);
+        if (url != null) {
+            Pattern p1 = Pattern.compile(":/{2}");
+            Matcher m1 = p1.matcher(url);
 
-        Pattern p2 = Pattern.compile(":/{3,}");
-        Matcher m2 = p2.matcher(url);
+            Pattern p2 = Pattern.compile(":/{3,}");
+            Matcher m2 = p2.matcher(url);
 
-        return (m1.find() && !(m2.find()));
+            ret = (m1.find() && !(m2.find()));
+        }
+
+        return ret;
     }
 
 
@@ -229,7 +234,7 @@ public class RangerURLResourceMatcher extends RangerDefaultResourceMatcher {
     }
 }
 
-final class CaseSensitiveURLRecursiveWildcardMatcher extends ResourceMatcher {
+final class CaseSensitiveURLRecursiveWildcardMatcher extends AbstractStringResourceMatcher {
     private final char levelSeparatorChar;
     CaseSensitiveURLRecursiveWildcardMatcher(String value, Map<String, String> options, char levelSeparatorChar) {
         super(value, options);
@@ -240,10 +245,16 @@ final class CaseSensitiveURLRecursiveWildcardMatcher extends ResourceMatcher {
     boolean isMatch(String resourceValue, Map<String, Object> evalContext) {
         return RangerURLResourceMatcher.isRecursiveWildCardMatch(resourceValue, getExpandedValue(evalContext), levelSeparatorChar, IOCase.SENSITIVE);
     }
+
+    @Override
+    public boolean isPrefixMatch(String resourceValue, Map<String, Object> evalContext) {
+        return ResourceMatcher.wildcardPrefixMatch(resourceValue, getExpandedValue(evalContext), IOCase.SENSITIVE);
+    }
+
     int getPriority() { return 7 + (getNeedsDynamicEval() ? DYNAMIC_EVALUATION_PENALTY : 0);}
 }
 
-final class CaseInsensitiveURLRecursiveWildcardMatcher extends ResourceMatcher {
+final class CaseInsensitiveURLRecursiveWildcardMatcher extends AbstractStringResourceMatcher {
     private final char levelSeparatorChar;
     CaseInsensitiveURLRecursiveWildcardMatcher(String value, Map<String, String> options, char levelSeparatorChar) {
         super(value, options);
@@ -254,11 +265,17 @@ final class CaseInsensitiveURLRecursiveWildcardMatcher extends ResourceMatcher {
     boolean isMatch(String resourceValue, Map<String, Object> evalContext) {
         return RangerURLResourceMatcher.isRecursiveWildCardMatch(resourceValue, getExpandedValue(evalContext), levelSeparatorChar, IOCase.INSENSITIVE);
     }
+
+    @Override
+    public boolean isPrefixMatch(String resourceValue, Map<String, Object> evalContext) {
+        return ResourceMatcher.wildcardPrefixMatch(resourceValue, getExpandedValue(evalContext), IOCase.INSENSITIVE);
+    }
+
     int getPriority() { return 8 + (getNeedsDynamicEval() ? DYNAMIC_EVALUATION_PENALTY : 0);}
 
 }
 
-abstract class RecursiveMatcher extends ResourceMatcher {
+abstract class RecursiveMatcher extends AbstractStringResourceMatcher {
     final char levelSeparatorChar;
     String valueWithoutSeparator;
     String valueWithSeparator;
@@ -306,6 +323,12 @@ final class CaseSensitiveURLRecursiveMatcher extends RecursiveMatcher {
 
         return ret;
     }
+
+    @Override
+    public boolean isPrefixMatch(String resourceValue, Map<String, Object> evalContext) {
+        return StringUtils.startsWith(getExpandedValue(evalContext), resourceValue);
+    }
+
     int getPriority() { return 7 + (getNeedsDynamicEval() ? DYNAMIC_EVALUATION_PENALTY : 0);}
 }
 
@@ -339,5 +362,10 @@ final class CaseInsensitiveURLRecursiveMatcher extends RecursiveMatcher {
         return ret;
     }
 
+    @Override
+    public boolean isPrefixMatch(String resourceValue, Map<String, Object> evalContext) {
+        return StringUtils.startsWithIgnoreCase(getExpandedValue(evalContext), resourceValue);
+    }
+
     int getPriority() { return 8 + (getNeedsDynamicEval() ? DYNAMIC_EVALUATION_PENALTY : 0);}
 }
