@@ -514,7 +514,7 @@ public class RangerBasePlugin {
 			} else {
 				LOG.warn("Leaving current policy engine as-is");
 				LOG.warn("Policies are not saved to cache. policyVersion in the policy-cache may be different than in Ranger-admin, even though the policies are the same!");
-				LOG.warn("Ranger-PolicyVersion:[" + (policies != null ? policies.getPolicyVersion() : -1L) + "], Cached-PolicyVersion:[" + (this.policyEngine != null ? this.policyEngine.getPolicyVersion() : -1L) + "]");
+				LOG.warn("Ranger-PolicyVersion:[" + (policies != null ? policies.getPolicyVersion() : -1L) + "], Cached-PolicyVersion:[" + getPoliciesVersion() + "]");
 			}
 
 		} catch (Exception e) {
@@ -794,13 +794,11 @@ public class RangerBasePlugin {
 	}
 
 	public Set<RangerRole> getRangerRoleForPrincipal(String principal, String type) {
-		Set<RangerRole>  		 ret                 = new HashSet<>();
-		Set<RangerRole>			 rangerRoles		 = null;
-		Map<String, Set<String>> roleMapping         = null;
-		RangerRoles		 		 roles 		         = getRangerRoles();
-		if (roles != null) {
-			rangerRoles = roles.getRangerRoles();
-		}
+		Set<RangerRole>          ret          = new HashSet<>();
+		RangerPolicyEngine       policyEngine = this.policyEngine;
+		RangerRoles              roles        = policyEngine != null ? policyEngine.getRangerRoles() : null;
+		Set<RangerRole>          rangerRoles  = roles != null ? roles.getRangerRoles() : null;
+		Map<String, Set<String>> roleMapping  = null;
 
 		if (rangerRoles != null) {
 			RangerPluginContext rangerPluginContext = policyEngine.getPluginContext();
@@ -836,6 +834,7 @@ public class RangerBasePlugin {
 				}
 			}
 		}
+
 		return ret;
 	}
 
@@ -1042,18 +1041,14 @@ public class RangerBasePlugin {
 		}
 
 		try {
-			RangerPolicyEngine policyEngine = this.policyEngine;
+			long oldPolicyVersion = getPoliciesVersion();
 
 			// Synch-up policies
-			long oldPolicyVersion = policyEngine.getPolicyVersion();
-
 			if (refresher != null) {
 				refresher.syncPoliciesWithAdmin(accessTrigger);
 			}
 
-			policyEngine = this.policyEngine; // might be updated in syncPoliciesWithAdmin()
-
-			long newPolicyVersion = policyEngine.getPolicyVersion();
+			long newPolicyVersion = getPoliciesVersion();
 
 			if (oldPolicyVersion == newPolicyVersion) {
 				// Synch-up tags
@@ -1415,6 +1410,8 @@ public class RangerBasePlugin {
 	}
 
 	public Long getPolicyVersion() {
-		return this.policyEngine == null ? -1L : this.policyEngine.getPolicyVersion();
+		RangerPolicyEngine policyEngine = this.policyEngine;
+
+		return policyEngine == null ? -1L : policyEngine.getPolicyVersion();
 	}
 }
