@@ -44,6 +44,7 @@ import javax.net.ssl.SSLSession;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
 import javax.ws.rs.core.Cookie;
+import javax.ws.rs.core.Response;
 
 import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;
 import com.sun.jersey.api.client.filter.ClientFilter;
@@ -466,8 +467,8 @@ public class RangerRESTClient {
 			LOG.error("SSL algorithm is not available in the environment", e);
 			throw new IllegalStateException("SSL algorithm is not available in the environment: " + e.getMessage(), e);
 		} catch (KeyManagementException e) {
-			LOG.error("Unable to initials the SSLContext", e);
-			throw new IllegalStateException("Unable to initials the SSLContex: " + e.getMessage(), e);
+			LOG.error("Unable to initialize the SSLContext", e);
+			throw new IllegalStateException("Unable to initialize the SSLContext: " + e.getMessage(), e);
 		}
 	}
 
@@ -516,6 +517,10 @@ public class RangerRESTClient {
 				finalResponse = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).get(ClientResponse.class);
 
 				if (finalResponse != null) {
+					if (finalResponse.getStatusInfo().getFamily() == Response.Status.Family.SERVER_ERROR) {
+						throw new ClientHandlerException("Response status: " + finalResponse.getStatus());
+					}
+
 					setLastKnownActiveUrlIndex(currentIndex);
 					break;
 				}
@@ -544,6 +549,10 @@ public class RangerRESTClient {
 				finalResponse = br.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).get(ClientResponse.class);
 
 				if (finalResponse != null) {
+					if (finalResponse.getStatusInfo().getFamily() == Response.Status.Family.SERVER_ERROR) {
+						throw new ClientHandlerException("Response status: " + finalResponse.getStatus());
+					}
+
 					setLastKnownActiveUrlIndex(currentIndex);
 					break;
 				}
