@@ -62,7 +62,7 @@ public class RangerSslHelper {
 
 	static final String RANGER_SSL_KEYMANAGER_ALGO_TYPE                   = KeyManagerFactory.getDefaultAlgorithm();
 	static final String RANGER_SSL_TRUSTMANAGER_ALGO_TYPE                 = TrustManagerFactory.getDefaultAlgorithm();
-	static final String RANGER_SSL_CONTEXT_ALGO_TYPE                      = "TLS";
+	static final String RANGER_SSL_CONTEXT_ALGO_TYPE                      = "TLSv1.2";
 
 	private String mKeyStoreURL;
 	private String mKeyStoreAlias;
