@@ -21,12 +21,14 @@ package org.apache.ranger.plugin.util;
 
 
 import java.util.Date;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
 import java.util.HashMap;
 import java.util.ArrayList;
+import java.util.Set;
 
 import org.apache.commons.lang3.tuple.MutablePair;
 import org.apache.ranger.authorization.utils.StringUtil;
@@ -250,6 +252,7 @@ public class ServiceTags implements java.io.Serializable {
 		final Map<Long, Long> replacedIds      = new HashMap<>();
 		final int             initialTagsCount = tags.size();
 		final List<Long>      tagIdsToRemove   = new ArrayList<>();
+		final Map<Long, RangerTag> tagsToAdd   = new HashMap<>();
 
 		for (Iterator<Map.Entry<Long, RangerTag>> iter = tags.entrySet().iterator(); iter.hasNext(); ) {
 			Map.Entry<Long, RangerTag> entry       = iter.next();
@@ -266,6 +269,7 @@ public class ServiceTags implements java.io.Serializable {
 					cachedTag.left = tagId;
 				} else {
 					replacedIds.put(tagId, cachedTag.left);
+					tagsToAdd.put(cachedTag.left, tag);
 					iter.remove();
 				}
 			}
@@ -275,9 +279,13 @@ public class ServiceTags implements java.io.Serializable {
 			tags.remove(tagIdToRemove);
 		}
 
+		// Add all the tags whose tagIds are modified back to tags
+		tags.putAll(tagsToAdd);
+
 		final int finalTagsCount = tags.size();
 
 		for (Map.Entry<Long, List<Long>> resourceEntry : resourceToTagIds.entrySet()) {
+			Set<Long> uniqueTagIds = new HashSet<>(resourceEntry.getValue().size());
 			for (ListIterator<Long> listIter = resourceEntry.getValue().listIterator(); listIter.hasNext(); ) {
 				final Long tagId       = listIter.next();
 				Long       mappedTagId = null;
@@ -290,6 +298,11 @@ public class ServiceTags implements java.io.Serializable {
 					continue;
 				}
 
+				if (!uniqueTagIds.add(mappedTagId)) {
+					listIter.remove();
+					continue;
+				}
+
 				listIter.set(mappedTagId);
 
 				RangerTag tag = tags.get(mappedTagId);
