@@ -256,6 +256,13 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(hdfsTestResourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_hdfs_incremental_update_for_wildcard_evaluators() {
+		String[] hdfsTestResourceFiles = {"/policyengine/test_policyengine_hdfs_incremental_update_for_wildcard_evaluators.json"};
+
+		runTestsFromResourceFiles(hdfsTestResourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_hiveForTag() {
 		String[] hiveTestResourceFiles = { "/policyengine/test_policyengine_tag_hive.json" };
@@ -284,6 +291,13 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(hbaseTestResourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_hbaseForTag_filebased() {
+		String[] hbaseTestResourceFiles = { "/policyengine/test_policyengine_tag_hbase.json" };
+
+		runTestsFromResourceFiles(hbaseTestResourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_conditions() {
 		String[] conditionsTestResourceFiles = { "/policyengine/test_policyengine_conditions.json" };
@@ -631,10 +645,8 @@ public class TestPolicyEngine {
 	}
 
     private void runTestCaseTests(RangerPolicyEngine policyEngine, RangerServiceDef serviceDef, String testName, List<TestData> tests) {
-        RangerAccessRequest request = null;
-
-        for(TestData test : tests) {
-			request = test.request;
+        tests.parallelStream().forEach(test -> {
+			RangerAccessRequest request = test.request;
 
 			if (request.getContext().containsKey(RangerAccessRequestUtil.KEY_CONTEXT_TAGS) ||
 					request.getContext().containsKey(RangerAccessRequestUtil.KEY_CONTEXT_REQUESTED_RESOURCES)) {
@@ -765,8 +777,7 @@ public class TestPolicyEngine {
 				assertEquals("deniedUsers mismatched! - " + test.name, expected.getDeniedUsers(), result.getDeniedUsers());
 				assertEquals("deniedGroups mismatched! - " + test.name, expected.getDeniedGroups(), result.getDeniedGroups());
 			}
-		}
-
+		});
 	}
 
 	private void setPluginConfig(RangerPluginConfig conf, String suffix, Set<String> value) {
