@@ -54,27 +54,30 @@ images=`docker images | cut -f 1 -d " "`
 if [ $build_image -eq 1 ]; then
     echo "Creating image $image_name ..."
     docker rmi -f $image_name
-
-docker build -t $image_name - <<Dockerfile
-FROM centos
+    export MAVEN_MAJOR_VER=3
+    export MAVEN_VER=3.9.9
+    docker build -t $image_name - <<Dockerfile
+FROM ubuntu:22.04
 
 RUN mkdir /tools
 WORKDIR /tools
 
 #Install default services
 #RUN yum clean all
-RUN yum install -y wget
-RUN yum install -y git
-RUN yum install -y gcc
-RUN yum install -y bzip2 fontconfig
-RUN yum install -y diffutils
-RUN yum install -y python3
+RUN apt-get update
+RUN apt-get install -y wget
+RUN apt-get install -y git
+RUN apt-get install -y gcc
+RUN apt-get install -y bzip2 fontconfig
+RUN apt-get install -y diffutils
+RUN apt-get install -y python3
 
 RUN ln -s /usr/bin/python3 /usr/bin/python
 
-RUN yum install -y java-1.8.0-openjdk java-1.8.0-openjdk-devel
+#RUN apt-get install -y java-1.8.0-openjdk java-1.8.0-openjdk-devel
 #ENV JAVA_HOME /etc/alternatives/jre
-ENV JAVA_HOME /usr/lib/jvm/java-1.8.0-openjdk/
+RUN apt-get install -y openjdk-11-jdk 
+ENV JAVA_HOME  /usr/lib/jvm/java-11-openjdk-amd64 
 ENV PATH $JAVA_HOME/bin:$PATH
 
 #Download and install JDK8 from AWS s3's docker-assets 
@@ -84,42 +87,29 @@ ENV PATH $JAVA_HOME/bin:$PATH
 #ENV  PATH $JAVA_HOME/bin:$PATH
 
 
-ADD https://www.apache.org/dist/maven/maven-3/3.6.3/binaries/apache-maven-3.6.3-bin.tar.gz.sha512 /tools
-ADD http://www-us.apache.org/dist/maven/maven-3/3.6.3/binaries/apache-maven-3.6.3-bin.tar.gz /tools
-RUN sha512sum  apache-maven-3.6.3-bin.tar.gz | cut -f 1 -d " " > tmp.sha1
 
-RUN cat apache-maven-3.6.3-bin.tar.gz.sha512 | cut -f 1 -d " " > tmp.sha1.download
+ADD https://www.apache.org/dist/maven/maven-${MAVEN_MAJOR_VER}/${MAVEN_VER}/binaries/apache-maven-${MAVEN_VER}-bin.tar.gz.sha512 /tools
+ADD http://www.apache.org/dist/maven/maven-${MAVEN_MAJOR_VER}/${MAVEN_VER}/binaries/apache-maven-${MAVEN_VER}-bin.tar.gz /tools
+RUN sha512sum  apache-maven-${MAVEN_VER}-bin.tar.gz | cut -f 1 -d " " > tmp.sha1
+
+RUN cat apache-maven-${MAVEN_VER}-bin.tar.gz.sha512 | cut -f 1 -d " " > tmp.sha1.download
 
 RUN diff -w tmp.sha1 tmp.sha1.download
 
-RUN tar xfz apache-maven-3.6.3-bin.tar.gz
-RUN ln -sf /tools/apache-maven-3.6.3 /tools/maven
+RUN tar xfz apache-maven-${MAVEN_VER}-bin.tar.gz
+RUN ln -sf /tools/apache-maven-${MAVEN_VER} /tools/maven
 
 ENV  PATH /tools/maven/bin:$PATH
 ENV MAVEN_OPTS "-Xmx2048m -XX:MaxPermSize=512m"
 
 # Setup gosu for easier command execution
-RUN gpg --keyserver pool.sks-keyservers.net --recv-keys B42F6819007F00F88E364FD4036A9C25BF357DD4 \
-    && curl -o /usr/local/bin/gosu -SL "https://github.com/tianon/gosu/releases/download/1.10/gosu-amd64" \
-    && curl -o /usr/local/bin/gosu.asc -SL "https://github.com/tianon/gosu/releases/download/1.10/gosu-amd64.asc" \
-    && gpg --verify /usr/local/bin/gosu.asc \
-    && rm /usr/local/bin/gosu.asc \
-    && rm -r /root/.gnupg/ \
-    && chmod +x /usr/local/bin/gosu
-
 RUN useradd -ms /bin/bash builder
 RUN usermod -g root builder
 RUN mkdir -p /scripts
 
-RUN echo "#!/bin/bash" > /scripts/mvn.sh
-RUN echo 'set -x; if [ "\$1" = "mvn" ]; then usermod -u \$(stat -c "%u" pom.xml) builder; gosu builder bash -c '"'"'ln -sf /.m2 \$HOME'"'"'; exec gosu builder "\$@"; fi; exec "\$@" ' >> /scripts/mvn.sh
-
 RUN chmod -R 777 /scripts
 RUN chmod -R 777 /tools
-
-ENTRYPOINT ["/scripts/mvn.sh"]
 Dockerfile
-
 fi
 
 src_folder=`pwd`
