@@ -17,19 +17,19 @@
  */
 package org.apache.ranger.credentialapi;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.io.File;
 
 import org.apache.commons.io.FileUtils;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class TestCredentialReader {
     private String keystoreFile;
 
-    @Before
+    @BeforeEach
     public void setup() throws Exception {
         String basedir = System.getProperty("basedir");
         if (basedir == null) {
@@ -43,7 +43,7 @@ public class TestCredentialReader {
         assertEquals(0, rc2);
     }
 
-    @After
+    @AfterEach
     public void cleanup() throws Exception {
         FileUtils.deleteQuietly(new File(keystoreFile));
     }
