@@ -76,6 +76,7 @@ import org.apache.ranger.plugin.policyengine.RangerPolicyEngine;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
 import org.apache.ranger.plugin.service.RangerBasePlugin;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
+import org.apache.ranger.plugin.util.ServicePolicies;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -90,11 +91,11 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 	private static final String GROUP_PREFIX = "@";
 
 	private UserProvider userProvider;
-    private RegionCoprocessorEnvironment regionEnv;
+	private RegionCoprocessorEnvironment regionEnv;
 	private Map<InternalScanner, String> scannerOwners = new MapMaker().weakKeys().makeMap();
 	/** if we should check EXEC permissions */
 	private boolean shouldCheckExecPermission;
-	
+
 	/*
 	 * These are package level only for testability and aren't meant to be exposed outside via getters/setters or made available to derived classes.
 	 */
@@ -102,7 +103,17 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 	final HbaseUserUtils _userUtils = _factory.getUserUtils();
 	final HbaseAuthUtils _authUtils = _factory.getAuthUtils();
 	private static volatile RangerHBasePlugin hbasePlugin = null;
-	
+
+	public void setColumnAuthOptimizationEnabled(boolean enable) throws Exception {
+		RangerHBasePlugin plugin = hbasePlugin;
+		if (plugin!=null) {
+			plugin.setColumnAuthOptimizationEnabled(enable);
+		}
+		else {
+			throw new Exception("Error while enabling column auth optimization");
+		}
+	}
+
 	// Utilities Methods
 	protected byte[] getTableName(RegionCoprocessorEnvironment e) {
 		Region region = e.getRegion();
@@ -139,7 +150,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				return true;
 			}
 		}
-			
+
 		return false;
 	}
 	protected boolean isAccessForMetaTables(RegionCoprocessorEnvironment env) {
@@ -205,7 +216,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		return user;
 	}
 
-	
+
 	private String getRemoteAddress() {
 		InetAddress remoteAddr = null;
 		try {
@@ -237,7 +248,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
      String owner = scannerOwners.get(s);
      if (owner != null && !owner.equals(requestUserName)) {
        throw new AccessDeniedException("User '"+ requestUserName +"' is not the scanner owner!");
-     }	
+     }
 	}
 	/**
 	 * @param families
@@ -258,8 +269,16 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				Collection<?> columnCollection = anEntry.getValue();
 				if (CollectionUtils.isEmpty(columnCollection)) {
 					// family points to null map, OK.
+					// if column auth disabled, then also empty set is fine
+					if (LOG.isDebugEnabled()) {
+						LOG.debug("RangerAuthorizationCoprocessor getColumnFamilies: columns are empty. " +
+								"Setting columns to emptySet in familyMap");
+					}
 					result.put(family, Collections.<String> emptySet());
 				} else {
+					if (LOG.isDebugEnabled()) {
+						LOG.debug("RangerAuthorizationCoprocessor getColumnFamilies: columns exist");
+					}
 					Iterator<String> columnIterator = new ColumnIterator(columnCollection);
 					Set<String> columns = new HashSet<String>();
 					try {
@@ -278,7 +297,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		}
 		return result;
 	}
-	
+
 	static class ColumnFamilyAccessResult {
 		final boolean _everythingIsAccessible;
 		final boolean _somethingIsAccessible;
@@ -301,7 +320,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			// cached values of access results
 			_filter = filter;
 		}
-		
+
 		@Override
 		public String toString() {
 			return MoreObjects.toStringHelper(getClass())
@@ -313,12 +332,15 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 					.add("denialReason", _denialReason)
 					.add("filter", _filter)
 					.toString();
-			
+
 		}
 	}
-	
+
 	ColumnFamilyAccessResult evaluateAccess(ObserverContext<?> ctx, String operation, Action action, final RegionCoprocessorEnvironment env,
-											final Map<byte[], ? extends Collection<?>> familyMap, String commandStr) throws AccessDeniedException {
+			final Map<byte[], ? extends Collection<?>> familyMap, String commandStr) throws AccessDeniedException {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("evaluateAccess: isColumnAuthOptimizationEnabled="+hbasePlugin.getPropertyIsColumnAuthOptimizationEnabled());
+		}
 
 		String access = _authUtils.getAccess(action);
 		User user = getActiveUser(ctx);
@@ -393,7 +415,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		} else {
 			LOG.debug("evaluateAccess: Families collection not null.  Skipping table-level check, will do finer level check");
 		}
-		
+
 		boolean everythingIsAccessible = true;
 		boolean somethingIsAccessible = false;
 		/*
@@ -409,6 +431,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		Set<String> familesAccessAllowed = new HashSet<String>();
 		Set<String> familesAccessDenied = new HashSet<String>();
 		Set<String> familesAccessIndeterminate = new HashSet<String>();
+		Set<String> familiesFullyAuthorized = new HashSet<>();
 
 		for (Map.Entry<byte[], ? extends Collection<?>> anEntry : familyMap.entrySet()) {
 			String family = Bytes.toString(anEntry.getKey());
@@ -440,7 +463,10 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("evaluateAccess: family level access for [" + family + "] is evaluated to " + isColumnFamilyAuthorized + ". Checking if [" + family + "] descendants have access.");
 				}
+				// buildRequest again since resourceMatchingScope changed
+				// reset ResourceMatchingScope to SELF, ignoreDescendantDeny to true
 				session.resourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS)
+						.ignoreDescendantDeny(false)
 						.buildRequest()
 						.authorize();
 				auditEvent = auditHandler.getAndDiscardMostRecentEvent(); // capture it only for failure
@@ -488,8 +514,53 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				}
 				// Restore the headMatch setting
 				session.resourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF);
+				session.ignoreDescendantDeny(true);
 			} else {
-				LOG.debug("evaluateAccess: columns collection not empty.  Skipping Family level check, will do finer level access check.");
+				boolean isColumnAuthOptimizationEnabled = hbasePlugin.getPropertyIsColumnAuthOptimizationEnabled();
+				if(LOG.isDebugEnabled()) {
+					LOG.debug("evaluateAccess: columns collection not empty." +
+							" Skipping Family level check, will do finer level access check for columns.");
+				}
+				if (isColumnAuthOptimizationEnabled) {
+					session.column(null)
+							.buildRequest()
+							.authorize();
+					if (LOG.isDebugEnabled()) {
+						LOG.debug(
+								"evaluateAccess: isColumnAuthOptimizationEnabled={}, isColumnFamilyAuthorized={}",
+								isColumnAuthOptimizationEnabled, session.isAuthorized());
+					}
+					if(session.isAuthorized()) {
+
+						//check if column family fully authorized i.e. no deny for columns
+						session.column(null)
+								.resourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS)
+								.ignoreDescendantDeny(false)
+								.buildRequest()
+								.authorize();
+
+						boolean isColumnFamilyAndDescendantsAuthorized = session.isAuthorized();
+						AuthzAuditEvent auditEvent = auditHandler.getAndDiscardMostRecentEvent();
+						// reset ResourceMatchingScope to SELF, ignoreDescendantDeny to true
+						session.resourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF)
+								.ignoreDescendantDeny(true);
+						if (LOG.isDebugEnabled()) {
+							LOG.debug(
+									"evaluateAccess: isColumnAuthOptimizationEnabled={}, isColumnFamilyAndDescendantsAuthorized={}",
+									isColumnAuthOptimizationEnabled, isColumnFamilyAndDescendantsAuthorized);
+						}
+						if (isColumnFamilyAndDescendantsAuthorized) {
+							familiesFullyAuthorized.add(family);
+							if (auditEvent != null) {
+								if (LOG.isDebugEnabled()) {
+									LOG.debug("evaluateAccess: isColumnAuthOptimizationEnabled ={}, adding family {} to familiesFullyAuthorized", isColumnAuthOptimizationEnabled, family);
+								}
+								familyLevelAccessEvents.add(auditEvent);
+							}
+							continue;
+						}
+					}
+				}
 				Set<String> accessibleColumns = new HashSet<String>(); // will be used in to populate our results cache for the filter
 				Iterator<String> columnIterator = new ColumnIterator(columns);
 				while (columnIterator.hasNext()) {
@@ -497,6 +568,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 					 if (LOG.isDebugEnabled()) {
  						LOG.debug("evaluateAccess: Processing column: " + column);
  					}
+					//buildRequest required again since now column is being set
  					session.column(column)
  						.buildRequest()
  						.authorize();
@@ -531,7 +603,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			}
 		}
 		// Cache of auth results are encapsulated the in the filter. Not every caller of the function uses it - only preGet and preOpt will.
-		RangerAuthorizationFilter filter = new RangerAuthorizationFilter(session, familesAccessAllowed, familesAccessDenied, familesAccessIndeterminate, columnsAccessAllowed);
+		RangerAuthorizationFilter filter = new RangerAuthorizationFilter(session, familesAccessAllowed, familesAccessDenied, familesAccessIndeterminate, columnsAccessAllowed, familiesFullyAuthorized);
 		result = new ColumnFamilyAccessResult(everythingIsAccessible, somethingIsAccessible, authorizedEvents, familyLevelAccessEvents, deniedEvent, denialReason, filter);
 		if (LOG.isDebugEnabled()) {
 			String message = String.format(messageTemplate, userName, operation, access, colFamiliesForDebugLoggingOnly, result.toString());
@@ -575,7 +647,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			}
 		}
 	}
-	
+
 	Filter combineFilters(Filter filter, Filter existingFilter) {
 		Filter combinedFilter = filter;
 		if (existingFilter != null) {
@@ -609,7 +681,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			RangerPerfTracer.log(perf);
 		}
 	}
-	
+
 	/**
 	 * This could run s
 	 * @param operation
@@ -628,7 +700,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			String message = String.format(format, "Entering", operation, otherInformation, access, table, columnFamily, column);
 			LOG.debug(message);
 		}
-		
+
 		final String format =  "authorizeAccess: %s: Operation[%s], Info[%s], access[%s], table[%s], columnFamily[%s], column[%s], allowed[%s], reason[%s]";
 		if (canSkipAccessCheck(user, operation, access, table)) {
 			if (LOG.isDebugEnabled()) {
@@ -638,7 +710,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			return;
 		}
 
-		
+
 		HbaseAuditHandler auditHandler = _factory.getAuditHandler();
 		AuthorizationSession session = new AuthorizationSession(hbasePlugin)
 			.operation(operation)
@@ -652,20 +724,20 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 			.column(column)
 			.buildRequest()
 			.authorize();
-		
+
 		if (LOG.isDebugEnabled()) {
 			boolean allowed = session.isAuthorized();
 			String reason = session.getDenialReason();
 			String message = String.format(format, "Exiting", operation, otherInformation, access, table, columnFamily, column, allowed, reason);
 			LOG.debug(message);
 		}
-		
+
 		session.publishResults();
 	}
-	
+
 	boolean canSkipAccessCheck(User user, final String operation, String access, final String table)
 			throws AccessDeniedException {
-		
+
 		boolean result = false;
 		if (user == null) {
 			String message = "Unexpeceted: User is null: access denied, not audited!";
@@ -677,10 +749,10 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		} else {
 			LOG.debug("Can't skip access checks");
 		}
-		
+
 		return result;
 	}
-	
+
 	boolean canSkipAccessCheck(User user, final String operation, String access, final RegionCoprocessorEnvironment regionServerEnv) throws AccessDeniedException {
 
 		// read access to metadata tables is always allowed and isn't audited.
@@ -706,7 +778,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		}
 		return false;
 	}
-	
+
 	boolean isAccessForMetadataRead(String access, String table) {
 		if (_authUtils.isReadAccess(access) && isSpecialTable(table)) {
 			LOG.debug("isAccessForMetadataRead: Metadata tables read: access allowed!");
@@ -729,7 +801,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 
 		authorizeAccess(ctx, request, null, action, table, null, null);
 	}
-	
+
 	protected void requirePermission(ObserverContext<?> ctx, String request, byte[] aTableName, byte[] aColumnFamily, byte[] aQualifier, Permission.Action action) throws AccessDeniedException {
 
 		String table = Bytes.toString(aTableName);
@@ -738,7 +810,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 
 		authorizeAccess(ctx, request, null, action, table, columnFamily, column);
 	}
-	
+
 	protected void requirePermission(ObserverContext<?> ctx, String request, Permission.Action perm, RegionCoprocessorEnvironment env, Collection<byte[]> families) throws IOException {
 		HashMap<byte[], Set<byte[]>> familyMap = new HashMap<byte[], Set<byte[]>>();
 
@@ -927,7 +999,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 	@Override
 	public Result preIncrement(ObserverContext<RegionCoprocessorEnvironment> c, Increment increment) throws IOException {
 		requirePermission(c, "increment", TablePermission.Action.WRITE, c.getEnvironment(), increment.getFamilyCellMap().keySet());
-		
+
 		return null;
 	}
 
@@ -1121,7 +1193,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		if(plugin == null) {
 			synchronized(RangerAuthorizationCoprocessor.class) {
 				plugin = hbasePlugin;
-				
+
 				if(plugin == null) {
 					plugin = new RangerHBasePlugin(appType);
 
@@ -1133,7 +1205,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				}
 			}
 		}
-		
+
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("Start of Coprocessor: [" + coprocessorType + "]");
 		}
@@ -1143,7 +1215,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 	public void prePut(ObserverContext<RegionCoprocessorEnvironment> c, Put put, WALEdit edit, Durability durability) throws IOException {
 		requirePermission(c, "put", TablePermission.Action.WRITE, c.getEnvironment(), put.getFamilyCellMap());
 	}
-	
+
 	@Override
 	public void preGetOp(final ObserverContext<RegionCoprocessorEnvironment> rEnv, final Get get, final List<Cell> result) throws IOException {
 		if (LOG.isDebugEnabled()) {
@@ -1214,7 +1286,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		}
 
 		checkGetTableInfoAccess(ctx, "getTableDescriptors", descriptors, regex, _authUtils.getAccess(Action.CREATE));
-		
+
 		if (LOG.isDebugEnabled()) {
 			LOG.debug(String.format("<== postGetTableDescriptors(count(tableNamesList)=%s, count(descriptors)=%s, regex=%s)", tableNamesList == null ? 0 : tableNamesList.size(),
 					descriptors == null ? 0 : descriptors.size(), regex));
@@ -1269,7 +1341,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 
 		if(UpdateRangerPoliciesOnGrantRevoke) {
 			GrantRevokeRequest grData = null;
-	
+
 			try {
 				grData = createGrantData(request);
 
@@ -1505,7 +1577,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 				nameSpace = namepsacePermission.getNamespace();
 			break;
 		}
-		
+
 		if(StringUtil.isEmpty(nameSpace) && StringUtil.isEmpty(tableName) && StringUtil.isEmpty(colFamily) && StringUtil.isEmpty(qualifier)) {
 			throw new Exception("grant(): namespace/table/columnFamily/columnQualifier not specified");
 		}
@@ -1657,7 +1729,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 		ret.setForwardedAddresses(null);//TODO: Need to check with Knox proxy how they handle forwarded add.
 		ret.setRemoteIPAddress(getRemoteAddress());
 		ret.setRequestData(up.toString());
-		
+
 		if(userName.startsWith(GROUP_PREFIX)) {
 			ret.getGroups().add(userName.substring(GROUP_PREFIX.length()));
 		} else {
@@ -1870,6 +1942,7 @@ public class RangerAuthorizationCoprocessor implements AccessControlService.Inte
 class RangerHBasePlugin extends RangerBasePlugin {
 	private static final Logger LOG = LoggerFactory.getLogger(RangerHBasePlugin.class);
 	boolean isHBaseShuttingDown  = false;
+	private boolean isColumnAuthOptimizationEnabled = false;
 
 	public RangerHBasePlugin(String appType) {
 		super("hbase", appType);
@@ -1892,6 +1965,18 @@ class RangerHBasePlugin extends RangerBasePlugin {
 		}
 		return ret;
 	}
+	@Override
+	public void setPolicies(ServicePolicies policies) {
+		super.setPolicies(policies);
+		this.isColumnAuthOptimizationEnabled = Boolean.parseBoolean(this.getServiceConfigs().get(RangerHadoopConstants.HBASE_COLUMN_AUTH_OPTIMIZATION));
+		LOG.info("isColumnAuthOptimizationEnabled="+this.isColumnAuthOptimizationEnabled);
+	}
+	public boolean getPropertyIsColumnAuthOptimizationEnabled(){
+		return this.isColumnAuthOptimizationEnabled;
+	}
+	public void setColumnAuthOptimizationEnabled(boolean enable){
+		this.isColumnAuthOptimizationEnabled = enable;
+	}
 }
 
 
