@@ -250,82 +250,6 @@ chown ${CONFIG_FILE_OWNER} ${CredFile}
 # Modify the XML files needed to support the 
 #
 PROP_ARGS="-p  ${install_dir}/install.properties"
-to_file="${install_dir}/install.properties"
-DB_FLAVOR=`grep '^XAAUDIT.DB.FLAVOUR'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-DB_FLAVOR=`echo $DB_FLAVOR | tr '[:lower:]' '[:upper:]'`
-if [ "${DB_FLAVOR}" == "" ]
-then
-	$DB_FLAVOR="MYSQL"
-fi
-echo "[I] Updating install.properites setting for : $DB_FLAVOR"
-
-if [ "${DB_FLAVOR}" == "MYSQL" ]
-then
-	audit_db_hostname=`grep '^XAAUDIT.DB.HOSTNAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	audit_db_name=`grep '^XAAUDIT.DB.DATABASE_NAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	propertyName=XAAUDIT.DB.JDBC_URL
-	newPropertyValue="jdbc:mysql://${audit_db_hostname}/${audit_db_name}"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-
-	propertyName=XAAUDIT.DB.JDBC_DRIVER
-	newPropertyValue="com.mysql.jdbc.Driver"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-fi
-
-if [ "${DB_FLAVOR}" == "ORACLE" ]
-then
-	audit_db_hostname=`grep '^XAAUDIT.DB.HOSTNAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	propertyName=XAAUDIT.DB.JDBC_URL
-	count=$(grep -o ":" <<< "$audit_db_hostname" | wc -l)
-	#if [[ ${count} -eq 2 ]] ; then
-	if [ ${count} -eq 2 ] || [ ${count} -eq 0 ]; then
-		#jdbc:oracle:thin:@[HOST][:PORT]:SID
-		newPropertyValue="jdbc:oracle:thin:@${audit_db_hostname}"
-	else
-		#jdbc:oracle:thin:@//[HOST][:PORT]/SERVICE
-		newPropertyValue="jdbc:oracle:thin:@//${audit_db_hostname}"
-	fi
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-
-	propertyName=XAAUDIT.DB.JDBC_DRIVER
-	newPropertyValue="oracle.jdbc.OracleDriver"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-fi
-if [ "${DB_FLAVOR}" == "POSTGRES" ]
-then
-	audit_db_hostname=`grep '^XAAUDIT.DB.HOSTNAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	audit_db_name=`grep '^XAAUDIT.DB.DATABASE_NAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	propertyName=XAAUDIT.DB.JDBC_URL
-	newPropertyValue="jdbc:postgresql://${audit_db_hostname}/${audit_db_name}"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-	propertyName=XAAUDIT.DB.JDBC_DRIVER
-	newPropertyValue="org.postgresql.Driver"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-fi
-if [ "${DB_FLAVOR}" == "MSSQL" ]
-then
-	audit_db_hostname=`grep '^XAAUDIT.DB.HOSTNAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	audit_db_name=`grep '^XAAUDIT.DB.DATABASE_NAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	propertyName=XAAUDIT.DB.JDBC_URL
-	newPropertyValue="jdbc:sqlserver://${audit_db_hostname};databaseName=${audit_db_name}"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-
-	propertyName=XAAUDIT.DB.JDBC_DRIVER
-	newPropertyValue="com.microsoft.sqlserver.jdbc.SQLServerDriver"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-fi
-if [ "${DB_FLAVOR}" == "SQLA" ]
-then
-	audit_db_hostname=`grep '^XAAUDIT.DB.HOSTNAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	audit_db_name=`grep '^XAAUDIT.DB.DATABASE_NAME'  ${install_dir}/install.properties | awk -F= '{ print $2 }'`
-	propertyName=XAAUDIT.DB.JDBC_URL
-	newPropertyValue="jdbc:sqlanywhere:database=${audit_db_name};host=${audit_db_hostname}"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-
-	propertyName=XAAUDIT.DB.JDBC_DRIVER
-	newPropertyValue="sap.jdbc4.sqlanywhere.IDriver"
-	updatePropertyToFile $propertyName $newPropertyValue $to_file
-fi
 for f in ${install_dir}/installer/conf/*-changes.cfg
 do
         if [ -f ${f} ]
