@@ -742,13 +742,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 
 			RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, EXECUTE_ACCCESS_TYPE, operation, context.user, context.userGroups);
 
-			// if the request was already allowed by a Ranger policy (for ancestor/parent/node/child), skip chained plugin evaluations in subsequent calls
-			if (context.isAllowedByRangerPolicies) {
-				LOG.warn("This request is already allowed by Ranger policies. Ensuring that chained-plugins are not evaluated again for this request, request:[" + request + "]");
-
-				RangerAccessRequestUtil.setIsSkipChainedPlugins(request.getContext(), Boolean.TRUE);
-			}
-
 			RangerAccessResult result = context.plugin.isAccessAllowed(request, null);
 
 			context.saveResult(result);
@@ -762,8 +755,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("This request is for the first time allowed by Ranger policies. request:[" + request + "]");
 				}
-
-				context.isAllowedByRangerPolicies = true;
 			}
 
 			if (ret == AuthzStatus.DENY || (!skipAuditOnAllow && result != null && result.getIsAccessDetermined())) {
@@ -900,13 +891,9 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 
 					RangerAccessRequestUtil.setAllRequestedAccessTypeGroups(request, allAccessTypeGroups);
 					RangerAccessRequestUtil.setAllRequestedAccessTypes(request.getContext(), accessTypes);
-				}
-
-				// if the request was already allowed by a Ranger policy (for ancestor/parent/node/child), skip chained plugin evaluations in subsequent calls
-				if (context.isAllowedByRangerPolicies) {
-					LOG.warn("This request is already allowed by Ranger policies. Ensuring that chained-plugins are not evaluated again for this request, request:[" + request + "]");
-
-					RangerAccessRequestUtil.setIsSkipChainedPlugins(request.getContext(), Boolean.TRUE);
+					if (accessTypes.contains(EXECUTE_ACCCESS_TYPE)) {
+						RangerAccessRequestUtil.setIgnoreIfNotDeniedAccessTypes(request.getContext(), access2ActionListMapper.get(FsAction.EXECUTE));
+					}
 				}
 
 				RangerAccessResult result = context.plugin.isAccessAllowed(request, context.auditHandler);
@@ -924,8 +911,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 					if (LOG.isDebugEnabled()) {
 						LOG.debug("This request is for the first time allowed by Ranger policies. request:[" + request + "]");
 					}
-
-					context.isAllowedByRangerPolicies = true;
 				}
 			}
 
@@ -980,6 +965,9 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 
 						RangerAccessRequestUtil.setAllRequestedAccessTypeGroups(request, allAccessTypeGroups);
 						RangerAccessRequestUtil.setAllRequestedAccessTypes(request.getContext(), accessTypes);
+						if (accessTypes.contains(EXECUTE_ACCCESS_TYPE)) {
+							RangerAccessRequestUtil.setIgnoreIfNotDeniedAccessTypes(request.getContext(), access2ActionListMapper.get(FsAction.EXECUTE));
+						}
 					}
 
 					RangerAccessResult result = context.plugin.isAccessAllowed(request, null);
@@ -1443,7 +1431,6 @@ class AuthzContext {
 	public final Set<String>            userGroups;
 	public final String                 operationName;
 	public       boolean                isTraverseOnlyCheck;
-	public       boolean                isAllowedByRangerPolicies;
 	public       RangerHdfsAuditHandler auditHandler = null;
 	private      RangerAccessResult     lastResult   = null;
 
