@@ -21,7 +21,7 @@ import org.apache.ranger.entity.XXRangerMasterKey;
 
 public class RangerMasterKeyDao extends BaseDao<XXRangerMasterKey> {
 
-	public RangerMasterKeyDao(DaoManagerBase daoManager) {
+	RangerMasterKeyDao(DaoManagerBase daoManager) {
 		super(daoManager);
 	}
 }
