@@ -19,7 +19,8 @@
 
 package org.apache.ranger.services.ozone.client;
 
-import org.apache.hadoop.conf.Configuration;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.hadoop.hdds.conf.OzoneConfiguration;
 import org.apache.hadoop.ozone.client.OzoneBucket;
 import org.apache.hadoop.ozone.client.OzoneClientFactory;
@@ -29,32 +30,36 @@ import org.apache.ranger.plugin.client.BaseClient;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.security.auth.Subject;
 import java.io.IOException;
+import java.security.PrivilegedExceptionAction;
 import java.util.*;
 
 public class OzoneClient extends BaseClient {
 
-    private static final Logger LOG = LoggerFactory.getLogger(OzoneClient.class);
+    private static final Log LOG        = LogFactory.getLog(OzoneClient.class);
+    private static final String ERR_MSG = "You can still save the repository and start creating policies, but you " +
+            "would not be able to use autocomplete for resource names. Check ranger_admin.log for more info.";
 
-    private static final String ERR_MSG = "You can still save the repository and start creating "
-            + "policies, but you would not be able to use autocomplete for "
-            + "resource names. Check ranger_admin.log for more info.";
-
-    private Configuration conf;
+    private final OzoneConfiguration conf;
     private org.apache.hadoop.ozone.client.OzoneClient ozoneClient = null;
 
     public OzoneClient(String serviceName, Map<String,String> connectionProperties) throws Exception{
         super(serviceName,connectionProperties, "ozone-client");
-        conf = new Configuration();
+        conf = new OzoneConfiguration();
         Set<String> rangerInternalPropertyKeys = getConfigHolder().getRangerInternalPropertyKeys();
         for (Map.Entry<String, String> entry: connectionProperties.entrySet())  {
-            String key = entry.getKey();
+            String key   = entry.getKey();
             String value = entry.getValue();
             if (!rangerInternalPropertyKeys.contains(key) && value != null) {
                 conf.set(key, value);
             }
         }
-        ozoneClient = OzoneClientFactory.getRpcClient(new OzoneConfiguration(conf));
+        Subject.doAs(getLoginSubject(), (PrivilegedExceptionAction<Void>) () -> {
+            String[] serviceIds = conf.getTrimmedStrings("ozone.om.service.ids", "ozone1");
+            ozoneClient = OzoneClientFactory.getRpcClient(serviceIds[0], conf);
+            return null;
+        });
     }
 
     public void close() {
@@ -71,10 +76,10 @@ public class OzoneClient extends BaseClient {
             LOG.debug("==> OzoneClient getVolume volumePrefix : " + volumePrefix);
         }
 
-        List<String> ret = new ArrayList<String>();
+        List<String> ret = new ArrayList<>();
         try {
             if (ozoneClient != null) {
-                Iterator<? extends OzoneVolume> ozoneVolList = ozoneClient.getObjectStore().listVolumesByUser(conf.get("username"), volumePrefix, null);
+                Iterator<? extends OzoneVolume> ozoneVolList = ozoneClient.getObjectStore().listVolumes(volumePrefix);
                 if (ozoneVolList != null) {
                     while (ozoneVolList.hasNext()) {
                         ret.add(ozoneVolList.next().getName());
@@ -93,20 +98,18 @@ public class OzoneClient extends BaseClient {
         return ret;
     }
 
-    public List<String> getBucketList(String bucketPrefix, List<String> finalvolumeList) {
+    public List<String> getBucketList(String bucketPrefix, List<String> finalVolumeList) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("==> OzoneClient getBucketList bucketPrefix : " + bucketPrefix);
         }
-        List<String> ret = new ArrayList<String>();
+        List<String> ret = new ArrayList<>();
         try {
-            if (ozoneClient != null) {
-                if (finalvolumeList != null && !finalvolumeList.isEmpty()) {
-                    for (String ozoneVol : finalvolumeList) {
-                        Iterator<? extends OzoneBucket> ozoneBucketList = ozoneClient.getObjectStore().getVolume(ozoneVol).listBuckets(bucketPrefix);
-                        if (ozoneBucketList != null) {
-                            while (ozoneBucketList.hasNext()) {
-                                ret.add(ozoneBucketList.next().getName());
-                            }
+            if (ozoneClient != null && finalVolumeList != null && !finalVolumeList.isEmpty()){
+                for (String ozoneVol : finalVolumeList) {
+                    Iterator<? extends OzoneBucket> ozoneBucketList = ozoneClient.getObjectStore().getVolume(ozoneVol).listBuckets(bucketPrefix);
+                    if (ozoneBucketList != null) {
+                        while (ozoneBucketList.hasNext()) {
+                            ret.add(ozoneBucketList.next().getName());
                         }
                     }
                 }
@@ -123,25 +126,23 @@ public class OzoneClient extends BaseClient {
         return ret;
     }
 
-    public List<String> getKeyList(String keyPrefix, List<String> finalvolumeList, List<String> finalbucketList) {
+    public List<String> getKeyList(String keyPrefix, List<String> finalVolumeList, List<String> finalBucketList) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("==> OzoneClient getKeyList keyPrefix : " + keyPrefix);
         }
-        List<String> ret = new ArrayList<String>();
+        List<String> ret = new ArrayList<>();
         try {
-            if (ozoneClient != null) {
-                if (finalvolumeList != null && !finalvolumeList.isEmpty()) {
-                    for (String ozoneVol : finalvolumeList) {
-                        Iterator<? extends OzoneBucket> ozoneBucketList = ozoneClient.getObjectStore().getVolume(ozoneVol).listBuckets(null);
-                        if (ozoneBucketList != null) {
-                            while (ozoneBucketList.hasNext()) {
-                                String bucketName = ozoneBucketList.next().getName();
-                                if (finalbucketList.contains(bucketName)) {
-                                    Iterator<? extends OzoneKey> ozoneKeyList = ozoneBucketList.next().listKeys(keyPrefix);
-                                    if (ozoneKeyList != null) {
-                                        while (ozoneKeyList.hasNext()) {
-                                            ret.add(ozoneKeyList.next().getName());
-                                        }
+            if (ozoneClient != null && finalVolumeList != null && !finalVolumeList.isEmpty()) {
+                for (String ozoneVol : finalVolumeList) {
+                    Iterator<? extends OzoneBucket> ozoneBucketIterator = ozoneClient.getObjectStore().getVolume(ozoneVol).listBuckets(null);
+                    if (ozoneBucketIterator != null) {
+                        while (ozoneBucketIterator.hasNext()) {
+                            OzoneBucket currentBucket = ozoneBucketIterator.next();
+                            if (finalBucketList.contains(currentBucket.getName())) {
+                                Iterator<? extends OzoneKey> ozoneKeyIterator = currentBucket.listKeys(keyPrefix);
+                                if (ozoneKeyIterator != null) {
+                                    while (ozoneKeyIterator.hasNext()) {
+                                        ret.add(ozoneKeyIterator.next().getName());
                                     }
                                 }
                             }
@@ -163,30 +164,26 @@ public class OzoneClient extends BaseClient {
 
     public static Map<String, Object> connectionTest(String serviceName,
                                                      Map<String, String> connectionProperties) throws Exception {
-        Map<String, Object> responseData = new HashMap<String, Object>();
+        Map<String, Object> responseData = new HashMap<>();
         OzoneClient connectionObj = null;
         boolean connectivityStatus = false;
-        List<String> testResult = null;
+        List<String> testResult;
 
         try {
-            connectionObj = new OzoneClient(serviceName,	connectionProperties);
-            if (connectionObj != null) {
-                testResult = connectionObj.getVolumeList(null);
-                if (testResult != null && testResult.size() != 0) {
-                    connectivityStatus = true;
-                }
-                if (connectivityStatus) {
-                    String successMsg = "ConnectionTest Successful";
-                    generateResponseDataMap(connectivityStatus, successMsg, successMsg,
-                            null, null, responseData);
-                } else {
-                    String failureMsg = "Unable to retrieve any volumes using given parameters.";
-                    generateResponseDataMap(connectivityStatus, failureMsg, failureMsg + ERR_MSG,
-                            null, null, responseData);
-                }
+            connectionObj = new OzoneClient(serviceName, connectionProperties);
+            testResult    = connectionObj.getVolumeList("");
+            if (testResult != null && testResult.size() != 0) {
+                connectivityStatus = true;
+            }
+            if (connectivityStatus) {
+                String successMsg = "ConnectionTest Successful";
+                generateResponseDataMap(true, successMsg, successMsg,
+                        null, null, responseData);
+            } else {
+                String failureMsg = "Unable to retrieve any volumes using given parameters.";
+                generateResponseDataMap(false, failureMsg, failureMsg + ERR_MSG,
+                        null, null, responseData);
             }
-        } catch (Exception e) {
-            throw e;
         } finally {
             if (connectionObj != null) {
                 connectionObj.close();
