@@ -136,7 +136,7 @@ CREATE TABLE `x_service_config_def` (
 `rb_key_label` varchar(1024) DEFAULT NULL,
 `rb_key_description` varchar(1024) DEFAULT NULL,
 `rb_key_validation_message` varchar(1024) DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`),
 CONSTRAINT `x_service_config_def_FK_defid` FOREIGN KEY (`def_id`) REFERENCES `x_service_def` (`id`),
 CONSTRAINT `x_service_config_def_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -170,7 +170,7 @@ CREATE TABLE `x_resource_def` (
 `rb_key_label` varchar(1024) DEFAULT NULL,  
 `rb_key_description` varchar(1024) DEFAULT NULL, 
 `rb_key_validation_message` varchar(1024) DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0', 
+`sort_order` int DEFAULT 0,
 primary key (`id`),
 KEY `x_resource_def_FK_parent` (`parent`),   
 CONSTRAINT `x_resource_def_FK_parent` FOREIGN KEY (`parent`) REFERENCES `x_resource_def` (`id`) ,
@@ -191,7 +191,7 @@ CREATE TABLE `x_access_type_def` (
 `name` varchar(1024) DEFAULT NULL,  
 `label` varchar(1024) DEFAULT NULL,   
 `rb_key_label` varchar(1024) DEFAULT NULL, 
-`sort_order` tinyint(3) DEFAULT '0', 
+`sort_order` int DEFAULT 0,
 primary key (`id`)   ,
 CONSTRAINT `x_access_type_def_FK_defid` FOREIGN KEY (`def_id`) REFERENCES `x_service_def` (`id`),
 CONSTRAINT `x_access_type_def_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -233,7 +233,7 @@ CREATE TABLE `x_policy_condition_def` (
 `rb_key_label` varchar(1024) DEFAULT NULL,  
 `rb_key_description` varchar(1024) DEFAULT NULL,  
 `rb_key_validation_message` varchar(1024) DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`)   ,
 CONSTRAINT `x_policy_condition_def_FK_defid` FOREIGN KEY (`def_id`) REFERENCES `x_service_def` (`id`),
 CONSTRAINT `x_policy_condition_def_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -252,7 +252,7 @@ CREATE TABLE `x_context_enricher_def` (
 `name` varchar(1024) DEFAULT NULL,  
 `enricher` varchar(1024) DEFAULT NULL,
 `enricher_options` varchar(1024) DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`)   ,
 CONSTRAINT `x_context_enricher_def_FK_defid` FOREIGN KEY (`def_id`) REFERENCES `x_service_def` (`id`),
 CONSTRAINT `x_context_enricher_def_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -288,7 +288,7 @@ CREATE TABLE `x_enum_element_def` (
 `name` varchar(1024) DEFAULT NULL,  
 `label` varchar(1024) DEFAULT NULL,  
 `rb_key_label` varchar(1024) DEFAULT NULL,   
-`sort_order` tinyint(3) DEFAULT '0', 
+`sort_order` int DEFAULT 0,
 primary key (`id`),    
 CONSTRAINT `x_enum_element_def_FK_defid` FOREIGN KEY (`enum_def_id`) REFERENCES `x_enum_def` (`id`),
 CONSTRAINT `x_enum_element_def_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -338,7 +338,7 @@ CREATE TABLE `x_policy_resource_map` (
 `upd_by_id` bigint(20) DEFAULT NULL,
 `resource_id` bigint(20) NOT NULL, 
 `value` varchar(1024) DEFAULT NULL,  
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`),    
 CONSTRAINT `x_policy_resource_map_FK_resource_id` FOREIGN KEY (`resource_id`) REFERENCES `x_policy_resource` (`id`),
 CONSTRAINT `x_policy_resource_map_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -354,7 +354,7 @@ CREATE TABLE `x_policy_item` (
 `upd_by_id` bigint(20) DEFAULT NULL,
 `policy_id` bigint(20) NOT NULL,
 `delegate_admin` tinyint(1) NOT NULL DEFAULT '0',
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`), 
 CONSTRAINT `x_policy_item_FK_policy_id` FOREIGN KEY (`policy_id`) REFERENCES `x_policy` (`id`),
 CONSTRAINT `x_policy_item_FK_added_by_id` FOREIGN KEY (`added_by_id`) REFERENCES `x_portal_user` (`id`),
@@ -371,7 +371,7 @@ CREATE TABLE `x_policy_item_access` (
 `policy_item_id` bigint(20) NOT NULL, 
 `type` bigint(20) NOT NULL,
 `is_allowed` tinyint(11) NOT NULL DEFAULT '0',
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (id), 
 CONSTRAINT `x_policy_item_access_FK_pi_id` FOREIGN KEY (`policy_item_id`) REFERENCES `x_policy_item` (`id`) ,
 CONSTRAINT `x_policy_item_access_FK_atd_id` FOREIGN KEY (`type`) REFERENCES `x_access_type_def` (`id`),
@@ -389,7 +389,7 @@ CREATE TABLE `x_policy_item_condition` (
 `policy_item_id` bigint(20) NOT NULL, 
 `type` bigint(20) NOT NULL,
 `value` varchar(1024) DEFAULT NULL, 
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (id), 
 CONSTRAINT `x_policy_item_condition_FK_pi_id` FOREIGN KEY (`policy_item_id`) REFERENCES `x_policy_item` (`id`) ,
 CONSTRAINT `x_policy_item_condition_FK_pcd_id` FOREIGN KEY (`type`) REFERENCES `x_policy_condition_def` (`id`),
@@ -406,7 +406,7 @@ CREATE TABLE `x_policy_item_user_perm` (
 `upd_by_id` bigint(20) DEFAULT NULL,
 `policy_item_id` bigint(20) NOT NULL,
 `user_id` bigint(20) NULL DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`), 
 CONSTRAINT `x_policy_item_user_perm_FK_pi_id` FOREIGN KEY (`policy_item_id`) REFERENCES `x_policy_item` (`id`) ,
 CONSTRAINT `x_policy_item_user_perm_FK_user_id` FOREIGN KEY (`user_id`) REFERENCES `x_user` (`id`),
@@ -423,7 +423,7 @@ CREATE TABLE `x_policy_item_group_perm` (
 `upd_by_id` bigint(20) DEFAULT NULL,
 `policy_item_id` bigint(20) NOT NULL,
 `group_id` bigint(20) NULL DEFAULT NULL,
-`sort_order` tinyint(3) DEFAULT '0',
+`sort_order` int DEFAULT 0,
 primary key (`id`), 
 CONSTRAINT `x_policy_item_group_perm_FK_pi_id` FOREIGN KEY (`policy_item_id`) REFERENCES `x_policy_item` (`id`) ,
 CONSTRAINT `x_policy_item_group_perm_FK_group_id` FOREIGN KEY (`group_id`) REFERENCES `x_group` (`id`),
