@@ -52,8 +52,8 @@ def log(msg,type):
 
 def username_validation(username):
         if username:
-                if re.search("[\\\`'\"]",username):
-                        log("[E] username contains one of the unsupported special characters like \" ' \ `","error")
+                if re.search("[\\`'\"]",username):
+                        log("[E] username contains one of the unsupported special characters like \" ' \\ `","error")
                         sys.exit(1)
 
 
