@@ -45,7 +45,7 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.security.ProviderUtils;
 import org.apache.hadoop.security.SecureClientLogin;
 import org.apache.hadoop.security.authentication.util.KerberosName;
-import org.apache.log4j.Logger;
+import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.common.ContextUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.plugin.util.PasswordUtils;
@@ -63,10 +63,9 @@ import org.apache.ranger.view.VXKmsKey;
 import org.apache.ranger.view.VXKmsKeyList;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Strings;
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
 import com.sun.jersey.api.client.Client;
 import com.sun.jersey.api.client.UniformInterfaceException;
 import com.sun.jersey.api.client.WebResource;
@@ -76,7 +75,7 @@ import com.sun.jersey.api.client.config.DefaultClientConfig;
 @Component
 public class KmsKeyMgr {
 
-	private static final Logger logger = Logger.getLogger(KmsKeyMgr.class);
+	private static final Logger logger = LoggerFactory.getLogger(KmsKeyMgr.class);
 	
 	private static final String KMS_KEY_LIST_URI  		= "v1/keys/names";				//GET
 	private static final String KMS_ADD_KEY_URI  		= "v1/keys";					//POST
@@ -106,12 +105,12 @@ public class KmsKeyMgr {
 	
 	@Autowired
 	RangerDaoManagerBase rangerDaoManagerBase;
-	
+
         @Autowired
         RangerBizUtil rangerBizUtil;
 
 	@SuppressWarnings("unchecked")
-	public VXKmsKeyList searchKeys(HttpServletRequest request, String repoName) throws Exception{
+	public VXKmsKeyList searchKeys(HttpServletRequest request, String repoName) throws Exception {
 		String providers[] = null;
 		try {
 			providers = getKMSURL(repoName);
@@ -131,7 +130,7 @@ public class KmsKeyMgr {
 		if(providers!=null){
 			for (int i = 0; i < providers.length; i++) {
 				Client c = getClient();
-				String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+				String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 				String keyLists = KMS_KEY_LIST_URI.replaceAll(
 						Pattern.quote("${userName}"), currentUserLoginId);
 				connProvider = providers[i];
@@ -142,6 +141,7 @@ public class KmsKeyMgr {
 				}else{
 					uri = uri.concat("?doAs="+currentUserLoginId);
 				}
+
 				final WebResource r = c.resource(uri);
 				try {
 					String response = null;
@@ -156,9 +156,9 @@ public class KmsKeyMgr {
 							}
 						});
 					}
-					Gson gson = new GsonBuilder().create();
+
 					logger.debug(" Search Key RESPONSE: [" + response + "]");
-					keys = gson.fromJson(response, List.class);
+					keys = JsonUtils.jsonToListString(response);
 					Collections.sort(keys);
 					VXKmsKeyList vxKmsKeyList2 = new VXKmsKeyList();
 					List<VXKmsKey> vXKeys2 = new ArrayList<VXKmsKey>();
@@ -237,7 +237,7 @@ public class KmsKeyMgr {
 			for (int i = 0; i < providers.length; i++) {
 				Client c = getClient();
 				String rollRest = KMS_ROLL_KEY_URI.replaceAll(Pattern.quote("${alias}"), vXKey.getName());
-				String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+				String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 				String uri = providers[i] + (providers[i].endsWith("/") ? rollRest : ("/" + rollRest));
 				if(!isKerberos){
 					uri = uri.concat("?user.name="+currentUserLoginId);
@@ -245,8 +245,7 @@ public class KmsKeyMgr {
 					uri = uri.concat("?doAs="+currentUserLoginId);
 				}
 				final WebResource r = c.resource(uri);
-				Gson gson = new GsonBuilder().create();
-				final String jsonString = gson.toJson(vXKey);
+				final String jsonString = JsonUtils.objectToJson(vXKey);
 				try {
 					String response = null;
 					if(!isKerberos){
@@ -261,7 +260,7 @@ public class KmsKeyMgr {
 						});
 		            }
 					logger.debug("Roll RESPONSE: [" + response + "]");
-					ret = gson.fromJson(response, VXKmsKey.class);
+					ret = JsonUtils.jsonToObject(response, VXKmsKey.class);
 					break;
 				} catch (Exception e) {
 					if (e instanceof UniformInterfaceException || i == providers.length - 1)
@@ -292,7 +291,7 @@ public class KmsKeyMgr {
 			for (int i = 0; i < providers.length; i++) {
 				Client c = getClient();
 				String deleteRest = KMS_DELETE_KEY_URI.replaceAll(Pattern.quote("${alias}"), name);
-				String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+				String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 				String uri = providers[i] + (providers[i].endsWith("/") ? deleteRest : ("/" + deleteRest));
 				if(!isKerberos){
 						uri = uri.concat("?user.name="+currentUserLoginId);
@@ -344,7 +343,7 @@ public class KmsKeyMgr {
 		if(providers!=null){
 			for (int i = 0; i < providers.length; i++) {
 				Client c = getClient();
-				String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+				String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 				String uri = providers[i] + (providers[i].endsWith("/") ? KMS_ADD_KEY_URI : ("/" + KMS_ADD_KEY_URI));
 				if(!isKerberos){
 					uri = uri.concat("?user.name="+currentUserLoginId);
@@ -352,8 +351,7 @@ public class KmsKeyMgr {
 					uri = uri.concat("?doAs="+currentUserLoginId);
 				}
 				final WebResource r = c.resource(uri);
-				Gson gson = new GsonBuilder().create();
-				final String jsonString = gson.toJson(vXKey);
+				final String jsonString = JsonUtils.objectToJson(vXKey);
 				try {
 					String response = null;
 					if(!isKerberos){
@@ -368,7 +366,7 @@ public class KmsKeyMgr {
 							});
 					}
 					logger.debug("Create RESPONSE: [" + response + "]");
-					ret = gson.fromJson(response, VXKmsKey.class);
+					ret = JsonUtils.jsonToObject(response, VXKmsKey.class);
 					return ret;
 				} catch (Exception e) {
 					if (e instanceof UniformInterfaceException || i == providers.length - 1)
@@ -398,7 +396,7 @@ public class KmsKeyMgr {
 			for (int i = 0; i < providers.length; i++) {
 				Client c = getClient();
 				String keyRest = KMS_KEY_METADATA_URI.replaceAll(Pattern.quote("${alias}"), name);
-				String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+				String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 				String uri = providers[i] + (providers[i].endsWith("/") ? keyRest : ("/" + keyRest));
 				if(!isKerberos){
 						uri = uri.concat("?user.name="+currentUserLoginId);
@@ -419,9 +417,8 @@ public class KmsKeyMgr {
 							}
 						});
 					}
-					Gson gson = new GsonBuilder().create();
 					logger.debug("RESPONSE: [" + response + "]");
-					VXKmsKey key = gson.fromJson(response, VXKmsKey.class);
+					VXKmsKey key = JsonUtils.jsonToObject(response, VXKmsKey.class);
 					return key;
 				} catch (Exception e) {
 					if (e instanceof UniformInterfaceException || i == providers.length - 1)
@@ -433,11 +430,11 @@ public class KmsKeyMgr {
 		}
 		return null;
 	}
-	
+
 	public VXKmsKey getKeyFromUri(String provider, String name, boolean isKerberos, String repoName) throws Exception {
 		Client c = getClient();
 		String keyRest = KMS_KEY_METADATA_URI.replaceAll(Pattern.quote("${alias}"), name);
-		String currentUserLoginId = ContextUtil.getCurrentUserLoginId();
+		String currentUserLoginId = StringUtil.getUTFEncodedString(ContextUtil.getCurrentUserLoginId());
 		String uri = provider + (provider.endsWith("/") ? keyRest : ("/" + keyRest));
 		if(!isKerberos){
 			uri = uri.concat("?user.name="+currentUserLoginId);
@@ -457,9 +454,8 @@ public class KmsKeyMgr {
 				}				
 			});
 		}
-		Gson gson = new GsonBuilder().create();
 		logger.debug("RESPONSE: [" + response + "]");
-		VXKmsKey key = gson.fromJson(response, VXKmsKey.class);
+		VXKmsKey key = JsonUtils.jsonToObject(response, VXKmsKey.class);
 		return key;
 	}
 	
@@ -495,7 +491,7 @@ public class KmsKeyMgr {
 		URL origUrl = new URL(extractKMSPath(providerUri).toString());
 		String authority = origUrl.getAuthority();
 		// 	check for ';' which delimits the backup hosts
-		if (Strings.isNullOrEmpty(authority)) {
+		if (StringUtils.isEmpty(authority)) {
 			throw new IOException("No valid authority in kms uri [" + origUrl+ "]");
 		}
 		// 	Check if port is present in authority
