@@ -44,7 +44,6 @@ import org.apache.ranger.entity.XXPolicyRefUser;
 import org.apache.ranger.entity.XXResourceDef;
 import org.apache.ranger.entity.XXRole;
 import org.apache.ranger.entity.XXServiceDef;
-import org.apache.ranger.entity.XXTrxLog;
 import org.apache.ranger.entity.XXUser;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerDataMaskPolicyItem;
@@ -53,6 +52,7 @@ import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemCondition;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemDataMaskInfo;
 import org.apache.ranger.plugin.model.RangerRole;
+import org.apache.ranger.plugin.util.ServiceDefUtil;
 import org.apache.ranger.service.RangerAuditFields;
 import org.apache.ranger.service.XGroupService;
 import org.apache.ranger.view.VXGroup;
@@ -65,6 +65,8 @@ import org.springframework.stereotype.Component;
 
 import javax.servlet.http.HttpServletResponse;
 
+import static org.apache.ranger.service.RangerBaseModelService.OPERATION_CREATE_CONTEXT;
+
 
 @Component
 public class PolicyRefUpdater {
@@ -97,7 +99,7 @@ public class PolicyRefUpdater {
 	@Autowired
 	RESTErrorUtil restErrorUtil;
 
-	public void createNewPolMappingForRefTable(RangerPolicy policy, XXPolicy xPolicy, XXServiceDef xServiceDef) throws Exception {
+	public void createNewPolMappingForRefTable(RangerPolicy policy, XXPolicy xPolicy, XXServiceDef xServiceDef, boolean createPrincipalsIfAbsent) throws Exception {
 		if(policy == null) {
 			return;
 		}
@@ -168,7 +170,11 @@ public class PolicyRefUpdater {
 		}
 		daoMgr.getXXPolicyRefResource().batchCreate(xPolResources);
 
-		final boolean isAdmin = rangerBizUtil.checkAdminAccess();
+		if (createPrincipalsIfAbsent && !rangerBizUtil.checkAdminAccess()) {
+			LOG.warn("policy=" + policy.getName() + ": createPrincipalIfAbsent=true, but current user does not have admin privileges!");
+
+			createPrincipalsIfAbsent = false;
+		}
 
 		List<XXPolicyRefRole> xPolRoles = new ArrayList<>();
 		for (String role : roleNames) {
@@ -177,7 +183,7 @@ public class PolicyRefUpdater {
 			}
 			PolicyPrincipalAssociator associator = new PolicyPrincipalAssociator(PRINCIPAL_TYPE.ROLE, role, xPolicy);
 			if (!associator.doAssociate(false)) {
-				if (isAdmin) {
+				if (createPrincipalsIfAbsent) {
 					rangerTransactionSynchronizationAdapter.executeOnTransactionCommit(associator);
 				} else {
 					VXResponse gjResponse = new VXResponse();
@@ -197,7 +203,7 @@ public class PolicyRefUpdater {
 
 			PolicyPrincipalAssociator associator = new PolicyPrincipalAssociator(PRINCIPAL_TYPE.GROUP, group, xPolicy);
 			if (!associator.doAssociate(false)) {
-				if (isAdmin) {
+				if (createPrincipalsIfAbsent) {
 					rangerTransactionSynchronizationAdapter.executeOnTransactionCommit(associator);
 				} else {
 					VXResponse gjResponse = new VXResponse();
@@ -214,7 +220,7 @@ public class PolicyRefUpdater {
 			}
 			PolicyPrincipalAssociator associator = new PolicyPrincipalAssociator(PRINCIPAL_TYPE.USER, user, xPolicy);
 			if (!associator.doAssociate(false)) {
-				if (isAdmin) {
+				if (createPrincipalsIfAbsent) {
 					rangerTransactionSynchronizationAdapter.executeOnTransactionCommit(associator);
 				} else {
 					VXResponse gjResponse = new VXResponse();
@@ -226,6 +232,10 @@ public class PolicyRefUpdater {
 		}
 
 		List<XXPolicyRefAccessType> xPolAccesses = new ArrayList<>();
+
+		// ignore built-in access-types while creating ref-table entries
+		accessTypes.removeAll(ServiceDefUtil.ACCESS_TYPE_MARKERS);
+
 		for (String accessType : accessTypes) {
 			XXAccessTypeDef xAccTypeDef = daoMgr.getXXAccessTypeDef().findByNameAndServiceId(accessType, xPolicy.getService());
 
@@ -248,6 +258,10 @@ public class PolicyRefUpdater {
 			XXPolicyConditionDef xPolCondDef = daoMgr.getXXPolicyConditionDef().findByServiceDefIdAndName(xServiceDef.getId(), condition);
 
 			if (xPolCondDef == null) {
+				if (StringUtils.equalsIgnoreCase(condition, ServiceDefUtil.IMPLICIT_CONDITION_EXPRESSION_NAME)) {
+					continue;
+				}
+
 				throw new Exception(condition + ": is not a valid condition-type. policy='"+  xPolicy.getName() + "' service='"+ xPolicy.getService() + "'");
 			}
 
@@ -397,7 +411,7 @@ public class PolicyRefUpdater {
 							ret = xUser.getId();
 						}
 					} else {
-						LOG.error("serviceConfigUser:[" + name + "] creation failed");
+						LOG.warn("serviceConfigUser:[" + name + "] creation failed. This may be a transient/spurious condition that may correct itself when transaction is committed");
 					}
 				}
 				break;
@@ -409,12 +423,8 @@ public class PolicyRefUpdater {
 					vxGroup.setGroupSource(RangerCommonEnums.GROUP_EXTERNAL);
 					VXGroup vXGroup = xGroupService.createXGroupWithOutLogin(vxGroup);
 					if (vXGroup != null) {
-						List<XXTrxLog> trxLogList = xGroupService.getTransactionLog(vXGroup, "create");
-						for (XXTrxLog xTrxLog : trxLogList) {
-							xTrxLog.setAddedByUserId(xPolicy.getAddedByUserId());
-							xTrxLog.setUpdatedByUserId(xPolicy.getAddedByUserId());
-						}
-						rangerBizUtil.createTrxLog(trxLogList);
+						xGroupService.createTransactionLog(vXGroup, null, OPERATION_CREATE_CONTEXT, xPolicy.getAddedByUserId());
+
 						ret = vXGroup.getId();
 					}
 				}
