@@ -521,6 +521,31 @@ public class RangerPolicyAdminImpl implements RangerPolicyAdmin {
         return ret;
     }
 
+    @Override
+    public Collection<String> getZoneNamesForResource(Map<String, ?> resource) {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerPolicyAdminImpl.getSecurityZonesForResource(" + resource + ")");
+        }
+
+        Collection<String> ret = null;
+
+        try (RangerReadWriteLock.RangerLock readLock = policyEngine.getReadLock()) {
+            if (LOG.isDebugEnabled()) {
+                if (readLock.isLockingEnabled()) {
+                    LOG.debug("Acquired lock - " + readLock);
+                }
+            }
+
+            ret = policyEngine.getMatchedZonesForResourceAndChildren(resource);
+        }
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("<== RangerPolicyAdminImpl.getSecurityZonesForResource(" + resource + ") : " + ret);
+        }
+
+        return ret;
+    }
+
     @Override
     public String getUniquelyMatchedZoneName(GrantRevokeRequest grantRevokeRequest) {
         if (LOG.isDebugEnabled()) {
@@ -621,7 +646,7 @@ public class RangerPolicyAdminImpl implements RangerPolicyAdmin {
 
         requestProcessor.preProcess(request);
 
-        Set<String> zoneNames = policyEngine.getMatchedZonesForResourceAndChildren(resource);
+        Set<String> zoneNames = RangerAccessRequestUtil.getResourceZoneNamesFromContext(request.getContext());
 
         if (CollectionUtils.isEmpty(zoneNames)) {
             getMatchingPoliciesForZone(request, null, ret);
@@ -771,40 +796,34 @@ public class RangerPolicyAdminImpl implements RangerPolicyAdmin {
 
             if (policyType == RangerPolicy.POLICY_TYPE_ACCESS) {
                 for (RangerPolicy.RangerPolicyItem item : policy.getPolicyItems()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
                 for (RangerPolicy.RangerPolicyItem item : policy.getDenyPolicyItems()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
                 for (RangerPolicy.RangerPolicyItem item : policy.getAllowExceptions()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
                 for (RangerPolicy.RangerPolicyItem item : policy.getDenyExceptions()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
             } else if (policyType == RangerPolicy.POLICY_TYPE_DATAMASK) {
                 for (RangerPolicy.RangerPolicyItem item : policy.getDataMaskPolicyItems()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
             } else if (policyType == RangerPolicy.POLICY_TYPE_ROWFILTER) {
                 for (RangerPolicy.RangerPolicyItem item : policy.getRowFilterPolicyItems()) {
-                    List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
-                    for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+                    for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                         ret.addAll(expandedAccesses.get(access.getType()));
                     }
                 }
@@ -869,10 +888,9 @@ public class RangerPolicyAdminImpl implements RangerPolicyAdmin {
     private void collectAccessTypes(Map<String, Collection<String>> expandedAccesses, List<? extends RangerPolicy.RangerPolicyItem> policyItems, Map<String, Set<String>> userAccesses, Map<String, Set<String>> groupAccesses, Map<String, Set<String>> roleAccesses) {
         for (RangerPolicy.RangerPolicyItem item : policyItems) {
 
-            List<RangerPolicy.RangerPolicyItemAccess> accesses = item.getAccesses();
             Set<String> accessTypes = new HashSet<>();
 
-            for (RangerPolicy.RangerPolicyItemAccess access : accesses) {
+            for (RangerPolicy.RangerPolicyItemAccess access : item.getAccesses()) {
                 accessTypes.addAll(expandedAccesses.get(access.getType()));
             }
 
