@@ -28,6 +28,7 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.ListUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.hadoop.config.RangerAdminConfig;
+import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.biz.ServiceDBStore.REMOVE_REF_TYPE;
 import org.apache.ranger.common.ContextUtil;
 import org.apache.ranger.common.MessageEnums;
@@ -44,6 +45,7 @@ import org.apache.ranger.plugin.store.RolePredicateUtil;
 import org.apache.ranger.plugin.store.RoleStore;
 import org.apache.ranger.plugin.util.RangerRoles;
 import org.apache.ranger.plugin.util.SearchFilter;
+import org.apache.ranger.service.RangerBaseModelService;
 import org.apache.ranger.service.RangerRoleService;
 import org.apache.ranger.service.XUserService;
 import org.apache.ranger.view.RangerRoleList;
@@ -53,8 +55,6 @@ import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
 
 @Component
 public class RoleDBStore implements RoleStore {
@@ -77,9 +77,6 @@ public class RoleDBStore implements RoleStore {
     @Autowired
 	RoleRefUpdater roleRefUpdater;
 
-    @Autowired
-    RangerBizUtil bizUtil;
-    
     @Autowired
 	RangerTransactionSynchronizationAdapter transactionSynchronizationAdapter;
 
@@ -88,7 +85,7 @@ public class RoleDBStore implements RoleStore {
 
     RangerAdminConfig config;
 
-    private Boolean populateExistingBaseFields = true;
+    private Boolean populateExistingBaseFields = false;
 
     AbstractPredicateUtil predicateUtil = null;
 
@@ -111,7 +108,7 @@ public class RoleDBStore implements RoleStore {
     }
 
     @Override
-    public RangerRole createRole(RangerRole role, Boolean createNonExistUserGroup) throws Exception {
+    public RangerRole createRole(RangerRole role, Boolean createNonExistUserGroupRole) throws Exception {
         if (LOG.isDebugEnabled()) {
             LOG.debug("==> RoleDBStore.createRole()");
         }
@@ -131,15 +128,14 @@ public class RoleDBStore implements RoleStore {
             throw new Exception("Cannot create role:[" + role + "]");
         }
 
-        roleRefUpdater.createNewRoleMappingForRefTable(createdRole, createNonExistUserGroup);
+        roleRefUpdater.createNewRoleMappingForRefTable(createdRole, createNonExistUserGroupRole);
 
-        List<XXTrxLog> trxLogList = roleService.getTransactionLog(createdRole, null, "create");
-        bizUtil.createTrxLog(trxLogList);
+        roleService.createTransactionLog(createdRole, null, RangerBaseModelService.OPERATION_CREATE_CONTEXT);
         return createdRole;
     }
 
     @Override
-    public RangerRole updateRole(RangerRole role, Boolean createNonExistUserGroup) throws Exception {
+    public RangerRole updateRole(RangerRole role, Boolean createNonExistUserGroupRole) throws Exception {
         XXRole xxRole = daoMgr.getXXRole().findByRoleId(role.getId());
         if (xxRole == null) {
             throw restErrorUtil.createRESTException("role with id: " + role.getId() + " does not exist");
@@ -148,9 +144,11 @@ public class RoleDBStore implements RoleStore {
 		if (!role.getName().equals(xxRole.getName())) { // ensure only if role name is changed
 			ensureRoleNameUpdateAllowed(xxRole.getName());
 		}
+        RangerRole oldRole = null;
+        if(StringUtils.isNotEmpty(xxRole.getRoleText())) {
+            oldRole = JsonUtils.jsonToObject(xxRole.getRoleText(), RangerRole.class);
+        }
 
-        Gson gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSS-Z").create();
-        RangerRole oldRole = gsonBuilder.fromJson(xxRole.getRoleText(), RangerRole.class);
 
         Runnable roleVersionUpdater = new RoleVersionUpdater(daoMgr);
         transactionSynchronizationAdapter.executeOnTransactionCommit(roleVersionUpdater);
@@ -160,7 +158,7 @@ public class RoleDBStore implements RoleStore {
             throw new Exception("Cannot update role:[" + role + "]");
         }
 
-        roleRefUpdater.createNewRoleMappingForRefTable(updatedRole, createNonExistUserGroup);
+        roleRefUpdater.createNewRoleMappingForRefTable(updatedRole, createNonExistUserGroupRole);
 
         roleService.updatePolicyVersions(updatedRole.getId());
 
@@ -168,8 +166,7 @@ public class RoleDBStore implements RoleStore {
             roleService.updateRoleVersions(updatedRole.getId());
         }
 
-        List<XXTrxLog> trxLogList = roleService.getTransactionLog(updatedRole, oldRole, "update");
-        bizUtil.createTrxLog(trxLogList);
+        roleService.createTransactionLog(updatedRole, oldRole, RangerBaseModelService.OPERATION_UPDATE_CONTEXT);
         return role;
     }
 
@@ -185,6 +182,12 @@ public class RoleDBStore implements RoleStore {
 			throw new Exception("Rolename for '" + roleName
 					+ "' can not be updated as it is referenced in one or more other roles");
 		}
+
+		boolean rleNotInZone = ensureRoleNotInZone(roleName);
+
+		if(!rleNotInZone) {
+			throw new Exception("Rolename for '"+ roleName + "' can not be updated as it is referenced in one or more security zones");
+		}
 	}
 
 	@Override
@@ -205,8 +208,7 @@ public class RoleDBStore implements RoleStore {
 		svcStore.updateServiceAuditConfig(role.getName(), REMOVE_REF_TYPE.ROLE);
         roleService.delete(role);
 
-        List<XXTrxLog> trxLogList = roleService.getTransactionLog(role, null, "delete");
-        bizUtil.createTrxLog(trxLogList);
+        roleService.createTransactionLog(role, null, RangerBaseModelService.OPERATION_DELETE_CONTEXT);
     }
 
     @Override
@@ -222,8 +224,7 @@ public class RoleDBStore implements RoleStore {
 		// delete role from audit filter configs
 		svcStore.updateServiceAuditConfig(role.getName(), REMOVE_REF_TYPE.ROLE);
         roleService.delete(role);
-        List<XXTrxLog> trxLogList = roleService.getTransactionLog(role, null, "delete");
-        bizUtil.createTrxLog(trxLogList);
+        roleService.createTransactionLog(role, null, RangerBaseModelService.OPERATION_DELETE_CONTEXT);
     }
 
     private void ensureRoleDeleteAllowed(String roleName) throws Exception {
@@ -236,6 +237,12 @@ public class RoleDBStore implements RoleStore {
         if(!roleNotInOtherRole) {
             throw new Exception("Role '"+ roleName + "' can not be deleted as it is referenced in one or more other roles");
         }
+
+        boolean rleNotInZone = ensureRoleNotInZone(roleName);
+
+        if(!rleNotInZone) {
+            throw new Exception("Role '"+ roleName + "' can not be deleted as it is referenced in one or more security zones");
+        }
     }
 
 	private boolean ensureRoleNotInPolicy(String roleName) {
@@ -250,6 +257,12 @@ public class RoleDBStore implements RoleStore {
 		return roleRefRoleCount < 1;
 	}
 
+    private boolean ensureRoleNotInZone(String roleName) {
+        Long roleRefZoneCount = daoMgr.getXXSecurityZoneRefRole().findRoleRefZoneCount(roleName);
+
+        return roleRefZoneCount < 1;
+    }
+
     @Override
     public RangerRole getRole(Long id) throws Exception {
         return roleService.read(id);
