@@ -20,42 +20,55 @@
  package org.apache.ranger.credentialapi;
 import java.util.ArrayList;
 import java.util.List;
-
+import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.alias.CredentialProvider;
 import org.apache.hadoop.security.alias.CredentialProviderFactory;
 import org.apache.hadoop.security.alias.JavaKeyStoreProvider;
-
 public class CredentialReader {
-	
-	public static String getDecryptedString(String CrendentialProviderPath,String alias) {
+
+	public static String getDecryptedString(String CrendentialProviderPath,String alias, String storeType) {
 		  String credential=null;
 		  try{
 			  if(CrendentialProviderPath==null || alias==null||CrendentialProviderPath.trim().isEmpty()||alias.trim().isEmpty()){
 				  return null;
-			  }		  		
+			  }
 			  char[] pass = null;
 			  Configuration conf = new Configuration();
 			  String crendentialProviderPrefixJceks=JavaKeyStoreProvider.SCHEME_NAME + "://file";
 			  String crendentialProviderPrefixLocalJceks="localjceks://file";
 			  crendentialProviderPrefixJceks=crendentialProviderPrefixJceks.toLowerCase();
+
+			  String crendentialProviderPrefixBcfks= "bcfks" + "://file";
+			  String crendentialProviderPrefixLocalBcfks= "localbcfks" + "://file";
+			  crendentialProviderPrefixBcfks=crendentialProviderPrefixBcfks.toLowerCase();
+			  crendentialProviderPrefixLocalBcfks=crendentialProviderPrefixLocalBcfks.toLowerCase();
+
 			  CrendentialProviderPath=CrendentialProviderPath.trim();
 			  alias=alias.trim();
-			  if(CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixJceks) ||  CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixLocalJceks)){
+			  if(CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixJceks) ||
+					  CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixLocalJceks) ||
+					  CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixBcfks) ||
+					  CrendentialProviderPath.toLowerCase().startsWith(crendentialProviderPrefixLocalBcfks)){
 				  conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,
-						   //UserProvider.SCHEME_NAME + ":///," +
-				  CrendentialProviderPath);
+						  //UserProvider.SCHEME_NAME + ":///," +
+						  CrendentialProviderPath);
 			  }else{
 				  if(CrendentialProviderPath.startsWith("/")){
-					  conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,
-							   //UserProvider.SCHEME_NAME + ":///," +
-					  JavaKeyStoreProvider.SCHEME_NAME + "://file" + CrendentialProviderPath);
+					  if(StringUtils.equalsIgnoreCase(storeType, "bcfks")) {
+						  conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH, CrendentialProviderPath);
+					  } else {
+						  conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,
+								  //UserProvider.SCHEME_NAME + ":///," +
+								  JavaKeyStoreProvider.SCHEME_NAME + "://file" + CrendentialProviderPath);
+					  }
+
 				  }else{
 					  conf.set(CredentialProviderFactory.CREDENTIAL_PROVIDER_PATH,
-							   //UserProvider.SCHEME_NAME + ":///," +
-					  JavaKeyStoreProvider.SCHEME_NAME + "://file/" + CrendentialProviderPath);
+							  //UserProvider.SCHEME_NAME + ":///," +
+							  JavaKeyStoreProvider.SCHEME_NAME + "://file/" + CrendentialProviderPath);
 				  }
-			  }	 	
+			  }
 			  List<CredentialProvider> providers = CredentialProviderFactory.getProviders(conf);
 			  List<String> aliasesList=new ArrayList<String>();
 			  CredentialProvider.CredentialEntry credEntry=null;
@@ -64,7 +77,7 @@ public class CredentialReader {
 				  aliasesList=provider.getAliases();
 				  if(aliasesList!=null && aliasesList.contains(alias.toLowerCase())){
 					  credEntry=null;
-					  credEntry= provider.getCredentialEntry(alias);
+					  credEntry= provider.getCredentialEntry(alias.toLowerCase());
 					  pass = credEntry.getCredential();
 					  if(pass!=null && pass.length>0){
 						  credential=String.valueOf(pass);
@@ -78,4 +91,4 @@ public class CredentialReader {
 		  }
 		  return credential;
 	  }
-}
\ No newline at end of file
+}
