@@ -18,11 +18,13 @@
 package org.apache.ranger.db;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import javax.persistence.NoResultException;
+import javax.persistence.Query;
 
 import org.apache.commons.collections.ListUtils;
 import org.apache.commons.lang.StringUtils;
@@ -416,4 +418,64 @@ public class XXPolicyDao extends BaseDao<XXPolicy> {
 			return new ArrayList<XXPolicy>();
 		}
 	}
+	public List<XXPolicy> findByServiceType(String serviceType) {
+		List<XXPolicy> ret = Collections.emptyList();
+
+		if (serviceType != null && !serviceType.isEmpty()) {
+			try {
+				ret = getEntityManager().createNamedQuery("XXPolicy.findByServiceType", tClass)
+				                        .setParameter("serviceType", serviceType)
+				                        .getResultList();
+			} catch (NoResultException e) {
+			    // ignore
+			}
+		}
+
+		return ret;
+	}
+
+	public XXPolicy getProjectPolicy(Long projectId, Long policyId) {
+		XXPolicy ret = null;
+
+		if (projectId != null && policyId != null) {
+			try {
+				ret = getEntityManager().createNamedQuery("XXPolicy.getProjectPolicy", tClass)
+				                        .setParameter("projectId", projectId)
+				                        .setParameter("policyId", policyId)
+				                        .getSingleResult();
+			} catch (NoResultException e) {
+				// ignore
+			}
+		}
+
+		return ret;
+	}
+
+	public List<Object[]> getMetaAttributesForPolicies(List<Long> policyIds) {
+		if (policyIds == null || policyIds.isEmpty()) {
+			return Collections.emptyList();
+		}
+
+		Query query = getEntityManager().createNamedQuery("XXPolicy.getMetaAttributesForPolicies", tClass);
+		query.setParameter("policyIds", policyIds);
+
+		return query.getResultList();
+	}
+
+	public List<XXPolicy> getProjectPolicies(Long projectId) {
+		List<XXPolicy> ret = Collections.emptyList();
+
+		if (projectId != null) {
+			try {
+				ret = getEntityManager().createNamedQuery("XXPolicy.getProjectPolicies", tClass)
+				                        .setParameter("projectId", projectId)
+				                        .getResultList();
+			} catch (NoResultException e) {
+				// ignore
+			}
+		}
+
+		return ret;
+	}
+
 }
