@@ -96,5 +96,35 @@ public class XXRoleDao extends BaseDao<XXRole> {
             return new ArrayList<String>();
         }
     }
+
+    @SuppressWarnings("unchecked")
+	public List<XXRole> findByUserId(Long UserId) {
+		if (UserId == null) {
+			return null;
+		}
+		List<XXRole> ret;
+		try {
+			ret = getEntityManager().createNamedQuery("XXRole.findByUserId", tClass).setParameter("userId", UserId)
+					.getResultList();
+		} catch (NoResultException e) {
+			ret = ListUtils.EMPTY_LIST;
+		}
+		return ret;
+	}
+
+    @SuppressWarnings("unchecked")
+    public List<XXRole> findByGroupId(Long groupId) {
+        if (groupId == null) {
+            return null;
+        }
+        List<XXRole> ret;
+        try {
+            ret = getEntityManager().createNamedQuery("XXRole.findByGroupId", tClass).setParameter("groupId", groupId)
+                    .getResultList();
+        } catch (NoResultException e) {
+            ret = ListUtils.EMPTY_LIST;
+        }
+        return ret;
+    }
 }
 
