@@ -160,7 +160,7 @@ public class XXServiceDao extends BaseDao<XXService> {
 			ret = new ArrayList<>(results.size());
 
 			for (Object[] result : results) {
-				ret.add(new RangerServiceHeaderInfo((Long) result[0], (String) result[1], (String) result[2], (String) result[3]));
+				ret.add(new RangerServiceHeaderInfo((Long) result[0], (String) result[1], (String) result[2], (String) result[3], (Boolean) result[4]));
 			}
 		} catch (NoResultException excp) {
 			ret = Collections.emptyList();
