@@ -29,6 +29,7 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.biz.PolicyRefUpdater;
 import org.apache.ranger.biz.ServiceDBStore;
+import org.apache.ranger.biz.XUserMgr;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.db.XXGroupDao;
 import org.apache.ranger.db.XXPolicyDao;
@@ -67,6 +68,7 @@ import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.beans.factory.annotation.Qualifier;
 import org.springframework.stereotype.Component;
 import org.springframework.transaction.PlatformTransactionManager;
+import org.springframework.transaction.TransactionDefinition;
 import org.springframework.transaction.TransactionStatus;
 import org.springframework.transaction.support.TransactionCallback;
 import org.springframework.transaction.support.TransactionTemplate;
@@ -95,6 +97,9 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 	@Autowired
 	PolicyRefUpdater policyRefUpdater;
 
+	@Autowired
+	XUserMgr xUserMgr;
+
 	private final Map<String, Long>              groupIdMap         = new HashMap<>();
 	private final Map<String, Long>              userIdMap          = new HashMap<>();
 	private final Map<String, Map<String, Long>> resourceNameIdMap  = new HashMap<>();
@@ -286,9 +291,10 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 			resourceNameIdMap.put(serviceType, serviceDefResourceNameIDMap);
 
 			XXServiceDef dbServiceDef = daoMgr.getXXServiceDef().findByName(serviceType);
-
-			for (XXResourceDef resourceDef : daoMgr.getXXResourceDef().findByServiceDefId(dbServiceDef.getId())) {
-				serviceDefResourceNameIDMap.put(resourceDef.getName(), resourceDef.getId());
+			if (dbServiceDef != null) {
+				for (XXResourceDef resourceDef : daoMgr.getXXResourceDef().findByServiceDefId(dbServiceDef.getId())) {
+					serviceDefResourceNameIDMap.put(resourceDef.getName(), resourceDef.getId());
+				}
 			}
 		}
 
@@ -333,10 +339,28 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 				XXUser userObject = userDao.findByUserName(user);
 
 				if (userObject == null) {
-					throw new Exception(user + ": unknown user in policy [id=" + policyId + "]");
+					logger.info(user +" user is not found, adding user: "+user);
+					TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+					txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+					try {
+						txTemplate.execute(new TransactionCallback<Object>() {
+							@Override
+							public Object doInTransaction(TransactionStatus status) {
+								xUserMgr.createServiceConfigUserSynchronously(user);
+								return null;
+							}
+						});
+					} catch(Exception exception) {
+						logger.error("Cannot create ServiceConfigUser(" + user + ")", exception);
+					}
+					userObject = userDao.findByUserName(user);
+					if (userObject == null) {
+						throw new Exception(user + ": unknown user in policy [id=" + policyId + "]");
+					}
 				}
 
 				userId = userObject.getId();
+				logger.info("userId:"+userId);
 
 				userIdMap.put(user, userId);
 			}
@@ -400,9 +424,10 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 			accessTypeIdMap.put(serviceType, serviceDefAccessTypeIDMap);
 
 			XXServiceDef dbServiceDef = daoMgr.getXXServiceDef().findByName(serviceType);
-
-			for (XXAccessTypeDef accessTypeDef : daoMgr.getXXAccessTypeDef().findByServiceDefId(dbServiceDef.getId())) {
-				serviceDefAccessTypeIDMap.put(accessTypeDef.getName(), accessTypeDef.getId());
+			if (dbServiceDef != null) {
+				for (XXAccessTypeDef accessTypeDef : daoMgr.getXXAccessTypeDef().findByServiceDefId(dbServiceDef.getId())) {
+					serviceDefAccessTypeIDMap.put(accessTypeDef.getName(), accessTypeDef.getId());
+				}
 			}
 		}
 
@@ -439,9 +464,10 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 			conditionNameIdMap.put(serviceType, serviceDefConditionNameIDMap);
 
 			XXServiceDef dbServiceDef = daoMgr.getXXServiceDef().findByName(serviceType);
-
-			for (XXPolicyConditionDef conditionDef : daoMgr.getXXPolicyConditionDef().findByServiceDefId(dbServiceDef.getId())) {
-				serviceDefConditionNameIDMap.put(conditionDef.getName(), conditionDef.getId());
+			if (dbServiceDef != null) {
+				for (XXPolicyConditionDef conditionDef : daoMgr.getXXPolicyConditionDef().findByServiceDefId(dbServiceDef.getId())) {
+					serviceDefConditionNameIDMap.put(conditionDef.getName(), conditionDef.getId());
+				}
 			}
 		}
 
@@ -479,9 +505,10 @@ public class PatchForMigratingOldRegimePolicyJson_J10046 extends BaseLoader {
 			dataMaskTypeIdMap.put(serviceType, serviceDefDataMaskTypeIDMap);
 
 			XXServiceDef dbServiceDef = daoMgr.getXXServiceDef().findByName(serviceType);
-
-			for (XXDataMaskTypeDef dataMaskTypeDef : daoMgr.getXXDataMaskTypeDef().findByServiceDefId(dbServiceDef.getId())) {
-				serviceDefDataMaskTypeIDMap.put(dataMaskTypeDef.getName(), dataMaskTypeDef.getId());
+			if (dbServiceDef != null) {
+				for (XXDataMaskTypeDef dataMaskTypeDef : daoMgr.getXXDataMaskTypeDef().findByServiceDefId(dbServiceDef.getId())) {
+					serviceDefDataMaskTypeIDMap.put(dataMaskTypeDef.getName(), dataMaskTypeDef.getId());
+				}
 			}
 		}
 
