@@ -27,8 +27,8 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.log4j.Logger;
 import org.apache.ranger.biz.SecurityZoneDBStore;
 import org.apache.ranger.biz.ServiceDBStore;
 import org.apache.ranger.common.RangerValidatorFactory;
@@ -45,6 +45,7 @@ import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.model.RangerSecurityZone.RangerSecurityZoneService;
+import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerServiceConfigDef;
 import org.apache.ranger.plugin.model.validation.RangerServiceDefValidator;
@@ -52,12 +53,20 @@ import org.apache.ranger.plugin.model.validation.RangerValidator.Action;
 import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
 import org.apache.ranger.plugin.util.SearchFilter;
 import org.apache.ranger.util.CLIUtil;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.beans.factory.annotation.Qualifier;
 import org.springframework.stereotype.Component;
+import org.springframework.transaction.PlatformTransactionManager;
+import org.springframework.transaction.TransactionDefinition;
+import org.springframework.transaction.TransactionStatus;
+import org.springframework.transaction.support.TransactionCallback;
+import org.springframework.transaction.support.TransactionTemplate;
 
 @Component
 public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
-    private static final Logger logger             = Logger.getLogger(PatchForSolrSvcDefAndPoliciesUpdate_J10055.class);
+    private static final Logger logger             = LoggerFactory.getLogger(PatchForSolrSvcDefAndPoliciesUpdate_J10055.class);
     private static final String ACCESS_TYPE_UPDATE = "update";
     private static final String ACCESS_TYPE_QUERY  = "query";
     private static final String ACCESS_TYPE_ADMIN  = "solr_admin";
@@ -70,6 +79,8 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
     private static final String ACCESS_TYPE_OTHERS_TAG = "solr:others";
     private enum NEW_RESOURCE { admin, config, schema }
 
+    private static final String SVC_ACCESS_TYPE_CONFIG_SUFFIX = "accessTypes";
+
     private static final String     SOLR_SVC_DEF_NAME      = EmbeddedServiceDefsUtil.EMBEDDED_SERVICEDEF_SOLR_NAME;
     private static RangerServiceDef embeddedSolrServiceDef = null;
 
@@ -85,6 +96,10 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
     @Autowired
     private RangerValidatorFactory validatorFactory;
 
+	@Autowired
+	@Qualifier(value = "transactionManager")
+	PlatformTransactionManager txManager;
+
     public static void main(String[] args) {
         logger.info("main()");
         try {
@@ -121,20 +136,32 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
                 System.exit(1);
             }
 
-            if (updateSolrSvcDef() != null) {
-                final Long resTypeSvcDefId =  embeddedSolrServiceDef.getId();
-                final Long tagSvcDefId = EmbeddedServiceDefsUtil.instance().getTagServiceDefId();
-                updateExistingRangerResPolicy(resTypeSvcDefId);
-                updateExistingRangerTagPolicies(tagSvcDefId);
+			TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+			txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+			try {
+				txTemplate.execute(new TransactionCallback<Object>() {
+					@Override
+					public Object doInTransaction(TransactionStatus status) {
+						if (updateSolrSvcDef() == null) {
+							throw new RuntimeException("Error while updating " + SOLR_SVC_DEF_NAME + " service-def");
+						}
+						return null;
+					}
+				});
+			} catch (Throwable ex) {
+				logger.error("Error while updating " + SOLR_SVC_DEF_NAME + " service-def");
+				throw new RuntimeException("Error while updating " + SOLR_SVC_DEF_NAME + " service-def");
+			}
 
-                deleteOldAccessTypeRefs(resTypeSvcDefId);
-                deleteOldAccessTypeRefs(tagSvcDefId);
-            } else {
-                logger.error("Error while updating " + SOLR_SVC_DEF_NAME + " service-def");
-                throw new RuntimeException("Error while updating " + SOLR_SVC_DEF_NAME + " service-def");
-            }
+			final Long resTypeSvcDefId = embeddedSolrServiceDef.getId();
+			final Long tagSvcDefId = EmbeddedServiceDefsUtil.instance().getTagServiceDefId();
+			updateExistingRangerResPolicy(resTypeSvcDefId);
+			updateExistingRangerTagPolicies(tagSvcDefId);
+
+			deleteOldAccessTypeRefs(resTypeSvcDefId);
+			deleteOldAccessTypeRefs(tagSvcDefId);
         } catch (Exception e) {
-            logger.error("Error whille executing PatchForSolrSvcDefAndPoliciesUpdate_J10055.", e);
+            logger.error("Error whille executing PatchForSolrSvcDefAndPoliciesUpdate_J10055, Error - ", e);
             System.exit(1);
         }
 
@@ -142,7 +169,7 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
 			// For RANGER-3725 - Update atlas default audit filter
 			updateDefaultAuditFilter(EmbeddedServiceDefsUtil.EMBEDDED_SERVICEDEF_ATLAS_NAME);
 		} catch (Throwable t) {
-			logger.error("Failed to update atlas default audit filter, Error - ", t);
+			logger.error("Failed to update atlas default audit filter - ", t);
 			System.exit(1);
 		}
 
@@ -159,168 +186,220 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
 				filter.setParam(SearchFilter.FETCH_ZONE_UNZONE_POLICIES, "true");
 				updateResPolicies(svcDBStore.getServicePolicies(dbService.getId(), filter));
 				updateZoneResourceMapping(dbService);
+				updateServiceConfig(dbService);
 			}
 		}
 		logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateExistingRangerResPolicy(...)");
 	}
 
-    private void updateZoneResourceMapping(final XXService solrDBSvc) throws Exception {
-         logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateZoneResourceMapping(...)");
-        // Update Zone Resource Mapping For Solr Services
-        final String svcName = solrDBSvc.getName();
-        SearchFilter filter  = new SearchFilter();
-        filter.setParam(SearchFilter.SERVICE_NAME, svcName);
-        List<RangerSecurityZone> secZoneList = this.secZoneDBStore.getSecurityZones(filter);
-        for (RangerSecurityZone secZone : secZoneList) {
-            RangerSecurityZoneService           secZoneSvc                  = secZone.getServices().get(svcName);// get secZoneSvc only for this svcName
-            List<HashMap<String, List<String>>> solrZoneSvcResourcesMapList = secZoneSvc.getResources();
+	private void updateZoneResourceMapping(final XXService solrDBSvc) throws Exception {
+		logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateZoneResourceMapping(...)");
+		// Update Zone Resource Mapping For Solr Services
+		final String svcName = solrDBSvc.getName();
+		SearchFilter filter = new SearchFilter();
+		filter.setParam(SearchFilter.SERVICE_NAME, svcName);
+		List<RangerSecurityZone> secZoneList = this.secZoneDBStore.getSecurityZones(filter);
+		long index = 1;
+		for (RangerSecurityZone secZone : secZoneList) {
+			logger.info("updateZoneResourceMapping() processing: [" + index + "/" + secZoneList.size() + "]");
+			TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+			txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+			try {
+				txTemplate.execute(new TransactionCallback<Object>() {
+					@Override
+					public Object doInTransaction(TransactionStatus status) {
+						try {
+							updateZone(secZone, svcName);
+						} catch (Exception e) {
+							throw new RuntimeException(e);
+						}
+						return null;
+					}
+				});
+			} catch (Throwable ex) {
+				logger.error("updateZoneResourceMapping(): Failed to update zone: " + secZone.getName() + " ", ex);
+				throw new RuntimeException(ex);
+			}
+			index++;
+		}
+		logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateZoneResourceMapping(...)");
+	}
 
-            final Set<HashMap<String, List<String>>> updatedResMapSet = new HashSet<HashMap<String, List<String>>>();
-            for (HashMap<String, List<String>> existingResMap : solrZoneSvcResourcesMapList) {
-                boolean isAllResource = false; // *
-                for (Map.Entry<String, List<String>> resNameValueListMap : existingResMap.entrySet()) {
+	private void updateZone(RangerSecurityZone secZone, String svcName) throws Exception {
+		RangerSecurityZoneService secZoneSvc = secZone.getServices().get(svcName);// get secZoneSvc only for this svcName
+		List<HashMap<String, List<String>>> solrZoneSvcResourcesMapList = secZoneSvc.getResources();
 
-                    updatedResMapSet.add(existingResMap);
-                    final List<String> resourceValueList = resNameValueListMap.getValue();
+		final Set<HashMap<String, List<String>>> updatedResMapSet = new HashSet<HashMap<String, List<String>>>();
+		for (HashMap<String, List<String>> existingResMap : solrZoneSvcResourcesMapList) {
+			boolean isAllResource = false; // *
+			for (Map.Entry<String, List<String>> resNameValueListMap : existingResMap.entrySet()) {
 
-                    if (CollectionUtils.isNotEmpty(resourceValueList) && resourceValueList.indexOf("*") >= 0) {
-                        updatedResMapSet.clear();
-                        updatedResMapSet.add(existingResMap);
-                        isAllResource = true;
-                        break;
-                    } else {
-                        HashMap<String, List<String>> updatedResMap = new HashMap<String, List<String>>();
-                        updatedResMap.put(NEW_RESOURCE.schema.name(), resourceValueList);
-                        updatedResMapSet.add(updatedResMap);
-                    }
-                }
+				updatedResMapSet.add(existingResMap);
+				final List<String> resourceValueList = resNameValueListMap.getValue();
 
-                if (isAllResource) {
-                    final List<String> allResVal = Arrays.asList("*");
-                    for (NEW_RESOURCE newRes : NEW_RESOURCE.values()) {
-                        HashMap<String, List<String>> updatedResMap = new HashMap<String, List<String>>();
-                        updatedResMap.put(newRes.name(), allResVal);
-                        updatedResMapSet.add(updatedResMap);
-                    }
-                    secZoneSvc.setResources(new ArrayList<HashMap<String, List<String>>>(updatedResMapSet));
-                    break;
-                }
-                secZoneSvc.setResources(new ArrayList<HashMap<String, List<String>>>(updatedResMapSet));
-            }
-            this.secZoneDBStore.updateSecurityZoneById(secZone);
-            logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateZoneResourceMapping(...)");
-        }
-    }
+				if (CollectionUtils.isNotEmpty(resourceValueList) && resourceValueList.indexOf("*") >= 0) {
+					updatedResMapSet.clear();
+					updatedResMapSet.add(existingResMap);
+					isAllResource = true;
+					break;
+				} else {
+					HashMap<String, List<String>> updatedResMap = new HashMap<String, List<String>>();
+					updatedResMap.put(NEW_RESOURCE.schema.name(), resourceValueList);
+					updatedResMapSet.add(updatedResMap);
+				}
+			}
 
-    private void updateExistingRangerTagPolicies(Long svcDefId) throws Exception {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateExistingRangerTagPolicies(" + svcDefId + ")");
-        List<XXService> dbServices = daoMgr.getXXService().findByServiceDefId(svcDefId);
-        if (CollectionUtils.isNotEmpty(dbServices)) {
-            for (XXService dbService : dbServices) {
-                SearchFilter filter = new SearchFilter();
-                filter.setParam(SearchFilter.SERVICE_NAME, dbService.getName());
-                updateTagPolicies(svcDBStore.getServicePolicies(dbService.getId(), filter));
-            }
-        }
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateExistingRangerTagPolicies(" + svcDefId + ")");
-}
+			if (isAllResource) {
+				final List<String> allResVal = Arrays.asList("*");
+				for (NEW_RESOURCE newRes : NEW_RESOURCE.values()) {
+					HashMap<String, List<String>> updatedResMap = new HashMap<String, List<String>>();
+					updatedResMap.put(newRes.name(), allResVal);
+					updatedResMapSet.add(updatedResMap);
+				}
+				secZoneSvc.setResources(new ArrayList<HashMap<String, List<String>>>(updatedResMapSet));
+				break;
+			}
+			secZoneSvc.setResources(new ArrayList<HashMap<String, List<String>>>(updatedResMapSet));
+		}
+		this.secZoneDBStore.updateSecurityZoneById(secZone);
+	}
 
-    private void updateTagPolicies(List<RangerPolicy> tagServicePolicies) {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateTagPolicies(...)");
-        if (CollectionUtils.isNotEmpty(tagServicePolicies)) {
-            for (RangerPolicy exPolicy : tagServicePolicies) {
-                try {
-                    updateTagPolicyItemAccess(exPolicy.getPolicyItems());
-                    updateTagPolicyItemAccess(exPolicy.getAllowExceptions());
-                    updateTagPolicyItemAccess(exPolicy.getDenyPolicyItems());
-                    updateTagPolicyItemAccess(exPolicy.getDenyExceptions());
-                    this.svcDBStore.updatePolicy(exPolicy);
-                } catch (Exception e) {
-                    logger.error("Failed to apply the patch, Error - " + e.getCause());
-                    e.printStackTrace();
-                    System.exit(1);
-                }
-            }
-        }
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateTagPolicies(...)");
-    }
+	private void updateExistingRangerTagPolicies(Long svcDefId) throws Exception {
+		List<XXService> dbServices = daoMgr.getXXService().findByServiceDefId(svcDefId);
+		if (CollectionUtils.isNotEmpty(dbServices)) {
+			for (XXService dbService : dbServices) {
+				SearchFilter filter = new SearchFilter();
+				filter.setParam(SearchFilter.SERVICE_NAME, dbService.getName());
+				updateTagPolicies(svcDBStore.getServicePolicies(dbService.getId(), filter));
+			}
+		}
+	}
 
-    private void updateResPolicies(List<RangerPolicy> policies) {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateResPolicies(...)");
-        if (CollectionUtils.isNotEmpty(policies)) {
-            for (RangerPolicy exPolicy : policies) {
-                // Filter policy items which are eligible for admin,config and schema resources
-                final List<RangerPolicy.RangerPolicyItem> filteredAllowPolciyItems  = filterPolicyItemsForAdminPermission(exPolicy.getPolicyItems());
-                final List<RangerPolicy.RangerPolicyItem> filteredAllowExcpPolItems = filterPolicyItemsForAdminPermission(exPolicy.getAllowExceptions());
-                final List<RangerPolicy.RangerPolicyItem> filteredDenyPolItems      = filterPolicyItemsForAdminPermission(exPolicy.getDenyPolicyItems());
-                final List<RangerPolicy.RangerPolicyItem> filteredDenyExcpPolItems  = filterPolicyItemsForAdminPermission(exPolicy.getDenyExceptions());
+	private void updateTagPolicies(List<RangerPolicy> tagServicePolicies) {
+		if (CollectionUtils.isNotEmpty(tagServicePolicies)) {
+			long index = 1;
+			for (RangerPolicy exPolicy : tagServicePolicies) {
+				logger.info("updateTagPolicies() processing: [" + index + "/" + tagServicePolicies.size() + "]");
+				TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+				txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+				try {
+					txTemplate.execute(new TransactionCallback<Object>() {
+						@Override
+						public Object doInTransaction(TransactionStatus status) {
+							updateTagPolicyItemAccess(exPolicy.getPolicyItems());
+							updateTagPolicyItemAccess(exPolicy.getAllowExceptions());
+							updateTagPolicyItemAccess(exPolicy.getDenyPolicyItems());
+							updateTagPolicyItemAccess(exPolicy.getDenyExceptions());
+							try {
+								svcDBStore.updatePolicy(exPolicy);
+							} catch (Exception e) {
+								throw new RuntimeException(e);
+							}
+							return null;
+						}
+					});
+				} catch (Throwable ex) {
+					logger.error("updateTagPolicies(): Failed to update policy: " + exPolicy.getName() + " ", ex);
+					throw new RuntimeException(ex);
+				}
+				index++;
+			}
+		}
+	}
 
-                // check if there is a need to create additional policies with admin/config/schema resource(s)
-                final boolean splitPolicy = (filteredAllowPolciyItems.size() > 0 || filteredAllowExcpPolItems.size() > 0 || filteredDenyPolItems.size() > 0 || filteredDenyExcpPolItems.size() > 0);
-                if (splitPolicy) {
-                    RangerPolicy newPolicyForNewResource = new RangerPolicy();
-                    newPolicyForNewResource.setService(exPolicy.getService());
-                    newPolicyForNewResource.setServiceType(exPolicy.getServiceType());
-                    newPolicyForNewResource.setPolicyPriority(exPolicy.getPolicyPriority());
+	private void updateResPolicies(List<RangerPolicy> policies) {
+		if (CollectionUtils.isNotEmpty(policies)) {
+			long index = 1;
+			for (RangerPolicy exPolicy : policies) {
+				logger.info("updateResPolicies() processing: [" + index + "/" + policies.size() + "]");
+				TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+				txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+				try {
+					txTemplate.execute(new TransactionCallback<Object>() {
+						@Override
+						public Object doInTransaction(TransactionStatus status) {
+							createOrUpdatePolicy(exPolicy);
+							return null;
+						}
+					});
+				} catch (Throwable ex) {
+					logger.error("updateResPolicies(): Failed to create/update policy: " + exPolicy.getName() + " ", ex);
+					throw new RuntimeException(ex);
+				}
+				index++;
+			}
+		}
+	}
 
-                    RangerPolicyResource newRes         = new RangerPolicyResource();
-                    boolean              isAllResources = false;
-                    // Only one entry expected
-                    for (Map.Entry<String, RangerPolicyResource> entry : exPolicy.getResources().entrySet()) {
-                        RangerPolicyResource exPolRes = entry.getValue();
-                        newRes.setIsExcludes(exPolRes.getIsExcludes());
-                        newRes.setIsRecursive(exPolRes.getIsRecursive());
-                        newRes.setValues(exPolRes.getValues());
-                        if (CollectionUtils.isNotEmpty(exPolRes.getValues()) && exPolRes.getValues().indexOf("*") >= 0) {
-                            isAllResources = true;
-                        }
-                    }
+	private void createOrUpdatePolicy(RangerPolicy exPolicy) {
+		// Filter policy items which are eligible for admin,config and schema resources
+		final List<RangerPolicy.RangerPolicyItem> filteredAllowPolciyItems = filterPolicyItemsForAdminPermission(exPolicy.getPolicyItems());
+		final List<RangerPolicy.RangerPolicyItem> filteredAllowExcpPolItems = filterPolicyItemsForAdminPermission(exPolicy.getAllowExceptions());
+		final List<RangerPolicy.RangerPolicyItem> filteredDenyPolItems = filterPolicyItemsForAdminPermission(exPolicy.getDenyPolicyItems());
+		final List<RangerPolicy.RangerPolicyItem> filteredDenyExcpPolItems = filterPolicyItemsForAdminPermission(exPolicy.getDenyExceptions());
 
-                    newPolicyForNewResource.setPolicyItems(filteredAllowPolciyItems);
-                    newPolicyForNewResource.setAllowExceptions(filteredAllowExcpPolItems);
-                    newPolicyForNewResource.setDenyPolicyItems(filteredDenyPolItems);
-                    newPolicyForNewResource.setDenyExceptions(filteredDenyExcpPolItems);
-                    newPolicyForNewResource.setOptions(exPolicy.getOptions());
-                    newPolicyForNewResource.setValiditySchedules(exPolicy.getValiditySchedules());
-                    newPolicyForNewResource.setPolicyLabels(exPolicy.getPolicyLabels());
-                    newPolicyForNewResource.setConditions(exPolicy.getConditions());
-                    newPolicyForNewResource.setIsDenyAllElse(exPolicy.getIsDenyAllElse());
-                    newPolicyForNewResource.setZoneName(exPolicy.getZoneName());
+		// check if there is a need to create additional policies with
+		// admin/config/schema resource(s)
+		final boolean splitPolicy = (filteredAllowPolciyItems.size() > 0 || filteredAllowExcpPolItems.size() > 0 || filteredDenyPolItems.size() > 0 || filteredDenyExcpPolItems.size() > 0);
+		if (splitPolicy) {
+			RangerPolicy newPolicyForNewResource = new RangerPolicy();
+			newPolicyForNewResource.setService(exPolicy.getService());
+			newPolicyForNewResource.setServiceType(exPolicy.getServiceType());
+			newPolicyForNewResource.setPolicyPriority(exPolicy.getPolicyPriority());
 
-                    try {
-                        if (isAllResources) {
-                            for (NEW_RESOURCE resType : NEW_RESOURCE.values()) {
-                                createNewPolicy(resType.name(), newPolicyForNewResource, newRes, exPolicy.getName());
-                            }
-                        } else {
-                            createNewPolicy(NEW_RESOURCE.schema.name(), newPolicyForNewResource, newRes, exPolicy.getName());
-                        }
+			RangerPolicyResource newRes = new RangerPolicyResource();
+			boolean isAllResources = false;
+			// Only one entry expected
+			for (Map.Entry<String, RangerPolicyResource> entry : exPolicy.getResources().entrySet()) {
+				RangerPolicyResource exPolRes = entry.getValue();
+				newRes.setIsExcludes(exPolRes.getIsExcludes());
+				newRes.setIsRecursive(exPolRes.getIsRecursive());
+				newRes.setValues(exPolRes.getValues());
+				if (CollectionUtils.isNotEmpty(exPolRes.getValues()) && exPolRes.getValues().indexOf("*") >= 0) {
+					isAllResources = true;
+				}
+			}
 
-                    } catch (Exception e) {
-                        logger.error("Failed to apply the patch, Error Msg - " + e.getCause());
-                        e.printStackTrace();
-                        System.exit(1);
-                    }
-                }
-                try {
-                    // update policy items
-                    updateResPolicyItemAccess(exPolicy.getPolicyItems());
-                    updateResPolicyItemAccess(exPolicy.getAllowExceptions());
-                    updateResPolicyItemAccess(exPolicy.getDenyPolicyItems());
-                    updateResPolicyItemAccess(exPolicy.getDenyExceptions());
-                    this.svcDBStore.updatePolicy(exPolicy);
-                } catch (Exception e) {
-                    logger.error("Failed to apply the patch, Error - " + e.getCause());
-                    e.printStackTrace();
-                    System.exit(1);
-                }
-            }
-        }
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateResPolicies(...)");
-    }
+			newPolicyForNewResource.setPolicyItems(filteredAllowPolciyItems);
+			newPolicyForNewResource.setAllowExceptions(filteredAllowExcpPolItems);
+			newPolicyForNewResource.setDenyPolicyItems(filteredDenyPolItems);
+			newPolicyForNewResource.setDenyExceptions(filteredDenyExcpPolItems);
+			newPolicyForNewResource.setOptions(exPolicy.getOptions());
+			newPolicyForNewResource.setValiditySchedules(exPolicy.getValiditySchedules());
+			newPolicyForNewResource.setPolicyLabels(exPolicy.getPolicyLabels());
+			newPolicyForNewResource.setConditions(exPolicy.getConditions());
+			newPolicyForNewResource.setIsDenyAllElse(exPolicy.getIsDenyAllElse());
+			newPolicyForNewResource.setZoneName(exPolicy.getZoneName());
+			newPolicyForNewResource.setIsEnabled(exPolicy.getIsEnabled());
+			newPolicyForNewResource.setIsAuditEnabled(exPolicy.getIsAuditEnabled());
+			newPolicyForNewResource.setPolicyType(exPolicy.getPolicyType());
+
+			try {
+				if (isAllResources) {
+					for (NEW_RESOURCE resType : NEW_RESOURCE.values()) {
+						createNewPolicy(resType.name(), newPolicyForNewResource, newRes, exPolicy.getName());
+					}
+				} else {
+					createNewPolicy(NEW_RESOURCE.schema.name(), newPolicyForNewResource, newRes, exPolicy.getName());
+				}
+
+			} catch (Exception e) {
+				throw new RuntimeException(e);
+			}
+		}
+		try {
+			// update policy items
+			updateResPolicyItemAccess(exPolicy.getPolicyItems());
+			updateResPolicyItemAccess(exPolicy.getAllowExceptions());
+			updateResPolicyItemAccess(exPolicy.getDenyPolicyItems());
+			updateResPolicyItemAccess(exPolicy.getDenyExceptions());
+			this.svcDBStore.updatePolicy(exPolicy);
+		} catch (Exception e) {
+			throw new RuntimeException(e);
+		}
+	}
 
     private void createNewPolicy(final String resType, final RangerPolicy newPolicy, final RangerPolicyResource newRes, final String exPolicyName) throws Exception {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.createNewPolicy(...)");
         final String newPolicyName = resType + " - '" + exPolicyName + "'";
         newPolicy.setName(newPolicyName);
         newPolicy.setDescription(newPolicyName);
@@ -330,12 +409,13 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
         newPolicy.setResources(resForNewPol);
         newPolicy.setResourceSignature(null);
         newPolicy.setGuid(null);
+        if (logger.isDebugEnabled()) {
+            logger.debug("newPolicy:"+newPolicy);
+        }
         this.svcDBStore.createPolicy(newPolicy);
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.createNewPolicy(...)");
     }
 
     private void updateResPolicyItemAccess(List<RangerPolicyItem> policyItems) {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateResPolicyItemAccess(...)");
         Set<RangerPolicyItemAccess>         newRangerPolicyItemAccess = new HashSet<RangerPolicyItemAccess>();
         if (CollectionUtils.isNotEmpty(policyItems)) {
             for (RangerPolicyItem exPolicyItem : policyItems) {
@@ -365,11 +445,9 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
                 }
             }
         }
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateResPolicyItemAccess(...)");
     }
 
     private void updateTagPolicyItemAccess(List<RangerPolicyItem> policyItems) {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateTagPolicyItemAccess(...)");
         List<RangerPolicy.RangerPolicyItem> newPolicyItems            = new ArrayList<RangerPolicy.RangerPolicyItem>();
         Set<RangerPolicyItemAccess>         newRangerPolicyItemAccess = new HashSet<RangerPolicyItemAccess>();
         if (CollectionUtils.isNotEmpty(policyItems)) {
@@ -402,11 +480,9 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
                 }
             }
         }
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateTagPolicyItemAccess(...)");
     }
 
     private List<RangerPolicy.RangerPolicyItem> filterPolicyItemsForAdminPermission(List<RangerPolicy.RangerPolicyItem> policyItems) {
-        logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.filterPolicyItemsForAdminPermission(...)");
         // Add only those policy items who's access permission list contains 'solr_admin' permission
         List<RangerPolicy.RangerPolicyItem> filteredPolicyItems       = new ArrayList<RangerPolicy.RangerPolicyItem>();
         Set<RangerPolicyItemAccess>         newRangerPolicyItemAccess = new HashSet<RangerPolicyItemAccess>();
@@ -419,7 +495,6 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
                 filteredPolicyItems.add(newPolicyItem);
             }
         }));
-        logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.filterPolicyItemsForAdminPermission(...)");
         return filteredPolicyItems;
     }
 
@@ -436,7 +511,7 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
                 xXServiceDefObj = daoMgr.getXXServiceDef().findByName(SOLR_SVC_DEF_NAME);
                 if (xXServiceDefObj == null) {
                     logger.info(xXServiceDefObj + ": service-def not found. No patching is needed");
-                    System.out.println(0);
+                    System.exit(0);
                 }
 
                 embeddedSolrResourceDefs = embeddedSolrServiceDef.getResources();                 // ResourcesType
@@ -449,6 +524,7 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
             }
         } catch (Exception e) {
             logger.error("Error while updating " + SOLR_SVC_DEF_NAME + " service-def", e);
+            throw new RuntimeException(e);
         }
         logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateSolrSvcDef()");
         return ret;
@@ -479,6 +555,40 @@ public class PatchForSolrSvcDefAndPoliciesUpdate_J10055 extends BaseLoader {
         logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.deleteOldAccessTypeRefs(" + svcDefId + ")");
     }
 
+	private void updateServiceConfig(final XXService dbService) throws Exception {
+		logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateServiceConfig()");
+		final RangerService rangerSvc = this.svcDBStore.getService(dbService.getId());
+		final Map<String, String> configMap = rangerSvc != null ? rangerSvc.getConfigs() : null;
+		Set<String> accessTypeSet = new HashSet<String>();
+
+		if (MapUtils.isNotEmpty(configMap)) {
+			for (final Map.Entry<String, String> entry : configMap.entrySet()) {
+				final String configKey = entry.getKey();
+				final String configValue = entry.getValue();
+				accessTypeSet = new HashSet<String>();
+				if (StringUtils.endsWith(configKey, SVC_ACCESS_TYPE_CONFIG_SUFFIX) && StringUtils.isNotEmpty(configValue)) {
+					final String[] accessTypeArray = configValue.split(",");
+					for (String access : accessTypeArray) {
+						if (!ACCESS_TYPE_OTHERS.equalsIgnoreCase(access) && !ACCESS_TYPE_ADMIN.equalsIgnoreCase(access)) {
+							accessTypeSet.add(access);
+						} else {
+							if (ACCESS_TYPE_ADMIN.equalsIgnoreCase(access)) {
+								accessTypeSet.add(ACCESS_TYPE_QUERY);
+								accessTypeSet.add(ACCESS_TYPE_UPDATE);
+							} else if (ACCESS_TYPE_OTHERS.equalsIgnoreCase(access)) {
+								accessTypeSet.add(ACCESS_TYPE_QUERY);
+							}
+						}
+					}
+					configMap.put(configKey, StringUtils.join(accessTypeSet, ","));
+				}
+			}
+			rangerSvc.setConfigs(configMap);
+			this.svcDBStore.updateService(rangerSvc, null);
+		}
+		logger.info("<== PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateServiceConfig()");
+	}
+
 	private void updateDefaultAuditFilter(final String svcDefName) throws Exception {
 		logger.info("==> PatchForSolrSvcDefAndPoliciesUpdate_J10055.updateAtlasDefaultAuditFilter()");
 		final RangerServiceDef embeddedAtlasServiceDef = EmbeddedServiceDefsUtil.instance()
