@@ -59,9 +59,9 @@ public class ServiceRESTUtil {
 		RangerPolicy.RangerPolicyItem policyItem = new RangerPolicy.RangerPolicyItem();
 
 		policyItem.setDelegateAdmin(grantRequest.getDelegateAdmin());
-		policyItem.getUsers().addAll(grantRequest.getUsers());
-		policyItem.getGroups().addAll(grantRequest.getGroups());
-		policyItem.getRoles().addAll(grantRequest.getRoles());
+		policyItem.addUsers(grantRequest.getUsers());
+		policyItem.addGroups(grantRequest.getGroups());
+		policyItem.addRoles(grantRequest.getRoles());
 
 		List<RangerPolicy.RangerPolicyItemAccess> accesses = new ArrayList<RangerPolicy.RangerPolicyItemAccess>();
 
@@ -72,7 +72,7 @@ public class ServiceRESTUtil {
 
 		policyItem.setAccesses(accesses);
 
-		appliedPolicy.getPolicyItems().add(policyItem);
+		appliedPolicy.addPolicyItem(policyItem);
 
 		processApplyPolicy(policy, appliedPolicy);
 
@@ -102,9 +102,9 @@ public class ServiceRESTUtil {
 			RangerPolicy.RangerPolicyItem appliedRangerPolicyItem = new RangerPolicy.RangerPolicyItem();
 
 			appliedRangerPolicyItem.setDelegateAdmin(revokeRequest.getDelegateAdmin());
-			appliedRangerPolicyItem.getUsers().addAll(revokeRequest.getUsers());
-			appliedRangerPolicyItem.getGroups().addAll(revokeRequest.getGroups());
-			appliedRangerPolicyItem.getRoles().addAll(revokeRequest.getRoles());
+			appliedRangerPolicyItem.addUsers(revokeRequest.getUsers());
+			appliedRangerPolicyItem.addGroups(revokeRequest.getGroups());
+			appliedRangerPolicyItem.addRoles(revokeRequest.getRoles());
 
 			List<RangerPolicy.RangerPolicyItemAccess> appliedRangerPolicyItemAccess = new ArrayList<RangerPolicy.RangerPolicyItemAccess>();
 
@@ -115,7 +115,7 @@ public class ServiceRESTUtil {
 
 			appliedRangerPolicyItem.setAccesses(appliedRangerPolicyItemAccess);
 
-			appliedRangerPolicy.getPolicyItems().add(appliedRangerPolicyItem);
+			appliedRangerPolicy.addPolicyItem(appliedRangerPolicyItem);
 
 			List<RangerPolicy.RangerPolicyItem> appliedRangerPolicyItems = appliedRangerPolicy.getPolicyItems();
 			//processApplyPolicyForItemType(existingRangerPolicy, appliedRangerPolicy, POLICYITEM_TYPE.ALLOW);
@@ -219,9 +219,7 @@ public class ServiceRESTUtil {
 		if (ServiceRESTUtil.containsRangerCondition(existingPolicy) || ServiceRESTUtil.containsRangerCondition(appliedPolicy)) {
 			LOG.info("Applied policy [" + appliedPolicy + "] or existing policy [" + existingPolicy + "] contains condition(s). Combining two policies.");
 			combinePolicy(existingPolicy, appliedPolicy);
-
 		} else {
-
 			processApplyPolicyForItemType(existingPolicy, appliedPolicy, POLICYITEM_TYPE.ALLOW);
 			processApplyPolicyForItemType(existingPolicy, appliedPolicy, POLICYITEM_TYPE.DENY);
 			processApplyPolicyForItemType(existingPolicy, appliedPolicy, POLICYITEM_TYPE.ALLOW_EXCEPTIONS);
@@ -234,33 +232,65 @@ public class ServiceRESTUtil {
 	}
 
 	static private void combinePolicy(RangerPolicy existingPolicy, RangerPolicy appliedPolicy) {
+		combinePolicyItems(existingPolicy, appliedPolicy, POLICYITEM_TYPE.ALLOW);
+		combinePolicyItems(existingPolicy, appliedPolicy, POLICYITEM_TYPE.DENY);
+		combinePolicyItems(existingPolicy, appliedPolicy, POLICYITEM_TYPE.ALLOW_EXCEPTIONS);
+		combinePolicyItems(existingPolicy, appliedPolicy, POLICYITEM_TYPE.DENY_EXCEPTIONS);
+	}
 
+	static private void combinePolicyItems(RangerPolicy existingPolicy, RangerPolicy appliedPolicy, POLICYITEM_TYPE polityItemType) {
+		List<RangerPolicy.RangerPolicyItem> existingPolicyItems;
 		List<RangerPolicy.RangerPolicyItem> appliedPolicyItems;
 
-		// Combine allow policy-items
-		appliedPolicyItems = appliedPolicy.getPolicyItems();
-		if (CollectionUtils.isNotEmpty(appliedPolicyItems)) {
-			existingPolicy.getPolicyItems().addAll(appliedPolicyItems);
+		switch (polityItemType) {
+			case ALLOW:
+				existingPolicyItems = existingPolicy.getPolicyItems();
+				appliedPolicyItems = appliedPolicy.getPolicyItems();
+				break;
+			case DENY:
+				existingPolicyItems = existingPolicy.getDenyPolicyItems();
+				appliedPolicyItems = appliedPolicy.getDenyPolicyItems();
+				break;
+			case ALLOW_EXCEPTIONS:
+				existingPolicyItems = existingPolicy.getAllowExceptions();
+				appliedPolicyItems = appliedPolicy.getAllowExceptions();
+				break;
+			case DENY_EXCEPTIONS:
+				existingPolicyItems = existingPolicy.getDenyExceptions();
+				appliedPolicyItems = appliedPolicy.getDenyExceptions();
+				break;
+			default:
+				existingPolicyItems = null;
+				appliedPolicyItems = null;
+				break;
 		}
 
-		// Combine deny policy-items
-		appliedPolicyItems = appliedPolicy.getDenyPolicyItems();
 		if (CollectionUtils.isNotEmpty(appliedPolicyItems)) {
-			existingPolicy.getDenyPolicyItems().addAll(appliedPolicyItems);
+			if (CollectionUtils.isNotEmpty(existingPolicyItems)) {
+				List<RangerPolicy.RangerPolicyItem> itemsToAdd = new ArrayList<>();
+				for (RangerPolicy.RangerPolicyItem appliedPolicyItem : appliedPolicyItems) {
+					if (!existingPolicyItems.contains(appliedPolicyItem)) {
+						itemsToAdd.add(appliedPolicyItem);
+					}
+				}
+				existingPolicyItems.addAll(itemsToAdd);
+			} else {
+				switch (polityItemType) {
+					case ALLOW:
+						existingPolicy.setPolicyItems(appliedPolicyItems);
+						break;
+					case DENY:
+						existingPolicy.setDenyPolicyItems(appliedPolicyItems);
+						break;
+					case ALLOW_EXCEPTIONS:
+						existingPolicy.setAllowExceptions(appliedPolicyItems);
+						break;
+					case DENY_EXCEPTIONS:
+						existingPolicy.setDenyExceptions(appliedPolicyItems);
+						break;
+				}
+			}
 		}
-
-		// Combine allow-exception policy-items
-		appliedPolicyItems = appliedPolicy.getAllowExceptions();
-		if (CollectionUtils.isNotEmpty(appliedPolicyItems)) {
-			existingPolicy.getAllowExceptions().addAll(appliedPolicyItems);
-		}
-
-		// Combine deny-exception policy-items
-		appliedPolicyItems = appliedPolicy.getDenyExceptions();
-		if (CollectionUtils.isNotEmpty(appliedPolicyItems)) {
-			existingPolicy.getDenyExceptions().addAll(appliedPolicyItems);
-		}
-
 	}
 
 	static private void processApplyPolicyForItemType(RangerPolicy existingPolicy, RangerPolicy appliedPolicy, POLICYITEM_TYPE policyItemType) {
@@ -498,7 +528,7 @@ public class ServiceRESTUtil {
 					if (ret == null) {
 						ret = new RangerPolicy.RangerPolicyItem();
 					}
-					ret.getUsers().add(user);
+					ret.addUser(user);
 					if (policyItem.getDelegateAdmin()) {
 						ret.setDelegateAdmin(Boolean.TRUE);
 					}
@@ -531,7 +561,7 @@ public class ServiceRESTUtil {
 					if (ret == null) {
 						ret = new RangerPolicy.RangerPolicyItem();
 					}
-					ret.getGroups().add(group);
+					ret.addGroup(group);
 					if (policyItem.getDelegateAdmin()) {
 						ret.setDelegateAdmin(Boolean.TRUE);
 					}
@@ -564,7 +594,7 @@ public class ServiceRESTUtil {
 					if (ret == null) {
 						ret = new RangerPolicy.RangerPolicyItem();
 					}
-					ret.getRoles().add(role);
+					ret.addRole(role);
 					if (policyItem.getDelegateAdmin()) {
 						ret.setDelegateAdmin(Boolean.TRUE);
 					}
@@ -592,32 +622,39 @@ public class ServiceRESTUtil {
 		for (RangerPolicy.RangerPolicyItem policyItem : appliedPolicyItems) {
 			List<String> users = policyItem.getUsers();
 			for (String user : users) {
-				RangerPolicy.RangerPolicyItem[] items = existingUserPolicyItems.get(user);
+				RangerPolicy.RangerPolicyItem[] existingPolicyItems = existingUserPolicyItems.get(user);
 
-				if (items == null) {
+				if (existingPolicyItems == null) {
 					// Should not get here
 					LOG.warn("Should not have come here..");
-					items = new RangerPolicy.RangerPolicyItem[4];
-					existingUserPolicyItems.put(user, items);
+					existingPolicyItems = new RangerPolicy.RangerPolicyItem[4];
+					existingUserPolicyItems.put(user, existingPolicyItems);
 				}
 
-				addPolicyItemForUser(items, policyItemType.ordinal(), user, policyItem);
+				addPolicyItemForUser(existingPolicyItems, policyItemType.ordinal(), user, policyItem);
 
 				switch (policyItemType) {
 					case ALLOW:
-						removeAccesses(items[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
-						addPolicyItemForUser(items, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), user, policyItem);
+						RangerPolicy.RangerPolicyItem denyPolicyItem = existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()];
+						if (denyPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
+							addPolicyItemForUser(existingPolicyItems, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), user, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
-						addPolicyItemForUser(items, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), user, policyItem);
-						removeAccesses(items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
+						RangerPolicy.RangerPolicyItem allowPolicyItem = existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()];
+						if (allowPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+							addPolicyItemForUser(existingPolicyItems, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), user, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case ALLOW_EXCEPTIONS:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY_EXCEPTIONS:
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
 						break;
 					default:
 						LOG.warn("Should not have come here..");
@@ -629,31 +666,38 @@ public class ServiceRESTUtil {
 		for (RangerPolicy.RangerPolicyItem policyItem : appliedPolicyItems) {
 			List<String> groups = policyItem.getGroups();
 			for (String group : groups) {
-				RangerPolicy.RangerPolicyItem[] items = existingGroupPolicyItems.get(group);
+				RangerPolicy.RangerPolicyItem[] existingPolicyItems = existingGroupPolicyItems.get(group);
 
-				if (items == null) {
+				if (existingPolicyItems == null) {
 					// Should not get here
-					items = new RangerPolicy.RangerPolicyItem[4];
-					existingGroupPolicyItems.put(group, items);
+					existingPolicyItems = new RangerPolicy.RangerPolicyItem[4];
+					existingGroupPolicyItems.put(group, existingPolicyItems);
 				}
 
-				addPolicyItemForGroup(items, policyItemType.ordinal(), group, policyItem);
+				addPolicyItemForGroup(existingPolicyItems, policyItemType.ordinal(), group, policyItem);
 
 				switch (policyItemType) {
 					case ALLOW:
-						removeAccesses(items[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
-						addPolicyItemForGroup(items, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), group, policyItem);
+						RangerPolicy.RangerPolicyItem denyPolicyItem = existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()];
+						if (denyPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
+							addPolicyItemForGroup(existingPolicyItems, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), group, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
-						addPolicyItemForGroup(items, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), group, policyItem);
-						removeAccesses(items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
+						RangerPolicy.RangerPolicyItem allowPolicyItem = existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()];
+						if (allowPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+							addPolicyItemForGroup(existingPolicyItems, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), group, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case ALLOW_EXCEPTIONS:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY_EXCEPTIONS:
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
 						break;
 					default:
 						break;
@@ -664,31 +708,38 @@ public class ServiceRESTUtil {
 		for (RangerPolicy.RangerPolicyItem policyItem : appliedPolicyItems) {
 			List<String> roles = policyItem.getRoles();
 			for (String role : roles) {
-				RangerPolicy.RangerPolicyItem[] items = existingRolePolicyItems.get(role);
+				RangerPolicy.RangerPolicyItem[] existingPolicyItems = existingRolePolicyItems.get(role);
 
-				if (items == null) {
+				if (existingPolicyItems == null) {
 					// Should not get here
-					items = new RangerPolicy.RangerPolicyItem[4];
-					existingRolePolicyItems.put(role, items);
+					existingPolicyItems = new RangerPolicy.RangerPolicyItem[4];
+					existingRolePolicyItems.put(role, existingPolicyItems);
 				}
 
-				addPolicyItemForRole(items, policyItemType.ordinal(), role, policyItem);
+				addPolicyItemForRole(existingPolicyItems, policyItemType.ordinal(), role, policyItem);
 
 				switch (policyItemType) {
 					case ALLOW:
-						removeAccesses(items[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
-						addPolicyItemForRole(items, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), role, policyItem);
+						RangerPolicy.RangerPolicyItem denyPolicyItem = existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()];
+						if (denyPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
+							addPolicyItemForRole(existingPolicyItems, POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal(), role, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
-						addPolicyItemForRole(items, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), role, policyItem);
-						removeAccesses(items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
+						RangerPolicy.RangerPolicyItem allowPolicyItem = existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()];
+						if (allowPolicyItem != null) {
+							removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+							addPolicyItemForRole(existingPolicyItems, POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal(), role, policyItem);
+						}
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()], policyItem.getAccesses());
 						break;
 					case ALLOW_EXCEPTIONS:
-						removeAccesses(items[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.ALLOW.ordinal()], policyItem.getAccesses());
 						break;
 					case DENY_EXCEPTIONS:
+						removeAccesses(existingPolicyItems[POLICYITEM_TYPE.DENY.ordinal()], policyItem.getAccesses());
 						break;
 					default:
 						break;
@@ -767,22 +818,22 @@ public class ServiceRESTUtil {
 
 			item = items[POLICYITEM_TYPE.ALLOW.ordinal()];
 			if (item != null) {
-				existingPolicy.getPolicyItems().add(item);
+				existingPolicy.addPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyPolicyItems().add(item);
+				existingPolicy.addDenyPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getAllowExceptions().add(item);
+				existingPolicy.addAllowException(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyExceptions().add(item);
+				existingPolicy.addDenyException(item);
 			}
 		}
 
@@ -793,22 +844,22 @@ public class ServiceRESTUtil {
 
 			item = items[POLICYITEM_TYPE.ALLOW.ordinal()];
 			if (item != null) {
-				existingPolicy.getPolicyItems().add(item);
+				existingPolicy.addPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyPolicyItems().add(item);
+				existingPolicy.addDenyPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getAllowExceptions().add(item);
+				existingPolicy.addAllowException(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyExceptions().add(item);
+				existingPolicy.addDenyException(item);
 			}
 		}
 
@@ -819,22 +870,22 @@ public class ServiceRESTUtil {
 
 			item = items[POLICYITEM_TYPE.ALLOW.ordinal()];
 			if (item != null) {
-				existingPolicy.getPolicyItems().add(item);
+				existingPolicy.addPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyPolicyItems().add(item);
+				existingPolicy.addDenyPolicyItem(item);
 			}
 
 			item = items[POLICYITEM_TYPE.ALLOW_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getAllowExceptions().add(item);
+				existingPolicy.addAllowException(item);
 			}
 
 			item = items[POLICYITEM_TYPE.DENY_EXCEPTIONS.ordinal()];
 			if (item != null) {
-				existingPolicy.getDenyExceptions().add(item);
+				existingPolicy.addDenyException(item);
 			}
 		}
 
@@ -867,7 +918,7 @@ public class ServiceRESTUtil {
 					ret = true;
 				}
 			} else {
-				policyItem.getAccesses().add(new RangerPolicy.RangerPolicyItemAccess(accessType, Boolean.TRUE));
+				policyItem.addAccess(new RangerPolicy.RangerPolicyItemAccess(accessType, Boolean.TRUE));
 				ret = true;
 			}
 		}
@@ -947,9 +998,9 @@ public class ServiceRESTUtil {
 				RangerPolicy.RangerPolicyItem matchingPolicyItem = matchedPolicyItems.get(allAccessesString);
 
 				if (matchingPolicyItem != null) {
-					addDistinctItems(policyItem.getUsers(), matchingPolicyItem.getUsers());
-					addDistinctItems(policyItem.getGroups(), matchingPolicyItem.getGroups());
-					addDistinctItems(policyItem.getRoles(), matchingPolicyItem.getRoles());
+					addDistinctUsers(policyItem.getUsers(), matchingPolicyItem);
+					addDistinctGroups(policyItem.getGroups(), matchingPolicyItem);
+					addDistinctRoles(policyItem.getRoles(), matchingPolicyItem);
 				} else {
 					matchedPolicyItems.put(allAccessesString, policyItem);
 				}
@@ -967,7 +1018,7 @@ public class ServiceRESTUtil {
 
 		if (items[typeOfItems] == null) {
 			RangerPolicy.RangerPolicyItem newItem = new RangerPolicy.RangerPolicyItem();
-			newItem.getUsers().add(user);
+			newItem.addUser(user);
 
 			items[typeOfItems] = newItem;
 		}
@@ -983,7 +1034,7 @@ public class ServiceRESTUtil {
 
 		if (items[typeOfItems] == null) {
 			RangerPolicy.RangerPolicyItem newItem = new RangerPolicy.RangerPolicyItem();
-			newItem.getGroups().add(group);
+			newItem.addGroup(group);
 
 			items[typeOfItems] = newItem;
 		}
@@ -999,7 +1050,7 @@ public class ServiceRESTUtil {
 
 		if (items[typeOfItems] == null) {
 			RangerPolicy.RangerPolicyItem newItem = new RangerPolicy.RangerPolicyItem();
-			newItem.getRoles().add(role);
+			newItem.addRole(role);
 
 			items[typeOfItems] = newItem;
 		}
@@ -1011,10 +1062,26 @@ public class ServiceRESTUtil {
 		}
 	}
 
-	static private void addDistinctItems(List<String> fromItems, List<String> toItems) {
-		for (String fromItem : fromItems) {
-			if (! toItems.contains(fromItem)) {
-				toItems.add(fromItem);
+	static private void addDistinctUsers(List<String> users, RangerPolicy.RangerPolicyItem policyItem) {
+		for (String user : users) {
+			if (! policyItem.getUsers().contains(user)) {
+				policyItem.addUser(user);
+			}
+		}
+	}
+
+	static private void addDistinctGroups(List<String> groups, RangerPolicy.RangerPolicyItem policyItem) {
+		for (String group : groups) {
+			if (! policyItem.getGroups().contains(group)) {
+				policyItem.addGroup(group);
+			}
+		}
+	}
+
+	static private void addDistinctRoles(List<String> roles, RangerPolicy.RangerPolicyItem policyItem) {
+		for (String role : roles) {
+			if (! policyItem.getRoles().contains(role)) {
+				policyItem.addRole(role);
 			}
 		}
 	}
