@@ -23,12 +23,16 @@ public class TagRESTConstants {
 	public static final String TAGDEF_NAME_AND_VERSION = "tags";
 
 	static final String TAGDEFS_RESOURCE         = "/tagdefs/";
+	static final String TAGDEFS_RESOURCE_PAGINATED = "/tagdefs/paginated";
 	static final String TAGDEF_RESOURCE          = "/tagdef/";
 	static final String TAGS_RESOURCE            = "/tags/";
+	static final String TAGS_RESOURCE_PAGINATED  = "/tags/paginated";
 	static final String TAG_RESOURCE             = "/tag/";
 	static final String RESOURCES_RESOURCE       = "/resources/";
+	static final String RESOURCES_RESOURCE_PAGINATED = "/resources/paginated";
 	static final String RESOURCE_RESOURCE        = "/resource/";
 	static final String TAGRESOURCEMAPS_RESOURCE = "/tagresourcemaps/";
+	static final String TAGRESOURCEMAPS_RESOURCE_PAGINATED = "/tagresourcemaps/paginated";
 	static final String IMPORT_SERVICETAGS_RESOURCE = "/importservicetags/";
 	static final String TAGRESOURCEMAP_RESOURCE  = "/tagresourcemap/";
 	static final String TAGTYPES_RESOURCE        = "/types/";
