@@ -97,13 +97,13 @@ public class RangerAPIMapping {
 		apiAssociatedWithReports.add(RangerAPIList.GET_SERVICE_DEF_BY_NAME);
 		apiAssociatedWithReports.add(RangerAPIList.GET_SERVICE_DEFS);
 		apiAssociatedWithReports.add(RangerAPIList.GET_SERVICES);
+		apiAssociatedWithReports.add(RangerAPIList.GET_SERVICE_HEADERS);
 		apiAssociatedWithReports.add(RangerAPIList.LOOKUP_RESOURCE);
 
 		apiAssociatedWithReports.add(RangerAPIList.GET_USER_PROFILE_FOR_USER);
 		apiAssociatedWithReports.add(RangerAPIList.SEARCH_USERS);
 
 		apiAssociatedWithReports.add(RangerAPIList.COUNT_X_AUDIT_MAPS);
-		apiAssociatedWithReports.add(RangerAPIList.COUNT_X_GROUP_GROUPS);
 		apiAssociatedWithReports.add(RangerAPIList.COUNT_X_GROUPS);
 		apiAssociatedWithReports.add(RangerAPIList.COUNT_X_GROUP_USERS);
 		apiAssociatedWithReports.add(RangerAPIList.COUNT_X_PERM_MAPS);
@@ -111,7 +111,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_AUDIT_MAP);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_GROUP);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_GROUP_BY_GROUP_NAME);
-		apiAssociatedWithReports.add(RangerAPIList.GET_X_GROUP_GROUP);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_GROUP_USER);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_GROUP_USERS);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_PERM_MAP);
@@ -119,7 +118,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_USER_BY_USER_NAME);
 		apiAssociatedWithReports.add(RangerAPIList.GET_X_USER_GROUPS);
 		apiAssociatedWithReports.add(RangerAPIList.SEARCH_X_AUDIT_MAPS);
-		apiAssociatedWithReports.add(RangerAPIList.SEARCH_X_GROUP_GROUPS);
 		apiAssociatedWithReports.add(RangerAPIList.SEARCH_X_GROUPS);
 		apiAssociatedWithReports.add(RangerAPIList.SEARCH_X_GROUP_USERS);
 		apiAssociatedWithReports.add(RangerAPIList.SEARCH_X_PERM_MAPS);
@@ -162,6 +160,7 @@ public class RangerAPIMapping {
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_SERVICE_DEF_BY_NAME);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_SERVICE_DEFS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_SERVICES);
+		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_SERVICE_HEADERS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.LOOKUP_RESOURCE);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.UPDATE_SERVICE);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.UPDATE_SERVICE_DEF);
@@ -171,7 +170,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_USERS);
 
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.COUNT_X_AUDIT_MAPS);
-		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.COUNT_X_GROUP_GROUPS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.COUNT_X_GROUPS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.COUNT_X_GROUP_USERS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.COUNT_X_PERM_MAPS);
@@ -183,7 +181,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_AUDIT_MAP);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_GROUP);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_GROUP_BY_GROUP_NAME);
-		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_GROUP_GROUP);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_GROUP_USER);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_GROUP_USERS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.GET_X_PERM_MAP);
@@ -194,7 +191,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.MODIFY_USER_ACTIVE_STATUS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.MODIFY_USER_VISIBILITY);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_X_AUDIT_MAPS);
-		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_X_GROUP_GROUPS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_X_GROUPS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_X_GROUP_USERS);
 		apiAssociatedWithTagBasedPolicy.add(RangerAPIList.SEARCH_X_PERM_MAPS);
@@ -246,6 +242,7 @@ public class RangerAPIMapping {
 		apiAssociatedWithKeyManager.add(RangerAPIList.GET_SERVICE_DEF_BY_NAME);
 		apiAssociatedWithKeyManager.add(RangerAPIList.GET_SERVICE_DEFS);
 		apiAssociatedWithKeyManager.add(RangerAPIList.GET_SERVICES);
+		apiAssociatedWithKeyManager.add(RangerAPIList.GET_SERVICE_HEADERS);
 		apiAssociatedWithKeyManager.add(RangerAPIList.LOOKUP_RESOURCE);
 		apiAssociatedWithKeyManager.add(RangerAPIList.UPDATE_SERVICE);
 		apiAssociatedWithKeyManager.add(RangerAPIList.UPDATE_SERVICE_DEF);
@@ -307,7 +304,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_USERS);
 
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.COUNT_X_AUDIT_MAPS);
-		apiAssociatedWithUserAndGroups.add(RangerAPIList.COUNT_X_GROUP_GROUPS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.COUNT_X_GROUPS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.COUNT_X_GROUP_USERS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.COUNT_X_PERM_MAPS);
@@ -319,7 +315,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_AUDIT_MAP);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_GROUP);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_GROUP_BY_GROUP_NAME);
-		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_GROUP_GROUP);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_GROUP_USER);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_GROUP_USERS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.GET_X_PERM_MAP);
@@ -330,7 +325,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.MODIFY_USER_ACTIVE_STATUS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.MODIFY_USER_VISIBILITY);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_X_AUDIT_MAPS);
-		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_X_GROUP_GROUPS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_X_GROUPS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_X_GROUP_USERS);
 		apiAssociatedWithUserAndGroups.add(RangerAPIList.SEARCH_X_PERM_MAPS);
@@ -379,13 +373,13 @@ public class RangerAPIMapping {
 		apiAssociatedWithAudit.add(RangerAPIList.GET_SERVICE_DEF_BY_NAME);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_SERVICE_DEFS);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_SERVICES);
+		apiAssociatedWithAudit.add(RangerAPIList.GET_SERVICE_HEADERS);
 		apiAssociatedWithAudit.add(RangerAPIList.LOOKUP_RESOURCE);
 
 		apiAssociatedWithAudit.add(RangerAPIList.GET_USER_PROFILE_FOR_USER);
 		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_USERS);
 
 		apiAssociatedWithAudit.add(RangerAPIList.COUNT_X_AUDIT_MAPS);
-		apiAssociatedWithAudit.add(RangerAPIList.COUNT_X_GROUP_GROUPS);
 		apiAssociatedWithAudit.add(RangerAPIList.COUNT_X_GROUPS);
 		apiAssociatedWithAudit.add(RangerAPIList.COUNT_X_GROUP_USERS);
 		apiAssociatedWithAudit.add(RangerAPIList.COUNT_X_PERM_MAPS);
@@ -393,7 +387,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_AUDIT_MAP);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_GROUP);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_GROUP_BY_GROUP_NAME);
-		apiAssociatedWithAudit.add(RangerAPIList.GET_X_GROUP_GROUP);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_GROUP_USER);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_GROUP_USERS);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_PERM_MAP);
@@ -401,7 +394,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_USER_BY_USER_NAME);
 		apiAssociatedWithAudit.add(RangerAPIList.GET_X_USER_GROUPS);
 		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_X_AUDIT_MAPS);
-		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_X_GROUP_GROUPS);
 		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_X_GROUPS);
 		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_X_GROUP_USERS);
 		apiAssociatedWithAudit.add(RangerAPIList.SEARCH_X_PERM_MAPS);
@@ -459,6 +451,7 @@ public class RangerAPIMapping {
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_SERVICE_DEF_BY_NAME);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_SERVICE_DEFS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_SERVICES);
+		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_SERVICE_HEADERS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.LOOKUP_RESOURCE);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.UPDATE_SERVICE);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.UPDATE_SERVICE_DEF);
@@ -468,7 +461,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_USERS);
 
 		apiAssociatedWithRBPolicies.add(RangerAPIList.COUNT_X_AUDIT_MAPS);
-		apiAssociatedWithRBPolicies.add(RangerAPIList.COUNT_X_GROUP_GROUPS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.COUNT_X_GROUPS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.COUNT_X_GROUP_USERS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.COUNT_X_PERM_MAPS);
@@ -480,7 +472,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_AUDIT_MAP);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_GROUP);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_GROUP_BY_GROUP_NAME);
-		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_GROUP_GROUP);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_GROUP_USER);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_GROUP_USERS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.GET_X_PERM_MAP);
@@ -491,7 +482,6 @@ public class RangerAPIMapping {
 		apiAssociatedWithRBPolicies.add(RangerAPIList.MODIFY_USER_ACTIVE_STATUS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.MODIFY_USER_VISIBILITY);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_X_AUDIT_MAPS);
-		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_X_GROUP_GROUPS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_X_GROUPS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_X_GROUP_USERS);
 		apiAssociatedWithRBPolicies.add(RangerAPIList.SEARCH_X_PERM_MAPS);
