@@ -697,6 +697,38 @@ public class RangerKRBAuthenticationFilter extends RangerKrbFilter {
 		public Dynamic addFilter(String filterName, String className) {
 			return null;
 		}
+
+		@Override
+		public ServletRegistration.Dynamic addJspFile(String servletName, String jspFile) {
+			return null;
+		}
+
+		@Override
+		public int getSessionTimeout() {
+			return 0;
+		}
+
+		@Override
+		public void setSessionTimeout(int sessionTimeout) {
+		}
+
+		@Override
+		public String getRequestCharacterEncoding() {
+			return null;
+		}
+
+		@Override
+		public void setRequestCharacterEncoding(String encoding) {
+		}
+
+		@Override
+		public String getResponseCharacterEncoding() {
+			return null;
+		}
+
+		@Override
+		public void setResponseCharacterEncoding(String encoding) {
+		}
 	};
 
 }
