@@ -70,6 +70,20 @@ public abstract class RangerServiceServiceBase<T extends XXServiceBase, V extend
 		sortFields.add(new SortField(SearchFilter.SERVICE_DISPLAY_NAME, "obj.displayName"));
 	}
 
+	@Override
+	public String getParentObjectName(V vObj, V oldObj) {
+		String serviceType = vObj != null ? vObj.getType() : null;
+		XXServiceDef xServiceDef = serviceType != null ? daoMgr.getXXServiceDef().findByName(serviceType) : null;
+		return xServiceDef != null ? xServiceDef.getName() : null;
+	}
+
+	@Override
+	public Long getParentObjectId(V vObj, V oldObj) {
+		String serviceType = vObj != null ? vObj.getType() : null;
+		XXServiceDef xServiceDef = serviceType != null ? daoMgr.getXXServiceDef().findByName(serviceType) : null;
+		return xServiceDef != null ? xServiceDef.getId() : null;
+	}
+
 	@Override
 	protected T mapViewToEntityBean(V vObj, T xObj, int OPERATION_CONTEXT) {
 		String guid = (StringUtils.isEmpty(vObj.getGuid())) ? guidUtil.genGUID() : vObj.getGuid();
