@@ -44,7 +44,6 @@ public class RangerMetricsUtil {
     private static final Logger LOG = LoggerFactory.getLogger(RangerMetricsUtil.class);
     private static final OperatingSystemMXBean OS;
     private static final MemoryMXBean MEM_BEAN;
-    public static final String NL = System.getProperty("line.separator");
 
     static {
         OS = ManagementFactory.getOperatingSystemMXBean();
@@ -53,7 +52,7 @@ public class RangerMetricsUtil {
 
     public Map<String, Object> getValues() {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerJVMMetricUtil.getValues()");
+            LOG.debug("==> RangerMetricsUtil.getValues()");
         }
         
         Map<String, Object> values = new LinkedHashMap<>();
@@ -62,7 +61,7 @@ public class RangerMetricsUtil {
         values.put("memory", addMemoryDetails());
 
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerJVMMetricUtil.getValues()" + values);
+            LOG.debug("<== RangerMetricsUtil.getValues()" + values);
         }
 
         return values;
@@ -73,7 +72,7 @@ public class RangerMetricsUtil {
      */
     protected Map<String, Object> getPoolDivision() {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerJVMMetricUtil.getPoolDivision()");
+            LOG.debug("==> RangerMetricsUtil.getPoolDivision()");
         }
 
         Map<String, Object> poolDivisionValues = new LinkedHashMap<>();
@@ -84,7 +83,7 @@ public class RangerMetricsUtil {
         }
 
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerJVMMetricUtil.getPoolDivision()" + poolDivisionValues);
+            LOG.debug("<== RangerMetricsUtil.getPoolDivision()" + poolDivisionValues);
         }
 
         return poolDivisionValues;
@@ -95,7 +94,7 @@ public class RangerMetricsUtil {
      */
     protected Map<String, Object> addMemoryDetails() {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerJVMMetricUtil.addMemoryDetails()");
+            LOG.debug("==> RangerMetricsUtil.addMemoryDetails()");
         }
 
         Map<String, Object> memory  = new LinkedHashMap<>();
@@ -112,7 +111,7 @@ public class RangerMetricsUtil {
         memory.put("memory_pool_usages", getPoolDivision());
 
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerJVMMetricUtil.addMemoryDetails()" + memory);
+            LOG.debug("<== RangerMetricsUtil.addMemoryDetails()" + memory);
         }
 
         return memory;
@@ -123,12 +122,12 @@ public class RangerMetricsUtil {
      */
     protected String[] addSystemInfo() {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerJVMMetricUtil.addSystemInfo()");
+            LOG.debug("==> RangerMetricsUtil.addSystemInfo()");
         }
 
         String[] osInfo = { OS.getName(), OS.getArch(), OS.getVersion() };
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerJVMMetricUtil.addSystemInfo()" + osInfo);
+            LOG.debug("<== RangerMetricsUtil.addSystemInfo()" + osInfo);
         }
 
         return osInfo;
