@@ -28,7 +28,7 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
       editors.Base.prototype.initialize.call(this, options);
 
       var schema = this.schema;
-      if (!schema) throw "Missing required option 'schema'";
+      if (!schema) throw new Error("Missing required option 'schema'");
 
       this.template = options.template || this.constructor.template;
 
@@ -51,7 +51,8 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
 
     render: function() {
       var self = this,
-          value = this.value || [];
+          value = this.value || [],
+          $ = Backbone.$;
 
       //Create main element
       var $el = $($.trim(this.template()));
@@ -289,12 +290,14 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
       this.value = options.value;
       this.Editor = options.Editor || Form.editors.Text;
       this.key = options.key;
-      this.template = options.template || this.constructor.template;
+      this.template = options.template || this.schema.itemTemplate || this.constructor.template;
       this.errorClassName = options.errorClassName || this.constructor.errorClassName;
       this.form = options.form;
     },
 
     render: function() {
+      var $ = Backbone.$;
+      
       //Create editor
       this.editor = new this.Editor({
         key: this.key,
@@ -419,10 +422,10 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
       Form.editors.Base.prototype.initialize.call(this, options);
       
       //Dependencies
-      if (!Form.editors.List.Modal.ModalAdapter) throw 'A ModalAdapter is required';
+      if (!Form.editors.List.Modal.ModalAdapter) throw new Error('A ModalAdapter is required');
 
       this.form = options.form;
-      if (!options.form) throw 'Missing required option: "form"';
+      if (!options.form) throw new Error('Missing required option: "form"');
 
       //Template
       this.template = options.template || this.constructor.template;
@@ -594,7 +597,7 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
     //STATICS
     template: _.template('\
       <div><%= summary %></div>\
-    '),
+    ', null, Form.templateSettings),
 
     //The modal adapter that creates and manages the modal dialog.
     //Defaults to BootstrapModal (http://github.com/powmedia/backbone.bootstrap-modal)
@@ -612,7 +615,7 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
 
       var schema = this.schema;
 
-      if (!schema.subSchema) throw 'Missing required option "schema.subSchema"';
+      if (!schema.subSchema) throw new Error('Missing required option "schema.subSchema"');
 
       this.nestedSchema = schema.subSchema;
     }
@@ -625,7 +628,7 @@ define(['jquery', 'underscore', 'backbone', 'backbone-forms'], function($, _, Ba
 
       var schema = this.schema;
 
-      if (!schema.model) throw 'Missing required option "schema.model"';
+      if (!schema.model) throw new Error('Missing required option "schema.model"');
 
       var nestedSchema = schema.model.prototype.schema;
 
