@@ -43,7 +43,8 @@ import {
   drop,
   dragOver,
   policyConditionUpdatedJSON
-} from "../../utils/XAUtils";
+} from "Utils/XAUtils";
+import { selectInputCustomStyles } from "Components/CommonComponents";
 
 const noneOptions = {
   label: "None",
@@ -285,6 +286,7 @@ export default function PolicyPermissionItem(props) {
   };
 
   const customStyles = {
+    ...selectInputCustomStyles,
     control: (base) => ({
       ...base,
       width: 200,
