@@ -38,18 +38,19 @@ import {
 import { Table } from "react-bootstrap";
 import { FieldArray } from "react-final-form-arrays";
 import arrayMutators from "final-form-arrays";
-import ModalResourceComp from "../Resources/ModalResourceComp";
+import ModalResourceComp from "Views/Resources/ModalResourceComp";
 import { RegexValidation } from "Utils/XAEnums";
 import { toast } from "react-toastify";
-import { commonBreadcrumb, serverError } from "../../utils/XAUtils";
+import { commonBreadcrumb, serverError } from "Utils/XAUtils";
 import {
   BlockUi,
   Loader,
   scrollToError,
-  selectCustomStyles
-} from "../../components/CommonComponents";
+  selectInputCustomStyles,
+  selectInputCustomErrorStyles
+} from "Components/CommonComponents";
 import usePrompt from "Hooks/usePrompt";
-import { getServiceDef } from "../../utils/appState";
+import { getServiceDef } from "Utils/appState";
 
 const noneOptions = {
   label: "None",
@@ -847,8 +848,8 @@ const SecurityZoneForm = () => {
                               {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
@@ -870,7 +871,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select User"
+                              placeholder="Select Users"
                             />
                           </Col>
                         </Row>
@@ -888,17 +889,17 @@ const SecurityZoneForm = () => {
                           </Col>
                           <Col xs={4}>
                             <AsyncSelect
+                              {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
                                   ? "isError"
                                   : "adminUserGroups"
                               }
-                              {...input}
                               cacheOptions
                               loadOptions={fetchGroupsData}
                               onFocus={() => {
@@ -914,7 +915,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select Group"
+                              placeholder="Select Groups"
                             />
                           </Col>
                         </Row>
@@ -935,8 +936,8 @@ const SecurityZoneForm = () => {
                               {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
@@ -958,7 +959,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select Role"
+                              placeholder="Select Roles"
                             />
                             {meta.touched && meta.error && (
                               <span className="invalid-field">
@@ -984,8 +985,8 @@ const SecurityZoneForm = () => {
                               {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
@@ -1007,7 +1008,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select User"
+                              placeholder="Select Users"
                             />
                           </Col>
                         </Row>
@@ -1028,8 +1029,8 @@ const SecurityZoneForm = () => {
                               {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
@@ -1051,7 +1052,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select Group"
+                              placeholder="Select Groups"
                             />
                           </Col>
                         </Row>
@@ -1072,8 +1073,8 @@ const SecurityZoneForm = () => {
                               {...input}
                               styles={
                                 meta.error && meta.touched
-                                  ? selectCustomStyles
-                                  : ""
+                                  ? selectInputCustomErrorStyles
+                                  : selectInputCustomStyles
                               }
                               id={
                                 meta.error && meta.touched
@@ -1095,7 +1096,7 @@ const SecurityZoneForm = () => {
                                 IndicatorSeparator: () => null
                               }}
                               isClearable={true}
-                              placeholder="Select Role"
+                              placeholder="Select Roles"
                             />
                             {meta.error && meta.touched && (
                               <span className="invalid-field">
@@ -1114,7 +1115,7 @@ const SecurityZoneForm = () => {
                         <Row className="form-group">
                           <Col xs={3}>
                             <label className="form-label float-end">
-                              Select Tag Services
+                              Tag Services
                             </label>
                           </Col>
                           <Col xs={6}>
@@ -1136,6 +1137,7 @@ const SecurityZoneForm = () => {
                               }}
                               isClearable={true}
                               placeholder="Select Tag Services"
+                              styles={selectInputCustomStyles}
                             />
                           </Col>
                         </Row>
@@ -1148,7 +1150,7 @@ const SecurityZoneForm = () => {
                         <Row className="form-group">
                           <Col xs={3}>
                             <label className="form-label float-end">
-                              Select Resource Services
+                              Resource Services
                             </label>
                           </Col>
                           <Col xs={6}>
@@ -1171,7 +1173,8 @@ const SecurityZoneForm = () => {
                               options={resourceServicesOpt}
                               isClearable={false}
                               isSearchable={true}
-                              placeholder="Select Service Name"
+                              placeholder="Select Resource Services"
+                              styles={selectInputCustomStyles}
                             />
                           </Col>
                         </Row>
