@@ -19,7 +19,18 @@
 
 import React from "react";
 import { Alert, Row, Col, Table, Badge } from "react-bootstrap";
-import { difference, isEmpty, keys, map, omit, pick } from "lodash";
+import {
+  difference,
+  isEmpty,
+  keys,
+  map,
+  omit,
+  pick,
+  intersection,
+  find,
+  sortBy
+} from "lodash";
+import { additionalServiceConfigs } from "Utils/XAEnums";
 
 export const ServiceViewDetails = (props) => {
   let { serviceData, serviceDefData } = props;
@@ -36,7 +47,18 @@ export const ServiceViewDetails = (props) => {
 
     let serviceConfigsKey = keys(serviceConfigs);
     let serviceDefConfigsKey = map(serviceDefConfigs, "name");
-    let customConfigsKey = difference(serviceConfigsKey, serviceDefConfigsKey);
+
+    const additionalServiceConfigsKey = intersection(
+      map(additionalServiceConfigs, "name"),
+      serviceConfigsKey
+    );
+
+    const customConfigsKey = sortBy(
+      difference(
+        difference(serviceConfigsKey, serviceDefConfigsKey),
+        additionalServiceConfigsKey
+      )
+    );
 
     serviceDefConfigs?.map(
       (config) =>
@@ -44,6 +66,11 @@ export const ServiceViewDetails = (props) => {
           serviceConfigs[config.name])
     );
 
+    additionalServiceConfigsKey.map((config) => {
+      configs[find(additionalServiceConfigs, ["name", config]).label] =
+        serviceConfigs[config];
+    });
+
     Object.entries(configs)?.map(([key, value]) =>
       tableRow.push(
         <tr key={key}>
@@ -60,7 +87,7 @@ export const ServiceViewDetails = (props) => {
     tableRow.push(
       <tr key="custom-configs-title">
         <td colSpan="2">
-          <b>Add New Configurations :</b>
+          <b>Custom Configurations :</b>
         </td>
       </tr>
     );
@@ -185,59 +212,59 @@ export const ServiceViewDetails = (props) => {
           <td className="text-center">
             {a.actions !== undefined
               ? a.actions.map((action) => (
-                  <h6 key={action}>
-                    <Badge bg="info">{action}</Badge>
-                  </h6>
+                  <Badge bg="info" className="m-1 text-truncate" key={action}>
+                    {action}
+                  </Badge>
                 ))
               : "--"}
           </td>
           <td className="text-center">
             {a.accessTypes !== undefined && a.accessTypes.length > 0
               ? a.accessTypes.map((accessType) => (
-                  <h6 key={accessType}>
-                    <Badge bg="info">{accessType}</Badge>
-                  </h6>
+                  <Badge
+                    bg="info"
+                    className="m-1 text-truncate"
+                    key={accessType}
+                  >
+                    {accessType}
+                  </Badge>
                 ))
               : "--"}
           </td>
           <td className="text-center">
             {a.users !== undefined
               ? a.users.map((user) => (
-                  <h6 key={user}>
-                    <Badge
-                      bg="info"
-                      className="m-1 text-truncate more-less-width"
-                      title={user}
-                      key={user}
-                    >
-                      {user}
-                    </Badge>
-                  </h6>
+                  <Badge
+                    bg="info"
+                    className="m-1 text-truncate more-less-width"
+                    title={user}
+                    key={user}
+                  >
+                    {user}
+                  </Badge>
                 ))
               : "--"}
           </td>
           <td className="text-center">
             {a.groups !== undefined
               ? a.groups.map((group) => (
-                  <h6 key={group}>
-                    <Badge
-                      bg="info"
-                      className="m-1 text-truncate more-less-width"
-                      title={group}
-                      key={group}
-                    >
-                      {group}
-                    </Badge>
-                  </h6>
+                  <Badge
+                    bg="info"
+                    className="m-1 text-truncate more-less-width"
+                    title={group}
+                    key={group}
+                  >
+                    {group}
+                  </Badge>
                 ))
               : "--"}
           </td>
           <td className="text-center">
             {a.roles !== undefined
               ? a.roles.map((role) => (
-                  <h6 key={role}>
-                    <Badge bg="info">{role}</Badge>
-                  </h6>
+                  <Badge bg="info" key={role}>
+                    {role}
+                  </Badge>
                 ))
               : "--"}
           </td>
@@ -256,16 +283,16 @@ export const ServiceViewDetails = (props) => {
             <tbody className="service-details">
               <tr>
                 <td className="text-nowrap">Service Name</td>
-                <td className="text-break">{serviceData.name}</td>
+                <td className="text-break">{serviceData?.name}</td>
               </tr>
               <tr>
                 <td className="text-nowrap">Display Name</td>
-                <td className="text-break">{serviceData.displayName}</td>
+                <td className="text-break">{serviceData?.displayName}</td>
               </tr>
               <tr>
                 <td className="text-nowrap">Description</td>
                 <td className="text-break">
-                  {serviceData.description ? serviceData.description : "--"}
+                  {serviceData?.description ? serviceData.description : "--"}
                 </td>
               </tr>
               <tr>
@@ -273,7 +300,7 @@ export const ServiceViewDetails = (props) => {
                 <td>
                   <h6>
                     <Badge bg="info">
-                      {serviceData.isEnabled ? `Enabled` : `Disabled`}
+                      {serviceData?.isEnabled ? `Enabled` : `Disabled`}
                     </Badge>
                   </h6>
                 </td>
@@ -281,7 +308,7 @@ export const ServiceViewDetails = (props) => {
               <tr>
                 <td className="text-nowrap">Tag Service</td>
                 <td className="text-break">
-                  {serviceData.tagService ? (
+                  {serviceData?.tagService ? (
                     <h6>
                       <Badge bg="info">{serviceData.tagService}</Badge>
                     </h6>
