@@ -553,7 +553,8 @@ function Users() {
       options: () => {
         return [
           { value: "0", label: "Internal" },
-          { value: "1", label: "External" }
+          { value: "1", label: "External" },
+          { value: "6", label: "Federated" }
         ];
       }
     },
