@@ -261,6 +261,9 @@ define(function(require) {
                 minGroupId                      : "Minimum group id",
                 userSearchFilter                : 'User search filter',
                 groupSearchFilter               : 'Group search filter',
+                userSearchEnabled               : 'User search enabled',
+                groupSearchEnabled              : 'Group search enabled',
+                groupSearchFirstEnabled         : 'Group search first enabled',
                 startDate                       : 'Start Date',
                 endDate                         : 'End Date',
                 addValidityPeriod               : ' Add Validity Period',
@@ -283,6 +286,9 @@ define(function(require) {
                 displayName                     : 'Display Name',
                 auditAccessDetail               : 'Audit Access Log Detail',
                 hiveQuery                       : 'Hive Query',
+                hbaseAudit                      : 'HBase Audit Data',
+                solrQuery                       : 'Solr Query',
+                hdfsOperation                   : 'HDFS Operation Name',
                 clientIP                        : 'Client IP',
                 eventCount                      : 'Event Count',
                 tags                            : 'Tags',
@@ -501,7 +507,8 @@ define(function(require) {
                                         You can still open this instance of Ranger from the same web browser without re-authentication. \
                                         To prevent additional access to Ranger, <b>close all browser windows and exit the browser</b>.',
                 pageNotFound            : 'Sorry, this page isn\'t here or has moved.',
-                resourcesLookup         : 'Resouce lookup fail for current resource'
+                resourcesLookup         : 'Resouce lookup fail for current resource',
+                dataNotFound            : 'Data not found for given page.'
 
 
 			},
@@ -516,7 +523,7 @@ define(function(require) {
 				preventNavGroupForm : 'Group form edit is in progress. Please save/cancel changes before navigating away!',
 				preventNavUserList : 'Some Users/Groups have been edited. Kindly save your changes before navigating away!',
 				preventNavZoneForm : 'Zone form edit is in progress. Please save/cancel changes before navigating away!',
-				idelTimeOutMsg : 'Because you have been inactive, your session is about to expire.'
+				idleTimeOutMsg : 'Because you have been inactive, your session is about to expire.'
 				
 			},	
 			validationMessages : {
