@@ -125,4 +125,14 @@ $(function() {
 			$(e.target).parent().removeClass('error');
 		}
 	});
+
+	$("#password").on("input", function() {
+		$("#show-password").toggle(this.value.trim() !== "");
+	});
+
+	$("#show-password").on("click", function() {
+		var showPassword = $("#password").is(":password");
+		$("#password").attr("type", showPassword ? "text" : "password");
+		$("#show-password").toggleClass("fa-eye-slash fa-eye");
+	});
 });
