@@ -14,18 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-try:
-	from StringIO import StringIO
-except ImportError:
-	from io import StringIO
-try:
-	from ConfigParser import ConfigParser
-except ImportError:
-	from configparser import ConfigParser
-try:
-	from urlparse import urlparse
-except ImportError:
-	from urllib.parse import urlparse
+from io import StringIO
+from configparser import ConfigParser
+from urllib.parse import urlparse
 import re
 import xml.etree.ElementTree as ET
 import os,errno,sys,getopt
@@ -161,7 +152,7 @@ def getPropertiesConfigMap(configFileName):
     config.seek(0,os.SEEK_SET)
     fcp = ConfigParser()
     fcp.optionxform = str
-    fcp.readfp(config)
+    fcp.read_file(config)
     for k,v in fcp.items('dummysection'):
         ret[k] = v
     return ret
@@ -174,7 +165,7 @@ def getPropertiesKeyList(configFileName):
     config.seek(0,os.SEEK_SET)
     fcp = ConfigParser()
     fcp.optionxform = str
-    fcp.readfp(config)
+    fcp.read_file(config)
     for k,v in fcp.items('dummysection'):
         ret.append(k)
     return ret
