@@ -22,18 +22,16 @@ package org.apache.ranger.tagsync.source.atlas;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.atlas.typesystem.IReferenceableInstance;
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerServiceResource;
+import org.apache.ranger.tagsync.source.atlasrest.RangerAtlasEntity;
 
 public class AtlasKafkaResourceMapper extends AtlasResourceMapper {
 	public static final String ENTITY_TYPE_KAFKA_TOPIC = "kafka_topic";
 	public static final String RANGER_TYPE_KAFKA_TOPIC = "topic";
 
-	public static final String ENTITY_ATTRIBUTE_QUALIFIED_NAME = "qualifiedName";
-
 	public static final String[] SUPPORTED_ENTITY_TYPES = { ENTITY_TYPE_KAFKA_TOPIC };
 
 	public AtlasKafkaResourceMapper() {
@@ -41,12 +39,8 @@ public class AtlasKafkaResourceMapper extends AtlasResourceMapper {
 	}
 
 	@Override
-	public RangerServiceResource buildResource(final IReferenceableInstance entity) throws Exception {
-		String qualifiedName = getEntityAttribute(entity, ENTITY_ATTRIBUTE_QUALIFIED_NAME, String.class);
-
-		if(StringUtils.isEmpty(qualifiedName)) {
-			throwExceptionWithMessage("attribute '" + ENTITY_ATTRIBUTE_QUALIFIED_NAME +  "' not found in entity");
-		}
+	public RangerServiceResource buildResource(final RangerAtlasEntity entity) throws Exception {
+		String qualifiedName = (String)entity.getAttributes().get(AtlasResourceMapper.ENTITY_ATTRIBUTE_QUALIFIED_NAME);
 
 		String topic = getResourceNameFromQualifiedName(qualifiedName);
 
@@ -61,16 +55,17 @@ public class AtlasKafkaResourceMapper extends AtlasResourceMapper {
 		}
 
 		if(StringUtils.isEmpty(clusterName)) {
-			throwExceptionWithMessage("Cluster name not found in attribute '" + ENTITY_ATTRIBUTE_QUALIFIED_NAME +  "'");
+			throwExceptionWithMessage("attribute '" + ENTITY_ATTRIBUTE_QUALIFIED_NAME +  "' not found in entity");
 		}
 
+
 		Map<String, RangerPolicyResource> elements = new HashMap<String, RangerPolicy.RangerPolicyResource>();
 		Boolean isExcludes  = Boolean.FALSE;
 		Boolean isRecursive = Boolean.TRUE;
 
 		elements.put(RANGER_TYPE_KAFKA_TOPIC, new RangerPolicyResource(topic, isExcludes, isRecursive));
 
-		String  entityGuid  = entity.getId() != null ? entity.getId()._getId() : null;
+		String  entityGuid  = entity.getGuid();
 		String  serviceName = getRangerServiceName(clusterName);
 
 		return new RangerServiceResource(entityGuid, serviceName, elements);
