@@ -54,6 +54,8 @@ import javax.naming.ldap.StartTlsResponse;
 
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
+import org.apache.hadoop.thirdparty.com.google.common.collect.HashBasedTable;
+import org.apache.hadoop.thirdparty.com.google.common.collect.Table;
 import org.apache.ranger.ugsyncutil.util.UgsyncCommonConstants;
 import org.apache.ranger.unixusersync.config.UserGroupSyncConfig;
 import org.apache.ranger.ugsyncutil.model.LdapSyncSourceInfo;
@@ -62,8 +64,6 @@ import org.apache.ranger.usergroupsync.UserGroupSink;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.HashBasedTable;
-import com.google.common.collect.Table;
 import org.apache.ranger.usergroupsync.UserGroupSource;
 
 public class LdapUserGroupBuilder implements UserGroupSource {
