@@ -19,25 +19,19 @@
 
  package org.apache.ranger.usergroupsync;
 
-import org.apache.ranger.unixusersync.model.UgsyncAuditInfo;
+import org.apache.ranger.ugsyncutil.model.UgsyncAuditInfo;
 
-import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 public interface UserGroupSink {
 	void init() throws Throwable;
 
-	void addOrUpdateUser(String user, List<String> groups) throws Throwable;
-	
-	void addOrUpdateUser(String user) throws Throwable;
-	
-	void addOrUpdateGroup(String group, Map<String, String> groupAttrs) throws Throwable;
-	
-	void addOrUpdateGroup(String group, List<String> users) throws Throwable;
-
 	void postUserGroupAuditInfo(UgsyncAuditInfo ugsyncAuditInfo) throws Throwable;
 
-	void addOrUpdateUser(String user, Map<String, String> userAttrs, List<String> groups) throws Throwable;
+	void addOrUpdateUsersGroups(Map<String, Map<String, String>> sourceGroups,
+								Map<String, Map<String, String>> sourceUsers,
+								Map<String, Set<String>> sourceGroupUsers,
+								boolean computeDeletes) throws Throwable;
 
-	void addOrUpdateGroup(String group, Map<String, String> groupAttrs, List<String> users) throws Throwable;
 }
