@@ -43,6 +43,7 @@ import javax.net.ssl.SSLServerSocketFactory;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
 
+import org.apache.ranger.unixusersync.ha.UserSyncHAInitializerImpl;
 import org.apache.ranger.credentialapi.CredentialReader;
 import org.apache.ranger.plugin.util.XMLUtils;
 import org.apache.ranger.unixusersync.config.UserGroupSyncConfig;
@@ -86,6 +87,7 @@ public class UnixAuthenticationService {
 	private String trustStoreType;
 	private List<String>  adminUserList = new ArrayList<String>();
 	private String adminRoleNames;
+	private UserSyncHAInitializerImpl userSyncHAInitializerImpl = null;
 	
 	private int  portNum;
 	
@@ -105,6 +107,7 @@ public class UnixAuthenticationService {
 			}
 		}
 		UnixAuthenticationService service = new UnixAuthenticationService();
+		service.userSyncHAInitializerImpl = UserSyncHAInitializerImpl.getInstance(UserGroupSyncConfig.getInstance().getUserGroupConfig());
 		service.run();
 	}
 
@@ -130,6 +133,10 @@ public class UnixAuthenticationService {
 		}
 		finally {
 			LOG.info("Service: " + serviceName + " - STOPPED.");
+			if(this.userSyncHAInitializerImpl != null) {
+				LOG.info("Stopping curator leader latch service as main thread is closing");
+				this.userSyncHAInitializerImpl.stop();
+			}
 		}
 	}
 
@@ -305,57 +312,57 @@ public class UnixAuthenticationService {
 		
 		SSLServerSocketFactory sf = context.getServerSocketFactory();
 
-		ServerSocket socket = (SSLEnabled ? sf.createServerSocket(portNum) :  new ServerSocket(portNum) );
-		
-		if (SSLEnabled) {
-			SSLServerSocket secureSocket = (SSLServerSocket) socket;
-			String[] protocols = secureSocket.getEnabledProtocols();
-			Set<String> allowedProtocols = new HashSet<String>();
-			for(String ep : protocols) {
-				if (enabledProtocolsList.contains(ep.toUpperCase())){
-					LOG.info("Enabling Protocol: [" + ep + "]");
-					allowedProtocols.add(ep);
-				}
-				else {
-					LOG.info("Disabling Protocol: [" + ep + "]");
-				}
-			}
-			
-			if (!allowedProtocols.isEmpty()) {
-				secureSocket.setEnabledProtocols(allowedProtocols.toArray(new String[0]));
-			}
-			String[] enabledCipherSuites = secureSocket.getEnabledCipherSuites();
-			Set<String> allowedCipherSuites = new HashSet<String>();
-			for(String enabledCipherSuite : enabledCipherSuites) {
-				if (enabledCipherSuiteList.contains(enabledCipherSuite)) {
-					if(LOG.isDebugEnabled()) {
-						LOG.debug("Enabling CipherSuite : [" + enabledCipherSuite + "]");
-					}
-					allowedCipherSuites.add(enabledCipherSuite);
-				} else {
-					if(LOG.isDebugEnabled()) {
-						LOG.debug("Disabling CipherSuite : [" + enabledCipherSuite + "]");
+		try(ServerSocket socket = (SSLEnabled ? sf.createServerSocket(portNum) :  new ServerSocket(portNum) )) {
+
+			if (SSLEnabled) {
+				SSLServerSocket secureSocket     = (SSLServerSocket) socket;
+				String[]        protocols        = secureSocket.getEnabledProtocols();
+				Set<String>     allowedProtocols = new HashSet<String>();
+				for (String ep : protocols) {
+					if (enabledProtocolsList.contains(ep.toUpperCase())) {
+						LOG.info("Enabling Protocol: [" + ep + "]");
+						allowedProtocols.add(ep);
+					} else {
+						LOG.info("Disabling Protocol: [" + ep + "]");
 					}
 				}
+
+				if (!allowedProtocols.isEmpty()) {
+					secureSocket.setEnabledProtocols(allowedProtocols.toArray(new String[0]));
+				}
+				String[]    enabledCipherSuites = secureSocket.getEnabledCipherSuites();
+				Set<String> allowedCipherSuites = new HashSet<String>();
+				for (String enabledCipherSuite : enabledCipherSuites) {
+					if (enabledCipherSuiteList.contains(enabledCipherSuite)) {
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("Enabling CipherSuite : [" + enabledCipherSuite + "]");
+						}
+						allowedCipherSuites.add(enabledCipherSuite);
+					} else {
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("Disabling CipherSuite : [" + enabledCipherSuite + "]");
+						}
+					}
+				}
+				if (!allowedCipherSuites.isEmpty()) {
+					secureSocket.setEnabledCipherSuites(allowedCipherSuites.toArray(new String[0]));
+				}
 			}
-			if (!allowedCipherSuites.isEmpty()) {
-				secureSocket.setEnabledCipherSuites(allowedCipherSuites.toArray(new String[0]));
+
+
+			Socket client = null;
+
+			try {
+
+				while ((client = socket.accept()) != null) {
+					Thread clientValidatorThread = new Thread(new PasswordValidator(client));
+					clientValidatorThread.start();
+				}
+			} catch (IOException e) {
+				socket.close();
+				throw (e);
 			}
 		}
-		
-				
-		Socket client = null;
-		
-		try {
-		
-			while ( (client = socket.accept()) != null ) {
-				Thread clientValidatorThread = new Thread(new PasswordValidator(client));
-				clientValidatorThread.start();
-			}
-		} catch (IOException e) {
-			socket.close();
-			throw(e);
-		}
 
 	}
 	
